package com.bda.controller;

import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.os.Handler;
import android.os.IBinder;
import android.os.RemoteException;
import com.bda.controller.IControllerListener.Stub;

public final class Controller {
    public static final int ACTION_CONNECTED = 1;
    public static final int ACTION_CONNECTING = 2;
    public static final int ACTION_DISCONNECTED = 0;
    public static final int ACTION_DOWN = 0;
    public static final int ACTION_FALSE = 0;
    public static final int ACTION_TRUE = 1;
    public static final int ACTION_UP = 1;
    public static final int ACTION_VERSION_MOGA = 0;
    public static final int ACTION_VERSION_MOGAPRO = 1;
    public static final int AXIS_LTRIGGER = 17;
    public static final int AXIS_RTRIGGER = 18;
    public static final int AXIS_RZ = 14;
    public static final int AXIS_X = 0;
    public static final int AXIS_Y = 1;
    public static final int AXIS_Z = 11;
    static final int CONTROLLER_ID = 1;
    public static final int INFO_ACTIVE_DEVICE_COUNT = 2;
    public static final int INFO_KNOWN_DEVICE_COUNT = 1;
    public static final int INFO_UNKNOWN = 0;
    public static final int KEYCODE_BUTTON_A = 96;
    public static final int KEYCODE_BUTTON_B = 97;
    public static final int KEYCODE_BUTTON_L1 = 102;
    public static final int KEYCODE_BUTTON_L2 = 104;
    public static final int KEYCODE_BUTTON_R1 = 103;
    public static final int KEYCODE_BUTTON_R2 = 105;
    public static final int KEYCODE_BUTTON_SELECT = 109;
    public static final int KEYCODE_BUTTON_START = 108;
    public static final int KEYCODE_BUTTON_THUMBL = 106;
    public static final int KEYCODE_BUTTON_THUMBR = 107;
    public static final int KEYCODE_BUTTON_X = 99;
    public static final int KEYCODE_BUTTON_Y = 100;
    public static final int KEYCODE_DPAD_DOWN = 20;
    public static final int KEYCODE_DPAD_LEFT = 21;
    public static final int KEYCODE_DPAD_RIGHT = 22;
    public static final int KEYCODE_DPAD_UP = 19;
    public static final int KEYCODE_UNKNOWN = 0;
    static final int LEGACY_KEYCODE_BUTTON_X = 98;
    static final int LEGACY_KEYCODE_BUTTON_Y = 99;
    public static final int STATE_CONNECTION = 1;
    public static final int STATE_CURRENT_PRODUCT_VERSION = 4;
    public static final int STATE_POWER_LOW = 2;
    @Deprecated
    public static final int STATE_SELECTED_VERSION = 4;
    public static final int STATE_SUPPORTED_PRODUCT_VERSION = 3;
    @Deprecated
    public static final int STATE_SUPPORTED_VERSION = 3;
    public static final int STATE_UNKNOWN = 0;
    int mActivityEvent;
    final Context mContext;
    Handler mHandler;
    boolean mIsBound;
    ControllerListener mListener;
    final Stub mListenerStub;
    ControllerMonitor mMonitor;
    final IControllerMonitor.Stub mMonitorStub;
    IControllerService mService;
    final ServiceConnection mServiceConnection;

    class IControllerListenerStub extends Stub {
        IControllerListenerStub() {
        }

        public void onKeyEvent(KeyEvent keyEvent) throws RemoteException {
            if (keyEvent.getControllerId() == Controller.STATE_CONNECTION && Controller.this.mListener != null) {
                Object keyRunnable = new KeyRunnable(keyEvent);
                if (Controller.this.mHandler != null) {
                    Controller.this.mHandler.post(keyRunnable);
                } else {
                    keyRunnable.run();
                }
            }
        }

        public void onMotionEvent(MotionEvent motionEvent) throws RemoteException {
            if (motionEvent.getControllerId() == Controller.STATE_CONNECTION && Controller.this.mListener != null) {
                Object motionRunnable = new MotionRunnable(motionEvent);
                if (Controller.this.mHandler != null) {
                    Controller.this.mHandler.post(motionRunnable);
                } else {
                    motionRunnable.run();
                }
            }
        }

        public void onStateEvent(StateEvent stateEvent) throws RemoteException {
            if (stateEvent.getControllerId() == Controller.STATE_CONNECTION && Controller.this.mListener != null) {
                Object stateRunnable = new StateRunnable(stateEvent);
                if (Controller.this.mHandler != null) {
                    Controller.this.mHandler.post(stateRunnable);
                } else {
                    stateRunnable.run();
                }
            }
        }
    }

    class IControllerMonitorStub extends IControllerMonitor.Stub {
        IControllerMonitorStub() {
        }

        public void onLog(int i, int i2, String str) throws RemoteException {
            if (Controller.this.mMonitor != null) {
                Controller.this.mMonitor.onLog(i, i2, str);
            }
        }
    }

    class KeyRunnable implements Runnable {
        final KeyEvent mEvent;

        public KeyRunnable(KeyEvent keyEvent) {
            this.mEvent = keyEvent;
        }

        public void run() {
            if (Controller.this.mListener != null) {
                Controller.this.mListener.onKeyEvent(this.mEvent);
            }
        }
    }

    class MotionRunnable implements Runnable {
        final MotionEvent mEvent;

        public MotionRunnable(MotionEvent motionEvent) {
            this.mEvent = motionEvent;
        }

        public void run() {
            if (Controller.this.mListener != null) {
                Controller.this.mListener.onMotionEvent(this.mEvent);
            }
        }
    }

    class ServiceConnection implements android.content.ServiceConnection {
        ServiceConnection() {
        }

        public final void onServiceConnected(ComponentName componentName, IBinder iBinder) {
            Controller.this.mService = IControllerService.Stub.asInterface(iBinder);
            Controller.this.registerListener();
            Controller.this.registerMonitor();
            if (Controller.this.mActivityEvent == 5) {
                Controller.this.sendMessage(Controller.STATE_CONNECTION, 5);
                Controller.this.sendMessage(Controller.STATE_CONNECTION, 7);
            }
        }

        public final void onServiceDisconnected(ComponentName componentName) {
            Controller.this.mService = null;
        }
    }

    class StateRunnable implements Runnable {
        final StateEvent mEvent;

        public StateRunnable(StateEvent stateEvent) {
            this.mEvent = stateEvent;
        }

        public void run() {
            if (Controller.this.mListener != null) {
                Controller.this.mListener.onStateEvent(this.mEvent);
            }
        }
    }

    Controller(Context context) {
        this.mIsBound = false;
        this.mService = null;
        this.mListenerStub = new IControllerListenerStub();
        this.mMonitorStub = new IControllerMonitorStub();
        this.mServiceConnection = new ServiceConnection();
        this.mActivityEvent = 6;
        this.mHandler = null;
        this.mListener = null;
        this.mMonitor = null;
        this.mContext = context;
    }

    public static final Controller getInstance(Context context) {
        return new Controller(context);
    }

    public void allowNewConnections() {
        if (this.mService != null) {
            try {
                this.mService.allowNewConnections();
            } catch (RemoteException e) {
            }
        }
    }

    public void disallowNewConnections() {
        if (this.mService != null) {
            try {
                this.mService.disallowNewConnections();
            } catch (RemoteException e) {
            }
        }
    }

    public final void exit() {
        setListener(null, null);
        setMonitor(null);
        if (this.mIsBound) {
            this.mContext.unbindService(this.mServiceConnection);
            this.mIsBound = false;
        }
    }

    public final float getAxisValue(int i) {
        if (this.mService != null) {
            try {
                return this.mService.getAxisValue(STATE_CONNECTION, i);
            } catch (RemoteException e) {
            }
        }
        return 0.0f;
    }

    public final int getInfo(int i) {
        if (this.mService != null) {
            try {
                return this.mService.getInfo(i);
            } catch (RemoteException e) {
            }
        }
        return KEYCODE_UNKNOWN;
    }

    public final int getKeyCode(int i) {
        int i2 = STATE_CONNECTION;
        if (this.mService != null) {
            try {
                i2 = this.mService.getKeyCode2(STATE_CONNECTION, i);
            } catch (RemoteException e) {
                switch (i) {
                    case LEGACY_KEYCODE_BUTTON_Y /*99*/:
                        i = LEGACY_KEYCODE_BUTTON_X;
                        break;
                    case KEYCODE_BUTTON_Y /*100*/:
                        i = LEGACY_KEYCODE_BUTTON_Y;
                        break;
                }
                try {
                    i2 = this.mService.getKeyCode(STATE_CONNECTION, i);
                } catch (RemoteException e2) {
                }
            }
        }
        return i2;
    }

    public final int getState(int i) {
        if (this.mService != null) {
            try {
                return this.mService.getState(STATE_CONNECTION, i);
            } catch (RemoteException e) {
            }
        }
        return KEYCODE_UNKNOWN;
    }

    public final boolean init() {
        if (!this.mIsBound) {
            Intent intent = new Intent(IControllerService.class.getName());
            this.mContext.startService(intent);
            this.mContext.bindService(intent, this.mServiceConnection, STATE_CONNECTION);
            this.mIsBound = true;
        }
        return this.mIsBound;
    }

    public void isAllowingNewConnections() {
        if (this.mService != null) {
            try {
                this.mService.isAllowingNewConnections();
            } catch (RemoteException e) {
            }
        }
    }

    public final void onPause() {
        this.mActivityEvent = 6;
        sendMessage(STATE_CONNECTION, this.mActivityEvent);
        registerListener();
    }

    public final void onResume() {
        this.mActivityEvent = 5;
        sendMessage(STATE_CONNECTION, this.mActivityEvent);
        registerListener();
    }

    void registerListener() {
        if (this.mListener != null && this.mService != null) {
            try {
                this.mService.registerListener2(this.mListenerStub, this.mActivityEvent);
            } catch (RemoteException e) {
                try {
                    this.mService.registerListener(this.mListenerStub, this.mActivityEvent);
                } catch (RemoteException e2) {
                }
            }
        }
    }

    void registerMonitor() {
        if (this.mMonitor != null && this.mService != null) {
            try {
                this.mService.registerMonitor(this.mMonitorStub, this.mActivityEvent);
            } catch (RemoteException e) {
            }
        }
    }

    void sendMessage(int i, int i2) {
        if (this.mService != null) {
            try {
                this.mService.sendMessage(i, i2);
            } catch (RemoteException e) {
            }
        }
    }

    public final void setListener(ControllerListener controllerListener, Handler handler) {
        unregisterListener();
        this.mListener = controllerListener;
        this.mHandler = handler;
        registerListener();
    }

    public final void setMonitor(ControllerMonitor controllerMonitor) {
        unregisterMonitor();
        this.mMonitor = controllerMonitor;
        registerMonitor();
    }

    void unregisterListener() {
        if (this.mService != null) {
            try {
                this.mService.unregisterListener(this.mListenerStub, this.mActivityEvent);
            } catch (RemoteException e) {
            }
        }
    }

    void unregisterMonitor() {
        if (this.mService != null) {
            try {
                this.mService.unregisterMonitor(this.mMonitorStub, this.mActivityEvent);
            } catch (RemoteException e) {
            }
        }
    }
}
