package com.epsxe.ePSXe;

import android.content.res.AssetManager;
import android.graphics.Bitmap;
import android.graphics.Bitmap.Config;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.Paint.FontMetrics;
import android.graphics.Typeface;
import android.opengl.GLUtils;
import com.google.android.vending.licensing.Policy;
import javax.microedition.khronos.opengles.GL10;

public class GLText {
    public static final int CHAR_BATCH_SIZE = 100;
    public static final int CHAR_CNT = 96;
    public static final int CHAR_END = 126;
    public static final int CHAR_NONE = 32;
    public static final int CHAR_START = 32;
    public static final int CHAR_UNKNOWN = 95;
    public static final int FONT_SIZE_MAX = 180;
    public static final int FONT_SIZE_MIN = 6;
    AssetManager assets;
    SpriteBatch batch;
    int cellHeight;
    int cellWidth;
    float charHeight;
    TextureRegion[] charRgn;
    float charWidthMax;
    final float[] charWidths;
    int colCnt;
    float fontAscent;
    float fontDescent;
    float fontHeight;
    int fontPadX;
    int fontPadY;
    GL10 gl;
    int rowCnt;
    float scaleX;
    float scaleY;
    float spaceX;
    int textureId;
    TextureRegion textureRgn;
    int textureSize;

    public GLText(GL10 gl10, AssetManager assetManager) {
        this.gl = gl10;
        this.assets = assetManager;
        this.batch = new SpriteBatch(gl10, CHAR_BATCH_SIZE);
        this.charWidths = new float[CHAR_CNT];
        this.charRgn = new TextureRegion[CHAR_CNT];
        this.fontPadX = 0;
        this.fontPadY = 0;
        this.fontHeight = 0.0f;
        this.fontAscent = 0.0f;
        this.fontDescent = 0.0f;
        this.textureId = -1;
        this.textureSize = 0;
        this.charWidthMax = 0.0f;
        this.charHeight = 0.0f;
        this.cellWidth = 0;
        this.cellHeight = 0;
        this.rowCnt = 0;
        this.colCnt = 0;
        this.scaleX = 1.0f;
        this.scaleY = 1.0f;
        this.spaceX = 0.0f;
    }

    public void begin() {
        begin(1.0f, 1.0f, 1.0f, 1.0f);
    }

    public void begin(float f) {
        begin(1.0f, 1.0f, 1.0f, f);
    }

    public void begin(float f, float f2, float f3, float f4) {
        this.gl.glColor4f(f, f2, f3, f4);
        this.gl.glBindTexture(3553, this.textureId);
        this.batch.beginBatch();
    }

    public void draw(String str, float f, float f2) {
        float f3 = ((float) this.cellHeight) * this.scaleY;
        float f4 = ((float) this.cellWidth) * this.scaleX;
        int length = str.length();
        float f5 = f + ((f4 / 2.0f) - (((float) this.fontPadX) * this.scaleX));
        float f6 = f2 + ((f3 / 2.0f) - (((float) this.fontPadY) * this.scaleY));
        for (int i = 0; i < length; i++) {
            int charAt = str.charAt(i) - 32;
            int i2 = (charAt < 0 || charAt >= CHAR_CNT) ? CHAR_UNKNOWN : charAt;
            this.batch.drawSprite(f5, f6, f4, f3, this.charRgn[i2]);
            f5 += (this.charWidths[i2] + this.spaceX) * this.scaleX;
        }
    }

    public float drawC(String str, float f, float f2) {
        float length = getLength(str);
        draw(str, f - (length / 2.0f), f2 - (getCharHeight() / 2.0f));
        return length;
    }

    public float drawCX(String str, float f, float f2) {
        float length = getLength(str);
        draw(str, f - (length / 2.0f), f2);
        return length;
    }

    public void drawCY(String str, float f, float f2) {
        draw(str, f, f2 - (getCharHeight() / 2.0f));
    }

    public void drawTexture(int i, int i2) {
        this.batch.beginBatch(this.textureId);
        this.batch.drawSprite((float) (this.textureSize / 2), (float) (i2 - (this.textureSize / 2)), (float) this.textureSize, (float) this.textureSize, this.textureRgn);
        this.batch.endBatch();
    }

    public void end() {
        this.batch.endBatch();
        this.gl.glColor4f(1.0f, 1.0f, 1.0f, 1.0f);
    }

    public float getAscent() {
        return this.fontAscent * this.scaleY;
    }

    public float getCharHeight() {
        return this.charHeight * this.scaleY;
    }

    public float getCharWidth(char c) {
        return this.charWidths[c - 32] * this.scaleX;
    }

    public float getCharWidthMax() {
        return this.charWidthMax * this.scaleX;
    }

    public float getDescent() {
        return this.fontDescent * this.scaleY;
    }

    public float getHeight() {
        return this.fontHeight * this.scaleY;
    }

    public float getLength(String str) {
        float f = 0.0f;
        int length = str.length();
        float f2 = 0.0f;
        for (int i = 0; i < length; i++) {
            f2 += this.charWidths[str.charAt(i) - 32] * this.scaleX;
        }
        if (length > 1) {
            f = (((float) (length - 1)) * this.spaceX) * this.scaleX;
        }
        return f + f2;
    }

    public float getScaleX() {
        return this.scaleX;
    }

    public float getScaleY() {
        return this.scaleY;
    }

    public float getSpace() {
        return this.spaceX;
    }

    public boolean load(String str, int i, int i2, int i3) {
        this.fontPadX = i2;
        this.fontPadY = i3;
        Typeface createFromAsset = Typeface.createFromAsset(this.assets, str);
        Paint paint = new Paint();
        paint.setAntiAlias(true);
        paint.setTextSize((float) i);
        paint.setColor(-1);
        paint.setTypeface(createFromAsset);
        FontMetrics fontMetrics = paint.getFontMetrics();
        this.fontHeight = (float) Math.ceil((double) (Math.abs(fontMetrics.bottom) + Math.abs(fontMetrics.top)));
        this.fontAscent = (float) Math.ceil((double) Math.abs(fontMetrics.ascent));
        this.fontDescent = (float) Math.ceil((double) Math.abs(fontMetrics.descent));
        char[] cArr = new char[2];
        this.charHeight = 0.0f;
        this.charWidthMax = 0.0f;
        float[] fArr = new float[2];
        int i4 = 0;
        for (char c = ' '; c <= '~'; c = (char) (c + 1)) {
            cArr[0] = c;
            paint.getTextWidths(cArr, 0, 1, fArr);
            this.charWidths[i4] = fArr[0];
            if (this.charWidths[i4] > this.charWidthMax) {
                this.charWidthMax = this.charWidths[i4];
            }
            i4++;
        }
        cArr[0] = ' ';
        paint.getTextWidths(cArr, 0, 1, fArr);
        this.charWidths[i4] = fArr[0];
        if (this.charWidths[i4] > this.charWidthMax) {
            this.charWidthMax = this.charWidths[i4];
        }
        int i5 = i4 + 1;
        this.charHeight = this.fontHeight;
        this.cellWidth = ((int) this.charWidthMax) + (this.fontPadX * 2);
        this.cellHeight = ((int) this.charHeight) + (this.fontPadY * 2);
        i5 = this.cellWidth > this.cellHeight ? this.cellWidth : this.cellHeight;
        if (i5 < FONT_SIZE_MIN || i5 > FONT_SIZE_MAX) {
            return false;
        }
        if (i5 <= 24) {
            this.textureSize = Policy.LICENSED;
        } else if (i5 <= 40) {
            this.textureSize = pbpFile.PBP_PSTITLEIMG;
        } else if (i5 <= 80) {
            this.textureSize = 1024;
        } else {
            this.textureSize = 2048;
        }
        Bitmap createBitmap = Bitmap.createBitmap(this.textureSize, this.textureSize, Config.ALPHA_8);
        Canvas canvas = new Canvas(createBitmap);
        createBitmap.eraseColor(0);
        this.colCnt = this.textureSize / this.cellWidth;
        this.rowCnt = (int) Math.ceil((double) (96.0f / ((float) this.colCnt)));
        float f = (float) this.fontPadX;
        float f2 = (((float) (this.cellHeight - 1)) - this.fontDescent) - ((float) this.fontPadY);
        char c2 = ' ';
        while (c2 <= '~') {
            cArr[0] = c2;
            canvas.drawText(cArr, 0, 1, f, f2, paint);
            float f3 = ((float) this.cellWidth) + f;
            if ((((float) this.cellWidth) + f3) - ((float) this.fontPadX) > ((float) this.textureSize)) {
                f3 = (float) this.fontPadX;
                f2 += (float) this.cellHeight;
            }
            c2 = (char) (c2 + 1);
            f = f3;
        }
        cArr[0] = ' ';
        canvas.drawText(cArr, 0, 1, f, f2, paint);
        int[] iArr = new int[1];
        this.gl.glGenTextures(1, iArr, 0);
        this.textureId = iArr[0];
        this.gl.glBindTexture(3553, this.textureId);
        this.gl.glTexParameterf(3553, 10241, 9728.0f);
        this.gl.glTexParameterf(3553, 10240, 9729.0f);
        this.gl.glTexParameterf(3553, 10242, 33071.0f);
        this.gl.glTexParameterf(3553, 10243, 33071.0f);
        GLUtils.texImage2D(3553, 0, createBitmap, 0);
        this.gl.glBindTexture(3553, 0);
        createBitmap.recycle();
        float f4 = 0.0f;
        f = 0.0f;
        int i6 = 0;
        while (i6 < CHAR_CNT) {
            this.charRgn[i6] = new TextureRegion((float) this.textureSize, (float) this.textureSize, f4, f, (float) (this.cellWidth - 1), (float) (this.cellHeight - 1));
            float f5 = ((float) this.cellWidth) + f4;
            if (((float) this.cellWidth) + f5 > ((float) this.textureSize)) {
                f5 = 0.0f;
                f += (float) this.cellHeight;
            }
            i6++;
            f4 = f5;
        }
        this.textureRgn = new TextureRegion((float) this.textureSize, (float) this.textureSize, 0.0f, 0.0f, (float) this.textureSize, (float) this.textureSize);
        return true;
    }

    public void setScale(float f) {
        this.scaleY = f;
        this.scaleX = f;
    }

    public void setScale(float f, float f2) {
        this.scaleX = f;
        this.scaleY = f2;
    }

    public void setSpace(float f) {
        this.spaceX = f;
    }
}
