package com.epsxe.ePSXe;

import java.nio.ByteBuffer;
import java.nio.ByteOrder;
import java.nio.IntBuffer;
import java.nio.ShortBuffer;
import javax.microedition.khronos.opengles.GL10;

public class Vertices {
    static final int COLOR_CNT = 4;
    static final int INDEX_SIZE = 2;
    static final int NORMAL_CNT = 3;
    static final int POSITION_CNT_2D = 2;
    static final int POSITION_CNT_3D = 3;
    static final int TEXCOORD_CNT = 2;
    final GL10 gl;
    final boolean hasColor;
    final boolean hasNormals;
    final boolean hasTexCoords;
    final ShortBuffer indices;
    public int numIndices;
    public int numVertices;
    public final int positionCnt;
    final int[] tmpBuffer;
    public final int vertexSize;
    public final int vertexStride;
    final IntBuffer vertices;

    public Vertices(GL10 gl10, int i, int i2, boolean z, boolean z2, boolean z3) {
        this(gl10, i, i2, z, z2, z3, false);
    }

    public Vertices(GL10 gl10, int i, int i2, boolean z, boolean z2, boolean z3, boolean z4) {
        int i3 = POSITION_CNT_3D;
        int i4 = TEXCOORD_CNT;
        this.gl = gl10;
        this.hasColor = z;
        this.hasTexCoords = z2;
        this.hasNormals = z3;
        this.positionCnt = z4 ? POSITION_CNT_3D : TEXCOORD_CNT;
        int i5 = (z ? COLOR_CNT : 0) + this.positionCnt;
        if (!z2) {
            i4 = 0;
        }
        i5 += i4;
        if (!z3) {
            i3 = 0;
        }
        this.vertexStride = i5 + i3;
        this.vertexSize = this.vertexStride * COLOR_CNT;
        ByteBuffer allocateDirect = ByteBuffer.allocateDirect(this.vertexSize * i);
        allocateDirect.order(ByteOrder.nativeOrder());
        this.vertices = allocateDirect.asIntBuffer();
        if (i2 > 0) {
            allocateDirect = ByteBuffer.allocateDirect(i2 * TEXCOORD_CNT);
            allocateDirect.order(ByteOrder.nativeOrder());
            this.indices = allocateDirect.asShortBuffer();
        } else {
            this.indices = null;
        }
        this.numVertices = 0;
        this.numIndices = 0;
        this.tmpBuffer = new int[((this.vertexSize * i) / COLOR_CNT)];
    }

    public void bind() {
        int i = 0;
        int i2 = COLOR_CNT;
        this.gl.glEnableClientState(32884);
        this.vertices.position(0);
        this.gl.glVertexPointer(this.positionCnt, 5126, this.vertexSize, this.vertices);
        if (this.hasColor) {
            this.gl.glEnableClientState(32886);
            this.vertices.position(this.positionCnt);
            this.gl.glColorPointer(COLOR_CNT, 5126, this.vertexSize, this.vertices);
        }
        if (this.hasTexCoords) {
            this.gl.glEnableClientState(32888);
            this.vertices.position((this.hasColor ? COLOR_CNT : 0) + this.positionCnt);
            this.gl.glTexCoordPointer(TEXCOORD_CNT, 5126, this.vertexSize, this.vertices);
        }
        if (this.hasNormals) {
            this.gl.glEnableClientState(32885);
            IntBuffer intBuffer = this.vertices;
            int i3 = this.positionCnt;
            if (!this.hasColor) {
                i2 = 0;
            }
            i2 += i3;
            if (this.hasTexCoords) {
                i = TEXCOORD_CNT;
            }
            intBuffer.position(i2 + i);
            this.gl.glNormalPointer(5126, this.vertexSize, this.vertices);
        }
    }

    public void draw(int i, int i2, int i3) {
        if (this.indices != null) {
            this.indices.position(i2);
            this.gl.glDrawElements(i, i3, 5123, this.indices);
            return;
        }
        this.gl.glDrawArrays(i, i2, i3);
    }

    public void drawFull(int i, int i2, int i3) {
        int i4 = 0;
        this.gl.glEnableClientState(32884);
        this.vertices.position(0);
        this.gl.glVertexPointer(this.positionCnt, 5126, this.vertexSize, this.vertices);
        if (this.hasColor) {
            this.gl.glEnableClientState(32886);
            this.vertices.position(this.positionCnt);
            this.gl.glColorPointer(COLOR_CNT, 5126, this.vertexSize, this.vertices);
        }
        if (this.hasTexCoords) {
            this.gl.glEnableClientState(32888);
            IntBuffer intBuffer = this.vertices;
            int i5 = this.positionCnt;
            if (this.hasColor) {
                i4 = COLOR_CNT;
            }
            intBuffer.position(i4 + i5);
            this.gl.glTexCoordPointer(TEXCOORD_CNT, 5126, this.vertexSize, this.vertices);
        }
        if (this.indices != null) {
            this.indices.position(i2);
            this.gl.glDrawElements(i, i3, 5123, this.indices);
        } else {
            this.gl.glDrawArrays(i, i2, i3);
        }
        if (this.hasTexCoords) {
            this.gl.glDisableClientState(32888);
        }
        if (this.hasColor) {
            this.gl.glDisableClientState(32886);
        }
    }

    public void setIndices(short[] sArr, int i, int i2) {
        this.indices.clear();
        this.indices.put(sArr, i, i2);
        this.indices.flip();
        this.numIndices = i2;
    }

    public void setVertices(float[] fArr, int i, int i2) {
        this.vertices.clear();
        int i3 = i + i2;
        int i4 = 0;
        while (i < i3) {
            this.tmpBuffer[i4] = Float.floatToRawIntBits(fArr[i]);
            i++;
            i4++;
        }
        this.vertices.put(this.tmpBuffer, 0, i2);
        this.vertices.flip();
        this.numVertices = i2 / this.vertexStride;
    }

    void setVtxColor(int i, float f) {
        this.vertices.put(((this.vertexStride * i) + this.positionCnt) + POSITION_CNT_3D, Float.floatToRawIntBits(f));
    }

    void setVtxColor(int i, float f, float f2, float f3) {
        int i2 = (this.vertexStride * i) + this.positionCnt;
        this.vertices.put(i2 + 0, Float.floatToRawIntBits(f));
        this.vertices.put(i2 + 1, Float.floatToRawIntBits(f2));
        this.vertices.put(i2 + TEXCOORD_CNT, Float.floatToRawIntBits(f3));
    }

    void setVtxColor(int i, float f, float f2, float f3, float f4) {
        int i2 = (this.vertexStride * i) + this.positionCnt;
        this.vertices.put(i2 + 0, Float.floatToRawIntBits(f));
        this.vertices.put(i2 + 1, Float.floatToRawIntBits(f2));
        this.vertices.put(i2 + TEXCOORD_CNT, Float.floatToRawIntBits(f3));
        this.vertices.put(i2 + POSITION_CNT_3D, Float.floatToRawIntBits(f4));
    }

    void setVtxNormal(int i, float f, float f2, float f3) {
        int i2 = 0;
        int i3 = (this.hasColor ? COLOR_CNT : 0) + (this.positionCnt + (this.vertexStride * i));
        if (this.hasTexCoords) {
            i2 = TEXCOORD_CNT;
        }
        i3 += i2;
        this.vertices.put(i3 + 0, Float.floatToRawIntBits(f));
        this.vertices.put(i3 + 1, Float.floatToRawIntBits(f2));
        this.vertices.put(i3 + TEXCOORD_CNT, Float.floatToRawIntBits(f3));
    }

    void setVtxPosition(int i, float f, float f2) {
        int i2 = this.vertexStride * i;
        this.vertices.put(i2 + 0, Float.floatToRawIntBits(f));
        this.vertices.put(i2 + 1, Float.floatToRawIntBits(f2));
    }

    void setVtxPosition(int i, float f, float f2, float f3) {
        int i2 = this.vertexStride * i;
        this.vertices.put(i2 + 0, Float.floatToRawIntBits(f));
        this.vertices.put(i2 + 1, Float.floatToRawIntBits(f2));
        this.vertices.put(i2 + TEXCOORD_CNT, Float.floatToRawIntBits(f3));
    }

    void setVtxTexCoords(int i, float f, float f2) {
        int i2 = (this.hasColor ? COLOR_CNT : 0) + (this.positionCnt + (this.vertexStride * i));
        this.vertices.put(i2 + 0, Float.floatToRawIntBits(f));
        this.vertices.put(i2 + 1, Float.floatToRawIntBits(f2));
    }

    public void unbind() {
        if (this.hasColor) {
            this.gl.glDisableClientState(32886);
        }
        if (this.hasTexCoords) {
            this.gl.glDisableClientState(32888);
        }
        if (this.hasNormals) {
            this.gl.glDisableClientState(32885);
        }
    }
}
