package com.epsxe.ePSXe;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Bitmap.CompressFormat;
import android.graphics.Bitmap.Config;
import android.graphics.BitmapFactory;
import android.graphics.BitmapFactory.Options;
import android.graphics.Matrix;
import android.opengl.GLES20;
import android.opengl.GLSurfaceView;
import android.opengl.GLSurfaceView.Renderer;
import android.opengl.GLUtils;
import android.os.Build.VERSION;
import android.os.Environment;
import android.util.Log;
import android.view.MotionEvent;
import android.view.SurfaceHolder;
import android.view.SurfaceView;
import android.widget.Toast;
import com.google.android.vending.licensing.Policy;
import java.io.File;
import java.io.FileOutputStream;
import java.io.OutputStream;
import java.lang.reflect.Array;
import java.nio.Buffer;
import java.nio.ByteBuffer;
import java.nio.ByteOrder;
import java.nio.FloatBuffer;
import java.nio.ShortBuffer;
import javax.microedition.khronos.egl.EGL10;
import javax.microedition.khronos.egl.EGLConfig;
import javax.microedition.khronos.egl.EGLContext;
import javax.microedition.khronos.egl.EGLDisplay;
import javax.microedition.khronos.egl.EGLSurface;
import javax.microedition.khronos.opengles.GL10;
import javax.microedition.khronos.opengles.GL11;

class ePSXeViewGL2 extends GLSurfaceView implements ePSXeView {
    public static final int ACTION_POINTER_INDEX_MASK = 65280;
    public static final int ACTION_POINTER_INDEX_SHIFT = 8;
    private static final int BUTTON_DOWN = 1;
    private static final int INPUT_HWBUTTONS = 1;
    private static final int INPUT_TOUCHSCREEN = 0;
    private static final int NO_BUTTON_DOWN = 0;
    private int[][] analog_values;
    private libepsxe f640e;
    private int emu_enable_framelimit;
    private int emu_enable_frameskip;
    private int emu_enable_frameskip_tmp;
    private int emu_enable_mme;
    private int emu_enable_printfps;
    private int emu_enable_tools;
    private int emu_opengl_options;
    private int[] emu_pad_draw_mode;
    private int[] emu_pad_mode;
    private int[] emu_pad_mode_analog;
    private int emu_pad_portrait;
    private int[] emu_pad_type;
    private int emu_pad_type_selected;
    private int emu_player_mode;
    private int emu_screen_orientation;
    private int emu_screen_ratio;
    private int emu_sound_latency;
    private int emu_split_mode;
    private int emu_video_filter;
    private int gpuVersion;
    private int gpuVersionAdvise;
    int gunX;
    int gunY;
    int gunb0;
    int gunb1;
    int gunb2;
    int initvirtualPad;
    private boolean license;
    private Context mContext;
    private EmuGLThread mGLThread;
    private int mHeight;
    private SurfaceHolder mHolder;
    private String mIsoName;
    private int mIsoSlot;
    private int mWidth;
    ePSXeReadPreferences mePSXeReadPreferences;
    private int mfps;
    private int mode;
    private int osVersion;
    float[][] padOffScreenLan;
    float[] padOffScreenLan2H;
    float[] padOffScreenLan2V;
    float[] padOffScreenPor;
    private float padResize;
    int[] padScreenExtra;
    int padScreenExtraCombo;
    int padScreenExtraEnabled;
    int[] padScreenFunc;
    float[][] padScreenResize;
    int[][] padScreenStatus;
    float[][] padSizeScreenLan;
    float[] padSizeScreenLan2H;
    float[] padSizeScreenLan2V;
    float[] padSizeScreenPor;
    private int screenshot;
    private String skinName;
    private int[] stickyButton;
    private int[] ts_vibration;
    int[][] virtualPad;
    int[] virtualPadBit;
    int[] virtualPadId;
    int[][] virtualPadPort;
    int[][] virtualPadPos;

    private class EmuGLThread extends Thread {
        SpriteBatch[] batchLan;
        SpriteBatch batchPor;
        SpriteBatch batchTools;
        boolean cscolor;
        boolean csnormal;
        boolean cstexture;
        boolean csvertex;
        int flimit;
        private FloatBuffer floatBuffer;
        private GLText glText;
        int[] hTexLan;
        int hTexPor;
        int hTexTools;
        int hTextmp;
        private int[] intVar;
        private boolean mDone;
        private EGL10 mEgl;
        private EGLConfig mEglConfig;
        private EGLContext mEglContext;
        private EGLDisplay mEglDisplay;
        private EGLSurface mEglSurface;
        private FloatBuffer mFVertexBuffer;
        private GL10 mGL;
        private ShortBuffer mIndexBuffer;
        private FloatBuffer mTexBuffer;
        int mTexExtra;
        int mTexLan;
        int mTexPor;
        int mTexTools;
        boolean mblend;
        boolean msci;
        boolean mtex2d;
        protected ShortBuffer shortBuffer;
        SurfaceView sv;
        TextureRegion[] textureRgnLan;
        TextureRegion textureRgnPor;
        TextureRegion textureRgnTools;
        int[] wTexLan;
        int wTexPor;
        int wTexTools;
        int wTextmp;

        EmuGLThread(SurfaceView surfaceView) {
            this.mDone = false;
            this.intVar = new int[16];
            this.floatBuffer = FloatBuffer.allocate(16);
            this.flimit = 0;
            this.mTexPor = -1;
            this.mTexLan = -1;
            this.mTexExtra = -1;
            this.batchLan = new SpriteBatch[28];
            this.textureRgnLan = new TextureRegion[28];
            this.hTexLan = new int[28];
            this.wTexLan = new int[28];
            this.mTexTools = -1;
            this.shortBuffer = null;
            this.sv = surfaceView;
        }

        private void checkEglError() {
            int eglGetError = this.mEgl.eglGetError();
            if (eglGetError != 12288) {
                Log.w("epsxe", "EGL error = 0x" + Integer.toHexString(eglGetError));
            }
        }

        private void checkGlError() {
            Log.w("epsxe", "GL error = 0x" + Integer.toHexString(-1));
        }

        private EGLConfig chooseEglConfig() {
            int[] iArr = new int[ePSXeViewGL2.INPUT_HWBUTTONS];
            EGLConfig[] eGLConfigArr = new EGLConfig[ePSXeViewGL2.INPUT_HWBUTTONS];
            if (!this.mEgl.eglChooseConfig(this.mEglDisplay, getConfig(), eGLConfigArr, ePSXeViewGL2.INPUT_HWBUTTONS, iArr)) {
                Log.e("epsxe", "eglChooseConfig failed " + this.mEgl.eglGetError());
            } else if (iArr[0] > 0) {
                return eGLConfigArr[0];
            }
            return null;
        }

        private int[] getConfig() {
            return new int[]{12324, 5, 12323, 6, 12322, 5, 12325, 16, 12344};
        }

        private int loadTexture(GL10 gl10, Context context, int i) {
            int newTextureID = newTextureID(gl10);
            Matrix matrix = new Matrix();
            matrix.setTranslate(1.0f, -1.0f);
            matrix.postScale(1.0f, 1.0f);
            Options options = new Options();
            options.inScaled = false;
            Bitmap decodeResource = BitmapFactory.decodeResource(context.getResources(), i, options);
            Bitmap createBitmap = Bitmap.createBitmap(decodeResource, 0, 0, decodeResource.getWidth(), decodeResource.getHeight(), matrix, true);
            decodeResource.recycle();
            gl10.glBindTexture(3553, newTextureID);
            gl10.glTexParameterf(3553, 10241, 9729.0f);
            gl10.glTexParameterf(3553, 10240, 9729.0f);
            gl10.glTexParameterf(3553, 10242, 10497.0f);
            gl10.glTexParameterf(3553, 10243, 10497.0f);
            this.wTextmp = createBitmap.getWidth();
            this.hTextmp = createBitmap.getHeight();
            GLUtils.texImage2D(3553, 0, createBitmap, 0);
            gl10.glBindTexture(3553, 0);
            createBitmap.recycle();
            return newTextureID;
        }

        private int loadTextureFromFile(GL10 gl10, Context context, String str) {
            int newTextureID = newTextureID(gl10);
            Matrix matrix = new Matrix();
            matrix.setTranslate(1.0f, -1.0f);
            matrix.postScale(1.0f, 1.0f);
            new Options().inScaled = false;
            Bitmap decodeFile = BitmapFactory.decodeFile(str);
            Bitmap createBitmap = Bitmap.createBitmap(decodeFile, 0, 0, decodeFile.getWidth(), decodeFile.getHeight(), matrix, true);
            decodeFile.recycle();
            gl10.glBindTexture(3553, newTextureID);
            gl10.glTexParameterf(3553, 10241, 9729.0f);
            gl10.glTexParameterf(3553, 10240, 9729.0f);
            gl10.glTexParameterf(3553, 10242, 10497.0f);
            gl10.glTexParameterf(3553, 10243, 10497.0f);
            this.wTextmp = createBitmap.getWidth();
            this.hTextmp = createBitmap.getHeight();
            GLUtils.texImage2D(3553, 0, createBitmap, 0);
            gl10.glBindTexture(3553, 0);
            createBitmap.recycle();
            return newTextureID;
        }

        private int newTextureID(GL10 gl10) {
            int[] iArr = new int[ePSXeViewGL2.INPUT_HWBUTTONS];
            gl10.glGenTextures(ePSXeViewGL2.INPUT_HWBUTTONS, iArr, 0);
            return iArr[0];
        }

        public void FlipGL() {
        }

        public void cleanupGL() {
            if (this.mEgl != null) {
                this.mEgl.eglDestroyContext(this.mEglDisplay, this.mEglContext);
                this.mEgl.eglDestroySurface(this.mEglDisplay, this.mEglSurface);
            }
        }

        public void doMiniPic(GL10 gl10) {
            int access$100 = ePSXeViewGL2.this.mWidth;
            int access$200 = ePSXeViewGL2.this.mHeight;
            if (ePSXeViewGL2.this.emu_screen_orientation == ePSXeViewGL2.INPUT_HWBUTTONS) {
                access$200 = ePSXeViewGL2.this.mHeight / 2;
            }
            int i = access$100 * access$200;
            Buffer allocateDirect = ByteBuffer.allocateDirect(i * 4);
            allocateDirect.order(ByteOrder.nativeOrder());
            if (ePSXeViewGL2.this.emu_screen_orientation == ePSXeViewGL2.INPUT_HWBUTTONS) {
                gl10.glReadPixels(0, access$200, access$100, access$200, 6408, 5121, allocateDirect);
            } else {
                gl10.glReadPixels(0, 0, access$100, access$200, 6408, 5121, allocateDirect);
            }
            int[] iArr = new int[i];
            allocateDirect.asIntBuffer().get(iArr);
            Bitmap createBitmap = Bitmap.createBitmap(access$100, access$200, Config.RGB_565);
            createBitmap.setPixels(iArr, i - access$100, -access$100, 0, 0, access$100, access$200);
            Bitmap createScaledBitmap = Bitmap.createScaledBitmap(createBitmap, InputList.KEYCODE_MEDIA_CLOSE, 96, false);
            short[] sArr = new short[12288];
            Buffer wrap = ShortBuffer.wrap(sArr);
            createScaledBitmap.copyPixelsToBuffer(wrap);
            for (int i2 = 0; i2 < 12288; i2 += ePSXeViewGL2.INPUT_HWBUTTONS) {
                short s = sArr[i2];
                sArr[i2] = (short) (((s & 63488) >> 11) | (((s & 31) << 11) | (s & 2016)));
            }
            wrap.rewind();
            createScaledBitmap.copyPixelsFromBuffer(wrap);
            saveImageRaw(sArr);
            ePSXeViewGL2.this.screenshot = 0;
        }

        public void drawFPS(GL10 gl10) {
            gl10.glDisable(3089);
            gl10.glEnable(3553);
            gl10.glEnable(3042);
            gl10.glBlendFunc(770, 771);
            this.glText.begin(1.0f, 1.0f, 0.0f, 1.0f);
            this.glText.draw(String.valueOf(ePSXeViewGL2.this.f640e.getFPS()) + "/" + ePSXeViewGL2.this.mfps, 0.0f, ((float) ePSXeViewGL2.this.mHeight) - this.glText.getCharHeight());
            this.glText.end();
            gl10.glDisable(3042);
            gl10.glDisable(3553);
        }

        public void drawGPUOutdated(GL10 gl10) {
            gl10.glDisable(3089);
            gl10.glEnable(3553);
            gl10.glEnable(3042);
            gl10.glBlendFunc(770, 771);
            this.glText.begin(1.0f, 1.0f, 1.0f, 1.0f);
            this.glText.draw("OpenGL Plugin outdated, get:", 60.0f, this.glText.getCharHeight());
            if (ePSXeViewGL2.this.f640e.isX86() == 0) {
                this.glText.draw("http://epsxe.com/files/libopenglplugin.so", 60.0f, 0.0f);
            } else {
                this.glText.draw("http://epsxe.com/files/libopenglplugin_intel.so)!!", 60.0f, 0.0f);
            }
            this.glText.end();
            gl10.glDisable(3042);
            gl10.glDisable(3553);
        }

        public void drawLicense(GL10 gl10) {
            gl10.glEnable(3553);
            gl10.glEnable(3042);
            gl10.glBlendFunc(770, 771);
            this.glText.begin(1.0f, 1.0f, 1.0f, 1.0f);
            this.glText.draw("License not validated yet. Read the documentation.", 60.0f, 0.0f);
            this.glText.end();
            gl10.glDisable(3042);
            gl10.glDisable(3553);
        }

        public void drawPad(GL10 gl10) {
            if (ePSXeViewGL2.this.emu_player_mode != ePSXeViewGL2.INPUT_HWBUTTONS || ePSXeViewGL2.this.emu_pad_draw_mode[0] == 2 || ePSXeViewGL2.this.emu_pad_mode[0] == 3) {
                if (ePSXeViewGL2.this.emu_pad_mode[0] == 3) {
                    gl10.glDisable(3089);
                    gl10.glEnable(3553);
                    gl10.glEnable(3042);
                    gl10.glBlendFunc(770, 771);
                    gl10.glColor4f(1.0f, 1.0f, 1.0f, 0.6f);
                    this.batchLan[0].beginBatch(this.mTexLan);
                    this.batchLan[0].drawSprite((float) ((ePSXeViewGL2.this.mWidth - ((ePSXeViewGL2.this.mHeight * 4) / 3)) / 4), (float) ((ePSXeViewGL2.this.mHeight / 4) * 3), (float) ((ePSXeViewGL2.this.mWidth - ((ePSXeViewGL2.this.mHeight * 4) / 3)) / 2), (float) (ePSXeViewGL2.this.mHeight / 2), this.textureRgnLan[0]);
                    this.batchLan[0].endBatch();
                    this.batchLan[ePSXeViewGL2.INPUT_HWBUTTONS].beginBatch(this.mTexLan);
                    this.batchLan[ePSXeViewGL2.INPUT_HWBUTTONS].drawSprite((float) ((ePSXeViewGL2.this.mWidth - ((ePSXeViewGL2.this.mHeight * 4) / 3)) / 4), (float) (ePSXeViewGL2.this.mHeight / 4), (float) ((ePSXeViewGL2.this.mWidth - ((ePSXeViewGL2.this.mHeight * 4) / 3)) / 2), (float) (ePSXeViewGL2.this.mHeight / 2), this.textureRgnLan[ePSXeViewGL2.INPUT_HWBUTTONS]);
                    this.batchLan[ePSXeViewGL2.INPUT_HWBUTTONS].endBatch();
                    gl10.glDisable(3042);
                    gl10.glDisable(3553);
                }
            } else if (ePSXeViewGL2.this.emu_screen_orientation == ePSXeViewGL2.INPUT_HWBUTTONS) {
                gl10.glDisable(3089);
                gl10.glEnable(3553);
                gl10.glEnable(3042);
                gl10.glBlendFunc(770, 771);
                gl10.glColor4f(1.0f, 1.0f, 1.0f, 0.6f);
                this.batchPor.beginBatch(this.mTexPor);
                this.batchPor.drawSprite(ePSXeViewGL2.this.padOffScreenPor[0], ePSXeViewGL2.this.padOffScreenPor[ePSXeViewGL2.INPUT_HWBUTTONS], ePSXeViewGL2.this.padSizeScreenPor[0], ePSXeViewGL2.this.padSizeScreenPor[ePSXeViewGL2.INPUT_HWBUTTONS], this.textureRgnPor);
                this.batchPor.endBatch();
                gl10.glDisable(3042);
                gl10.glDisable(3553);
            } else {
                gl10.glDisable(3089);
                gl10.glEnable(3553);
                gl10.glEnable(3042);
                gl10.glBlendFunc(770, 771);
                gl10.glColor4f(1.0f, 1.0f, 1.0f, 0.6f);
                int i = ePSXeViewGL2.this.emu_pad_mode[ePSXeViewGL2.this.emu_pad_type_selected] == 4 ? ePSXeViewGL2.this.emu_pad_mode_analog[ePSXeViewGL2.this.emu_pad_type_selected] == 0 ? 9 : 13 : ePSXeViewGL2.ACTION_POINTER_INDEX_SHIFT;
                int i2 = 0;
                while (i2 < i) {
                    if (ePSXeViewGL2.this.padScreenStatus[ePSXeViewGL2.this.mode][i2] == ePSXeViewGL2.INPUT_HWBUTTONS) {
                        this.batchLan[i2].beginBatch(this.mTexLan);
                        this.batchLan[i2].drawSprite(ePSXeViewGL2.this.padOffScreenLan[ePSXeViewGL2.this.mode][(i2 * 2) + 0], ePSXeViewGL2.this.padOffScreenLan[ePSXeViewGL2.this.mode][(i2 * 2) + ePSXeViewGL2.INPUT_HWBUTTONS], ePSXeViewGL2.this.padSizeScreenLan[ePSXeViewGL2.this.mode][(i2 * 2) + 0] * ePSXeViewGL2.this.padScreenResize[ePSXeViewGL2.this.mode][i2], ePSXeViewGL2.this.padSizeScreenLan[ePSXeViewGL2.this.mode][(i2 * 2) + ePSXeViewGL2.INPUT_HWBUTTONS] * ePSXeViewGL2.this.padScreenResize[ePSXeViewGL2.this.mode][i2], this.textureRgnLan[i2]);
                        this.batchLan[i2].endBatch();
                        if (i2 == 11 || i2 == 12) {
                            this.batchLan[i2].beginBatch(this.mTexLan);
                            this.batchLan[i2].drawSprite((float) ePSXeViewGL2.this.analog_values[0][(i2 - 11) * 2], (float) ePSXeViewGL2.this.analog_values[0][((i2 - 11) * 2) + ePSXeViewGL2.INPUT_HWBUTTONS], 2.0f * (ePSXeViewGL2.this.padSizeScreenLan[ePSXeViewGL2.this.mode][26] * ePSXeViewGL2.this.padScreenResize[ePSXeViewGL2.this.mode][i2]), 2.0f * (ePSXeViewGL2.this.padSizeScreenLan[ePSXeViewGL2.this.mode][27] * ePSXeViewGL2.this.padScreenResize[ePSXeViewGL2.this.mode][i2]), this.textureRgnLan[13]);
                            this.batchLan[i2].endBatch();
                        }
                    }
                    i2 += ePSXeViewGL2.INPUT_HWBUTTONS;
                }
                if (ePSXeViewGL2.this.padScreenExtraEnabled == ePSXeViewGL2.INPUT_HWBUTTONS) {
                    i = 14;
                    while (i < 20) {
                        if ((ePSXeViewGL2.this.padScreenStatus[ePSXeViewGL2.this.mode][i] & 2) != 2) {
                            if (ePSXeViewGL2.this.padScreenExtra[i - 14] < 20 || ePSXeViewGL2.this.stickyButton[ePSXeViewGL2.this.padScreenExtra[i - 14] - 20] != ePSXeViewGL2.INPUT_HWBUTTONS) {
                                this.batchLan[i].beginBatch(this.mTexExtra);
                                this.batchLan[i].drawSprite(ePSXeViewGL2.this.padOffScreenLan[ePSXeViewGL2.this.mode][(i * 2) + 0], ePSXeViewGL2.this.padOffScreenLan[ePSXeViewGL2.this.mode][(i * 2) + ePSXeViewGL2.INPUT_HWBUTTONS], ePSXeViewGL2.this.padSizeScreenLan[ePSXeViewGL2.this.mode][(i * 2) + 0] * ePSXeViewGL2.this.padScreenResize[ePSXeViewGL2.this.mode][i], ePSXeViewGL2.this.padSizeScreenLan[ePSXeViewGL2.this.mode][(i * 2) + ePSXeViewGL2.INPUT_HWBUTTONS] * ePSXeViewGL2.this.padScreenResize[ePSXeViewGL2.this.mode][i], this.textureRgnLan[i]);
                                this.batchLan[i].endBatch();
                            } else {
                                int i3 = ePSXeViewGL2.this.padScreenExtra[i - 14];
                                this.batchLan[i].beginBatch(this.mTexExtra);
                                this.batchLan[i].drawSprite(ePSXeViewGL2.this.padOffScreenLan[ePSXeViewGL2.this.mode][(i * 2) + 0], ePSXeViewGL2.this.padOffScreenLan[ePSXeViewGL2.this.mode][(i * 2) + ePSXeViewGL2.INPUT_HWBUTTONS], ePSXeViewGL2.this.padSizeScreenLan[ePSXeViewGL2.this.mode][(i * 2) + 0] * ePSXeViewGL2.this.padScreenResize[ePSXeViewGL2.this.mode][i], ePSXeViewGL2.this.padSizeScreenLan[ePSXeViewGL2.this.mode][(i * 2) + ePSXeViewGL2.INPUT_HWBUTTONS] * ePSXeViewGL2.this.padScreenResize[ePSXeViewGL2.this.mode][i], this.textureRgnLan[i3]);
                                this.batchLan[i].endBatch();
                            }
                        }
                        i += ePSXeViewGL2.INPUT_HWBUTTONS;
                    }
                }
                gl10.glDisable(3042);
                gl10.glDisable(3553);
            }
        }

        public void drawSelected(GL10 gl10, int i, int i2) {
            if (i2 == ePSXeViewGL2.INPUT_HWBUTTONS) {
                gl10.glColor4f(0.0f, 1.0f, 1.0f, 1.0f);
            }
            if (i2 == 2) {
                gl10.glColor4f(1.0f, 0.0f, 1.0f, 1.0f);
            }
            if (i2 == 3) {
                gl10.glColor4f(1.0f, 1.0f, 0.0f, 1.0f);
            }
            if (i2 == 4) {
                gl10.glColor4f(1.0f, 0.0f, 0.0f, 1.0f);
            }
            if (i2 == 5) {
                gl10.glColor4f(0.0f, 1.0f, 0.0f, 1.0f);
            }
            if (i2 == 6) {
                gl10.glColor4f(0.0f, 0.0f, 1.0f, 1.0f);
            }
            ByteBuffer allocateDirect = ByteBuffer.allocateDirect(48);
            allocateDirect.order(ByteOrder.nativeOrder());
            this.mFVertexBuffer = allocateDirect.asFloatBuffer();
            allocateDirect = ByteBuffer.allocateDirect(ePSXeViewGL2.ACTION_POINTER_INDEX_SHIFT);
            allocateDirect.order(ByteOrder.nativeOrder());
            this.mIndexBuffer = allocateDirect.asShortBuffer();
            float access$100 = ((((float) ePSXeViewGL2.this.mWidth) - (508.0f * ePSXeViewGL2.this.padResize)) / 2.0f) + (((508.0f * ePSXeViewGL2.this.padResize) / 9.0f) * ((float) i));
            float access$200 = ((float) ePSXeViewGL2.this.mHeight) - (60.0f * ePSXeViewGL2.this.padResize);
            float access$1400 = (508.0f * ePSXeViewGL2.this.padResize) / 9.0f;
            float access$14002 = 60.0f * ePSXeViewGL2.this.padResize;
            float[] fArr = new float[]{1.0f + access$100, 1.0f + access$200, 0.0f, (access$100 + access$1400) - 1.0f, (float) ((int) (1.0f + access$200)), 0.0f, (access$1400 + access$100) - 1.0f, (access$200 + access$14002) - 1.0f, 0.0f, access$100 + 1.0f, (float) ((int) ((access$200 + access$14002) - 1.0f)), 0.0f};
            for (int i3 = 0; i3 < 4; i3 += ePSXeViewGL2.INPUT_HWBUTTONS) {
                int i4;
                for (i4 = 0; i4 < 3; i4 += ePSXeViewGL2.INPUT_HWBUTTONS) {
                    this.mFVertexBuffer.put(fArr[(i3 * 3) + i4]);
                }
            }
            for (i4 = 0; i4 < 4; i4 += ePSXeViewGL2.INPUT_HWBUTTONS) {
                this.mIndexBuffer.put((short) i4);
            }
            this.mFVertexBuffer.position(0);
            this.mIndexBuffer.position(0);
            gl10.glDisable(3553);
            gl10.glEnableClientState(32884);
            gl10.glVertexPointer(3, 5126, 0, this.mFVertexBuffer);
            gl10.glDrawElements(2, 4, 5123, this.mIndexBuffer);
            gl10.glDisableClientState(32884);
            gl10.glEnable(3553);
            gl10.glColor4f(1.0f, 1.0f, 1.0f, 1.0f);
        }

        public void drawSelectedTools(GL10 gl10) {
            int access$1500 = ePSXeViewGL2.this.emu_opengl_options;
            if ((access$1500 & 7) != 0) {
                drawSelected(gl10, ePSXeViewGL2.INPUT_HWBUTTONS, ePSXeViewGL2.INPUT_HWBUTTONS);
            }
            if ((access$1500 & 56) != 0) {
                drawSelected(gl10, 2, (access$1500 >> 3) & 7);
            }
            if ((access$1500 & 448) != 0) {
                drawSelected(gl10, 5, ePSXeViewGL2.INPUT_HWBUTTONS);
            }
            if ((32768 & access$1500) != 0) {
                drawSelected(gl10, 4, ePSXeViewGL2.INPUT_HWBUTTONS);
            }
            if ((access$1500 & 16384) != 0) {
                drawSelected(gl10, 3, ePSXeViewGL2.INPUT_HWBUTTONS);
            }
            if ((access$1500 & 8192) != 0) {
                drawSelected(gl10, 6, ePSXeViewGL2.INPUT_HWBUTTONS);
            }
            if ((access$1500 & 4096) != 0) {
                drawSelected(gl10, 0, ePSXeViewGL2.INPUT_HWBUTTONS);
            }
        }

        public void drawTools(GL10 gl10) {
            gl10.glDisable(3089);
            gl10.glEnable(3553);
            gl10.glEnable(3042);
            gl10.glBlendFunc(770, 771);
            gl10.glColor4f(1.0f, 1.0f, 1.0f, 0.6f);
            this.batchTools.beginBatch(this.mTexTools);
            this.batchTools.drawSprite((float) (ePSXeViewGL2.this.mWidth / 2), ((float) ePSXeViewGL2.this.mHeight) - ((ePSXeViewGL2.this.padResize * 60.0f) / 2.0f), 508.0f * ePSXeViewGL2.this.padResize, ePSXeViewGL2.this.padResize * 60.0f, this.textureRgnTools);
            this.batchTools.endBatch();
            gl10.glDisable(3042);
            gl10.glDisable(3553);
        }

        public void initEGL2() {
        }

        public void initGL() {
        }

        public void requestStop() {
            this.mDone = true;
        }

        public void restoreGLState(GL10 gl10) {
            if (this.mblend) {
                gl10.glEnable(3042);
            } else {
                gl10.glDisable(3042);
            }
            if (this.mtex2d) {
                gl10.glEnable(3553);
            } else {
                gl10.glDisable(3553);
            }
            if (this.msci) {
                gl10.glEnable(3089);
            } else {
                gl10.glDisable(3089);
            }
            if (this.csvertex) {
                gl10.glEnableClientState(32884);
            } else {
                gl10.glDisableClientState(32884);
            }
            if (this.cscolor) {
                gl10.glEnableClientState(32886);
            } else {
                gl10.glDisableClientState(32886);
            }
            if (this.cstexture) {
                gl10.glEnableClientState(32888);
            } else {
                gl10.glDisableClientState(32888);
            }
            if (this.csnormal) {
                gl10.glEnableClientState(32885);
            } else {
                gl10.glDisableClientState(32885);
            }
            gl10.glBindTexture(3553, this.intVar[0]);
            gl10.glBlendFunc(this.intVar[ePSXeViewGL2.INPUT_HWBUTTONS], this.intVar[2]);
            ((GL11) gl10).glTexParameteri(3553, 10241, this.intVar[3]);
            ((GL11) gl10).glTexParameteri(3553, 10240, this.intVar[4]);
            ((GL11) gl10).glTexParameteri(3553, 10242, this.intVar[5]);
            ((GL11) gl10).glTexParameteri(3553, 10243, this.intVar[6]);
            gl10.glColor4f(this.floatBuffer.get(0), this.floatBuffer.get(ePSXeViewGL2.INPUT_HWBUTTONS), this.floatBuffer.get(2), this.floatBuffer.get(3));
            gl10.glPopMatrix();
        }

        public void run() {
            initEGL2();
            initGL();
            ePSXeViewGL2.this.f640e.setwh(ePSXeViewGL2.this.mWidth, ePSXeViewGL2.this.mHeight, ePSXeViewGL2.this.emu_screen_ratio);
            ePSXeViewGL2.this.mfps = ePSXeViewGL2.this.f640e.loadepsxe(ePSXeViewGL2.this.mIsoName, ePSXeViewGL2.this.mIsoSlot);
            if (ePSXeViewGL2.this.mIsoName.equals("___RUNBIOS___")) {
                ePSXeViewGL2.this.mfps = 60;
            } else if (ePSXeViewGL2.this.mfps == -1) {
                Toast.makeText(ePSXeViewGL2.this.mContext, "Error loading game (.bin/.mdf/.img not found)!!!!", ePSXeViewGL2.INPUT_HWBUTTONS).show();
                ePSXeViewGL2.this.mfps = 60;
            } else if (ePSXeViewGL2.this.mfps > 60) {
                Toast.makeText(ePSXeViewGL2.this.mContext, "SYSTEM.CNF not found, incompatible format/bad rom\nMaybe this rom will not work!!!!", ePSXeViewGL2.INPUT_HWBUTTONS).show();
                ePSXeViewGL2.this.mfps = ePSXeViewGL2.this.mfps - 100;
            }
            ePSXeViewGL2.this.gpuVersion = ePSXeViewGL2.this.f640e.getGPUVersion();
            while (!this.mDone) {
                ePSXeViewGL2.this.f640e.runemulatorframeGLext();
                GLES20.glClear(16384);
            }
            cleanupGL();
        }

        public void saveGLState(GL10 gl10) {
            this.csvertex = ((GL11) gl10).glIsEnabled(32884);
            this.cscolor = ((GL11) gl10).glIsEnabled(32886);
            this.cstexture = ((GL11) gl10).glIsEnabled(32888);
            this.csnormal = ((GL11) gl10).glIsEnabled(32885);
            this.mtex2d = ((GL11) gl10).glIsEnabled(3553);
            this.mblend = ((GL11) gl10).glIsEnabled(3042);
            this.msci = ((GL11) gl10).glIsEnabled(3089);
            this.floatBuffer.rewind();
            gl10.glGetIntegerv(32873, this.intVar, 0);
            gl10.glGetIntegerv(3041, this.intVar, ePSXeViewGL2.INPUT_HWBUTTONS);
            gl10.glGetIntegerv(3040, this.intVar, 2);
            ((GL11) gl10).glGetTexParameteriv(3553, 10241, this.intVar, 3);
            ((GL11) gl10).glGetTexParameteriv(3553, 10240, this.intVar, 4);
            ((GL11) gl10).glGetTexParameteriv(3553, 10242, this.intVar, 5);
            ((GL11) gl10).glGetTexParameteriv(3553, 10243, this.intVar, 6);
            ((GL11) gl10).glGetFloatv(2816, this.floatBuffer);
            gl10.glPushMatrix();
            gl10.glViewport(0, 0, ePSXeViewGL2.this.mWidth, ePSXeViewGL2.this.mHeight);
            gl10.glMatrixMode(5889);
            gl10.glLoadIdentity();
            gl10.glOrthof(0.0f, (float) ePSXeViewGL2.this.mWidth, 0.0f, (float) ePSXeViewGL2.this.mHeight, 1.0f, -1.0f);
            gl10.glDisableClientState(32886);
        }

        void saveImage(Bitmap bitmap) {
            File file = new File(new File(Environment.getExternalStorageDirectory().toString() + "/epsxe/sstates/"), "ImageXX.jpg");
            if (file.exists()) {
                file.delete();
            }
            try {
                OutputStream fileOutputStream = new FileOutputStream(file);
                bitmap.compress(CompressFormat.JPEG, 90, fileOutputStream);
                fileOutputStream.flush();
                fileOutputStream.close();
            } catch (Exception e) {
                e.printStackTrace();
            }
        }

        void saveImageRaw(short[] sArr) {
            File file = new File(new File(Environment.getExternalStorageDirectory().toString() + "/epsxe/sstates/"), ePSXeViewGL2.this.f640e.getCode() + ".00" + (ePSXeViewGL2.this.screenshot - 10) + ".pic");
            byte[] bArr = new byte[36864];
            for (int i = 0; i < 12288; i += ePSXeViewGL2.INPUT_HWBUTTONS) {
                bArr[(i * 3) + 2] = (byte) ((sArr[i] << 3) & 248);
                bArr[(i * 3) + ePSXeViewGL2.INPUT_HWBUTTONS] = (byte) ((sArr[i] >> 3) & 252);
                bArr[(i * 3) + 0] = (byte) ((sArr[i] >> ePSXeViewGL2.ACTION_POINTER_INDEX_SHIFT) & 248);
            }
            if (file.exists()) {
                file.delete();
            }
            try {
                FileOutputStream fileOutputStream = new FileOutputStream(file);
                fileOutputStream.write(bArr);
                fileOutputStream.flush();
                fileOutputStream.close();
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    private class ePSXeRendererGL2 implements Renderer {
        private ePSXeRendererGL2() {
        }

        public void onDrawFrame(GL10 gl10) {
        }

        public void onSurfaceChanged(GL10 gl10, int i, int i2) {
        }

        public void onSurfaceCreated(GL10 gl10, EGLConfig eGLConfig) {
        }
    }

    public ePSXeViewGL2(Context context) {
        super(context);
        this.mfps = 60;
        this.ts_vibration = new int[]{0, 0};
        this.emu_enable_frameskip = 0;
        this.emu_enable_frameskip_tmp = 0;
        this.emu_enable_printfps = INPUT_HWBUTTONS;
        this.emu_player_mode = INPUT_HWBUTTONS;
        this.emu_split_mode = 0;
        this.emu_enable_mme = INPUT_HWBUTTONS;
        this.emu_screen_orientation = 0;
        this.emu_screen_ratio = 0;
        this.emu_pad_portrait = 0;
        this.emu_pad_draw_mode = new int[]{INPUT_HWBUTTONS, INPUT_HWBUTTONS};
        this.emu_pad_mode = new int[]{INPUT_HWBUTTONS, INPUT_HWBUTTONS};
        this.emu_pad_mode_analog = new int[]{0, 0};
        this.mode = 0;
        this.emu_enable_framelimit = INPUT_HWBUTTONS;
        this.emu_pad_type = new int[]{0, 0};
        this.emu_pad_type_selected = 0;
        this.emu_video_filter = 0;
        this.emu_sound_latency = 0;
        this.emu_enable_tools = 0;
        this.emu_opengl_options = 0;
        this.license = true;
        this.analog_values = new int[][]{new int[]{0, 0, 0, 0}, new int[]{0, 0, 0, 0}};
        this.mIsoSlot = 0;
        this.screenshot = 0;
        this.gpuVersion = 0;
        this.gpuVersionAdvise = InputList.KEYCODE_NUMPAD_6;
        this.skinName = "/sdcard/skin.png";
        this.stickyButton = new int[]{0, 0, 0, 0, 0, 0, 0, 0};
        this.mWidth = 800;
        this.mHeight = 480;
        this.padResize = 1.0f;
        this.padSizeScreenLan = new float[][]{new float[]{228.0f, 228.0f, 224.0f, 248.0f, 66.0f, 50.0f, 66.0f, 62.0f, 64.0f, 60.0f, 64.0f, 60.0f, 64.0f, 60.0f, 64.0f, 60.0f, 53.0f, 41.0f, 64.0f, 60.0f, 64.0f, 60.0f, 222.0f, 222.0f, 222.0f, 222.0f, 71.0f, 71.0f, 64.0f, 64.0f, 64.0f, 64.0f, 64.0f, 64.0f, 64.0f, 64.0f, 64.0f, 64.0f, 64.0f, 64.0f}, new float[]{228.0f, 228.0f, 224.0f, 248.0f, 66.0f, 50.0f, 66.0f, 62.0f, 64.0f, 60.0f, 64.0f, 60.0f, 64.0f, 60.0f, 64.0f, 60.0f, 53.0f, 41.0f, 64.0f, 60.0f, 64.0f, 60.0f, 222.0f, 222.0f, 222.0f, 222.0f, 71.0f, 71.0f, 64.0f, 64.0f, 64.0f, 64.0f, 64.0f, 64.0f, 64.0f, 64.0f, 64.0f, 64.0f, 64.0f, 64.0f}};
        r0 = new float[2][];
        r0[0] = new float[]{this.padSizeScreenLan[0][0] / 2.0f, this.padSizeScreenLan[0][INPUT_HWBUTTONS] / 2.0f, 800.0f - (this.padSizeScreenLan[0][2] / 2.0f), this.padSizeScreenLan[0][3] / 2.0f, (400.0f - this.padSizeScreenLan[0][4]) - 30.0f, this.padSizeScreenLan[0][5] / 2.0f, 430.0f, this.padSizeScreenLan[0][7] / 2.0f, this.padSizeScreenLan[0][ACTION_POINTER_INDEX_SHIFT] / 2.0f, 480.0f - (this.padSizeScreenLan[0][9] / 2.0f), (this.padSizeScreenLan[0][10] / 2.0f) + this.padSizeScreenLan[0][ACTION_POINTER_INDEX_SHIFT], 480.0f - (this.padSizeScreenLan[0][11] / 2.0f), 800.0f - (this.padSizeScreenLan[0][12] / 2.0f), 480.0f - (this.padSizeScreenLan[0][13] / 2.0f), (800.0f - (this.padSizeScreenLan[0][14] / 2.0f)) - this.padSizeScreenLan[0][12], 480.0f - (this.padSizeScreenLan[0][15] / 2.0f), 440.0f + this.padSizeScreenLan[0][6], this.padSizeScreenLan[0][17] / 2.0f, ((this.padSizeScreenLan[0][18] / 2.0f) + this.padSizeScreenLan[0][10]) + this.padSizeScreenLan[0][ACTION_POINTER_INDEX_SHIFT], 480.0f - (this.padSizeScreenLan[0][19] / 2.0f), ((800.0f - (this.padSizeScreenLan[0][20] / 2.0f)) - this.padSizeScreenLan[0][12]) - this.padSizeScreenLan[0][14], 480.0f - (this.padSizeScreenLan[0][21] / 2.0f), this.padSizeScreenLan[0][22] / 2.0f, this.padSizeScreenLan[0][23] / 2.0f, 800.0f - (this.padSizeScreenLan[0][24] / 2.0f), this.padSizeScreenLan[0][25] / 2.0f, 0.0f, 0.0f, this.padSizeScreenLan[0][28] / 2.0f, (480.0f - (this.padSizeScreenLan[0][29] / 2.0f)) - (this.padSizeScreenLan[0][10] * 2.0f), (this.padSizeScreenLan[0][30] / 2.0f) + this.padSizeScreenLan[0][28], (480.0f - (this.padSizeScreenLan[0][31] / 2.0f)) - (this.padSizeScreenLan[0][10] * 2.0f), ((this.padSizeScreenLan[0][32] / 2.0f) + this.padSizeScreenLan[0][28]) + this.padSizeScreenLan[0][30], (480.0f - (this.padSizeScreenLan[0][33] / 2.0f)) - (this.padSizeScreenLan[0][10] * 2.0f), 800.0f - (this.padSizeScreenLan[0][34] / 2.0f), (480.0f - (this.padSizeScreenLan[0][35] / 2.0f)) - (this.padSizeScreenLan[0][10] * 2.0f), (800.0f - (this.padSizeScreenLan[0][36] / 2.0f)) - this.padSizeScreenLan[0][34], (480.0f - (this.padSizeScreenLan[0][37] / 2.0f)) - (this.padSizeScreenLan[0][10] * 2.0f), ((800.0f - (this.padSizeScreenLan[0][38] / 2.0f)) - this.padSizeScreenLan[0][34]) - this.padSizeScreenLan[0][36], (480.0f - (this.padSizeScreenLan[0][39] / 2.0f)) - (this.padSizeScreenLan[0][10] * 2.0f)};
        r0[INPUT_HWBUTTONS] = new float[]{400.0f - (0.76f * (this.padSizeScreenLan[INPUT_HWBUTTONS][0] / 2.0f)), 240.0f, 800.0f - (this.padSizeScreenLan[INPUT_HWBUTTONS][2] / 2.0f), this.padSizeScreenLan[INPUT_HWBUTTONS][3] / 2.0f, (400.0f - this.padSizeScreenLan[INPUT_HWBUTTONS][4]) - 30.0f, this.padSizeScreenLan[INPUT_HWBUTTONS][5] / 2.0f, 430.0f, this.padSizeScreenLan[INPUT_HWBUTTONS][7] / 2.0f, this.padSizeScreenLan[INPUT_HWBUTTONS][ACTION_POINTER_INDEX_SHIFT] / 2.0f, 480.0f - (this.padSizeScreenLan[INPUT_HWBUTTONS][9] / 2.0f), (this.padSizeScreenLan[INPUT_HWBUTTONS][10] / 2.0f) + this.padSizeScreenLan[INPUT_HWBUTTONS][ACTION_POINTER_INDEX_SHIFT], 480.0f - (this.padSizeScreenLan[INPUT_HWBUTTONS][11] / 2.0f), 800.0f - (this.padSizeScreenLan[INPUT_HWBUTTONS][12] / 2.0f), 480.0f - (this.padSizeScreenLan[INPUT_HWBUTTONS][13] / 2.0f), (800.0f - (this.padSizeScreenLan[INPUT_HWBUTTONS][14] / 2.0f)) - this.padSizeScreenLan[INPUT_HWBUTTONS][12], 480.0f - (this.padSizeScreenLan[INPUT_HWBUTTONS][15] / 2.0f), 440.0f + this.padSizeScreenLan[INPUT_HWBUTTONS][6], this.padSizeScreenLan[INPUT_HWBUTTONS][17] / 2.0f, ((this.padSizeScreenLan[INPUT_HWBUTTONS][18] / 2.0f) + this.padSizeScreenLan[INPUT_HWBUTTONS][10]) + this.padSizeScreenLan[INPUT_HWBUTTONS][ACTION_POINTER_INDEX_SHIFT], 480.0f - (this.padSizeScreenLan[INPUT_HWBUTTONS][19] / 2.0f), ((800.0f - (this.padSizeScreenLan[INPUT_HWBUTTONS][20] / 2.0f)) - this.padSizeScreenLan[INPUT_HWBUTTONS][12]) - this.padSizeScreenLan[INPUT_HWBUTTONS][14], 480.0f - (this.padSizeScreenLan[INPUT_HWBUTTONS][21] / 2.0f), this.padSizeScreenLan[INPUT_HWBUTTONS][22] / 2.0f, this.padSizeScreenLan[INPUT_HWBUTTONS][23] / 2.0f, 400.0f + (0.76f * (this.padSizeScreenLan[INPUT_HWBUTTONS][24] / 2.0f)), 240.0f, 0.0f, 0.0f, this.padSizeScreenLan[INPUT_HWBUTTONS][28] / 2.0f, (480.0f - (this.padSizeScreenLan[INPUT_HWBUTTONS][29] / 2.0f)) - (this.padSizeScreenLan[INPUT_HWBUTTONS][10] * 2.0f), (this.padSizeScreenLan[INPUT_HWBUTTONS][30] / 2.0f) + this.padSizeScreenLan[INPUT_HWBUTTONS][28], (480.0f - (this.padSizeScreenLan[INPUT_HWBUTTONS][31] / 2.0f)) - (this.padSizeScreenLan[INPUT_HWBUTTONS][10] * 2.0f), ((this.padSizeScreenLan[INPUT_HWBUTTONS][32] / 2.0f) + this.padSizeScreenLan[INPUT_HWBUTTONS][28]) + this.padSizeScreenLan[INPUT_HWBUTTONS][30], (480.0f - (this.padSizeScreenLan[INPUT_HWBUTTONS][33] / 2.0f)) - (this.padSizeScreenLan[INPUT_HWBUTTONS][10] * 2.0f), 800.0f - (this.padSizeScreenLan[INPUT_HWBUTTONS][34] / 2.0f), (480.0f - (this.padSizeScreenLan[INPUT_HWBUTTONS][35] / 2.0f)) - (this.padSizeScreenLan[INPUT_HWBUTTONS][10] * 2.0f), (800.0f - (this.padSizeScreenLan[INPUT_HWBUTTONS][36] / 2.0f)) - this.padSizeScreenLan[INPUT_HWBUTTONS][34], (480.0f - (this.padSizeScreenLan[INPUT_HWBUTTONS][37] / 2.0f)) - (this.padSizeScreenLan[INPUT_HWBUTTONS][10] * 2.0f), ((800.0f - (this.padSizeScreenLan[INPUT_HWBUTTONS][38] / 2.0f)) - this.padSizeScreenLan[INPUT_HWBUTTONS][34]) - this.padSizeScreenLan[INPUT_HWBUTTONS][36], (480.0f - (this.padSizeScreenLan[INPUT_HWBUTTONS][39] / 2.0f)) - (this.padSizeScreenLan[INPUT_HWBUTTONS][10] * 2.0f)};
        this.padOffScreenLan = r0;
        this.padScreenStatus = new int[][]{new int[]{INPUT_HWBUTTONS, INPUT_HWBUTTONS, INPUT_HWBUTTONS, INPUT_HWBUTTONS, INPUT_HWBUTTONS, INPUT_HWBUTTONS, INPUT_HWBUTTONS, INPUT_HWBUTTONS, INPUT_HWBUTTONS, 2, 2, 2, 2, 0, 0, 0, 0, 0, 0, 0}, new int[]{0, INPUT_HWBUTTONS, INPUT_HWBUTTONS, INPUT_HWBUTTONS, INPUT_HWBUTTONS, INPUT_HWBUTTONS, INPUT_HWBUTTONS, INPUT_HWBUTTONS, INPUT_HWBUTTONS, 0, 0, INPUT_HWBUTTONS, 0, 0, 0, 0, 0, 0, 0, 0}};
        this.padScreenResize = new float[][]{new float[]{1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f}, new float[]{0.76f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 0.76f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f}};
        this.padScreenExtra = new int[]{19, 19, 19, 19, 19, 19};
        this.padScreenFunc = new int[]{0, 0, 0, 0, 0, 0};
        this.padScreenExtraEnabled = 0;
        this.padScreenExtraCombo = 0;
        this.padSizeScreenPor = new float[]{480.0f, 400.0f};
        this.padOffScreenPor = new float[]{240.0f, 200.0f};
        this.padSizeScreenLan2H = new float[]{228.0f, 114.0f, 224.0f, 124.0f, 66.0f, 25.0f, 66.0f, 31.0f, 64.0f, 30.0f, 64.0f, 30.0f, 64.0f, 30.0f, 64.0f, 30.0f};
        this.padOffScreenLan2H = new float[]{this.padSizeScreenLan2H[0] / 2.0f, this.padSizeScreenLan2H[INPUT_HWBUTTONS] / 2.0f, 800.0f - (this.padSizeScreenLan2H[2] / 2.0f), this.padSizeScreenLan2H[3] / 2.0f, (400.0f - this.padSizeScreenLan2H[4]) - 30.0f, this.padSizeScreenLan2H[5] / 2.0f, 430.0f, this.padSizeScreenLan2H[7] / 2.0f, this.padSizeScreenLan2H[ACTION_POINTER_INDEX_SHIFT] / 2.0f, 240.0f - (this.padSizeScreenLan2H[9] / 2.0f), (this.padSizeScreenLan2H[10] / 2.0f) + this.padSizeScreenLan2H[ACTION_POINTER_INDEX_SHIFT], 240.0f - (this.padSizeScreenLan2H[11] / 2.0f), 800.0f - (this.padSizeScreenLan2H[12] / 2.0f), 240.0f - (this.padSizeScreenLan2H[13] / 2.0f), (800.0f - (this.padSizeScreenLan2H[14] / 2.0f)) - this.padSizeScreenLan2H[12], 240.0f - (this.padSizeScreenLan2H[15] / 2.0f)};
        this.padSizeScreenLan2V = new float[]{136.0f, 190.0f, 134.0f, 206.0f, 39.0f, 33.0f, 39.0f, 51.0f, 38.0f, 50.0f, 38.0f, 50.0f, 38.0f, 50.0f, 38.0f, 50.0f};
        this.padOffScreenLan2V = new float[]{this.padSizeScreenLan2V[0] / 2.0f, this.padSizeScreenLan2V[INPUT_HWBUTTONS] / 2.0f, 480.0f - (this.padSizeScreenLan2V[2] / 2.0f), this.padSizeScreenLan2V[3] / 2.0f, (240.0f - this.padSizeScreenLan2V[4]) - 30.0f, this.padSizeScreenLan2V[5] / 2.0f, 270.0f, this.padSizeScreenLan2V[7] / 2.0f, this.padSizeScreenLan2V[ACTION_POINTER_INDEX_SHIFT] / 2.0f, 400.0f - (this.padSizeScreenLan2V[9] / 2.0f), (this.padSizeScreenLan2V[10] / 2.0f) - this.padSizeScreenLan2V[ACTION_POINTER_INDEX_SHIFT], 400.0f - (this.padSizeScreenLan2V[11] / 2.0f), 480.0f - (this.padSizeScreenLan2V[12] / 2.0f), 400.0f - (this.padSizeScreenLan2V[13] / 2.0f), (480.0f - (this.padSizeScreenLan2V[14] / 2.0f)) - this.padSizeScreenLan2V[12], 400.0f - (this.padSizeScreenLan2V[15] / 2.0f)};
        this.virtualPad = new int[][]{new int[]{5, 0, 0, 55, 50, INPUT_HWBUTTONS}, new int[]{7, 0, 0, 55, 50, 2}, new int[]{4, 0, 0, 55, 50, 4}, new int[]{6, 0, 0, 55, 50, ACTION_POINTER_INDEX_SHIFT}, new int[]{INPUT_HWBUTTONS, 72, 0, InputList.KEYCODE_NUMPAD_8, 80, 16}, new int[]{INPUT_HWBUTTONS, InputList.KEYCODE_F10, 83, 220, InputList.KEYCODE_NUMPAD_RIGHT_PAREN, 32}, new int[]{INPUT_HWBUTTONS, 72, InputList.KEYCODE_VOLUME_MUTE, InputList.KEYCODE_NUMPAD_8, 244, 64}, new int[]{INPUT_HWBUTTONS, 0, 83, 90, InputList.KEYCODE_NUMPAD_RIGHT_PAREN, InputList.KEYCODE_MEDIA_CLOSE}, new int[]{2, 0, 0, 57, 50, Policy.LICENSED}, new int[]{9, 0, 0, 55, 50, pbpFile.PBP_PSTITLEIMG}, new int[]{10, 0, 0, 55, 50, 1024}, new int[]{3, 0, 0, 59, 50, 2048}, new int[]{0, 74, 0, InputList.KEYCODE_NUMPAD_4, 74, 4096}, new int[]{0, InputList.KEYCODE_NUMPAD_4, 74, 222, InputList.KEYCODE_NUMPAD_4, 8192}, new int[]{0, 74, InputList.KEYCODE_NUMPAD_4, InputList.KEYCODE_NUMPAD_4, 222, 16384}, new int[]{0, 0, 74, 74, InputList.KEYCODE_NUMPAD_4, 32768}, new int[]{0, 0, 0, 74, 74, 36864}, new int[]{0, InputList.KEYCODE_NUMPAD_4, 0, 222, 74, 12288}, new int[]{0, InputList.KEYCODE_NUMPAD_4, InputList.KEYCODE_NUMPAD_4, 222, 222, 24576}, new int[]{0, 0, InputList.KEYCODE_NUMPAD_4, 74, 222, 49152}, new int[]{11, 0, 0, 222, 222, 0}, new int[]{12, 0, 0, 222, 222, 0}, new int[]{ACTION_POINTER_INDEX_SHIFT, 0, 0, 53, 41, 0}, new int[]{16, 0, 0, 63, 63, 0}, new int[]{17, 0, 0, 63, 63, 0}, new int[]{18, 0, 0, 63, 63, 0}, new int[]{19, 0, 0, 63, 63, 0}, new int[]{20, 0, 0, 63, 63, 0}, new int[]{21, 0, 0, 63, 63, 0}};
        this.virtualPadPort = new int[][]{new int[]{0, 0, 10, 68, 58, INPUT_HWBUTTONS}, new int[]{0, 414, 10, 482, 58, 2}, new int[]{0, 70, 10, InputList.KEYCODE_F8, 58, 4}, new int[]{0, 344, 10, 412, 58, ACTION_POINTER_INDEX_SHIFT}, new int[]{0, 324, InputList.KEYCODE_NUMPAD_ENTER, 402, 242, 16}, new int[]{0, 404, 224, 482, 306, 32}, new int[]{0, 324, 302, 402, 406, 64}, new int[]{0, 248, 224, 326, 306, InputList.KEYCODE_MEDIA_CLOSE}, new int[]{0, InputList.KEYCODE_ZOOM_IN, 10, 230, 62, Policy.LICENSED}, new int[]{-1, 0, 0, 0, 0, pbpFile.PBP_PSTITLEIMG}, new int[]{-1, 0, 0, 0, 0, 1024}, new int[]{0, 244, 10, 316, 62, 2048}, new int[]{0, 74, InputList.KEYCODE_BUTTON_THUMBL, InputList.KEYCODE_NUMPAD_4, InputList.KEYCODE_STB_INPUT, 4096}, new int[]{0, InputList.KEYCODE_NUMPAD_4, InputList.KEYCODE_STB_INPUT, 222, 254, 8192}, new int[]{0, 74, 254, InputList.KEYCODE_NUMPAD_4, 328, 16384}, new int[]{0, 0, InputList.KEYCODE_STB_INPUT, 74, 254, 32768}, new int[]{0, 0, InputList.KEYCODE_BUTTON_THUMBL, 74, InputList.KEYCODE_STB_INPUT, 36864}, new int[]{0, InputList.KEYCODE_NUMPAD_4, InputList.KEYCODE_BUTTON_THUMBL, 222, InputList.KEYCODE_STB_INPUT, 12288}, new int[]{0, InputList.KEYCODE_NUMPAD_4, 254, 222, 328, 24576}, new int[]{0, 0, 254, 74, 328, 49152}, new int[]{-1, 0, 0, 222, 222, 0}, new int[]{-1, 0, 0, 222, 222, 0}, new int[]{-1, 0, 0, 53, 41, 0}, new int[]{-1, 0, 0, 63, 63, 0}, new int[]{-1, 0, 0, 63, 63, 0}, new int[]{-1, 0, 0, 63, 63, 0}, new int[]{-1, 0, 0, 63, 63, 0}, new int[]{-1, 0, 0, 63, 63, 0}, new int[]{-1, 0, 0, 63, 63, 0}};
        this.virtualPadPos = (int[][]) Array.newInstance(Integer.TYPE, new int[]{60, 4});
        this.virtualPadBit = new int[60];
        this.virtualPadId = new int[60];
        this.initvirtualPad = 0;
        this.gunb0 = 0;
        this.gunb1 = 0;
        this.gunb2 = 0;
        this.gunX = 0;
        this.gunY = 0;
        this.mContext = context;
        init();
        this.mHolder = getHolder();
        this.mHolder.addCallback(this);
        this.mHolder.setType(2);
    }

    private void dumpEvent(MotionEvent motionEvent) {
        int i = 0;
        String[] strArr = new String[]{"DOWN", "UP", "MOVE", "CANCEL", "OUTSIDE", "POINTER_DOWN", "POINTER_UP", "7?", "8?", "9?"};
        StringBuilder stringBuilder = new StringBuilder();
        int action = motionEvent.getAction();
        int i2 = action & 255;
        stringBuilder.append("event ACTION_").append(strArr[i2]);
        if (i2 == 5 || i2 == 6) {
            stringBuilder.append("(pid ").append(action >> ACTION_POINTER_INDEX_SHIFT);
            stringBuilder.append(")");
        }
        stringBuilder.append("[");
        while (i < motionEvent.getPointerCount()) {
            stringBuilder.append("#").append(i);
            stringBuilder.append("(pid ").append(motionEvent.getPointerId(i));
            stringBuilder.append(")=").append((int) motionEvent.getX(i));
            stringBuilder.append(",").append((int) motionEvent.getY(i));
            if (i + INPUT_HWBUTTONS < motionEvent.getPointerCount()) {
                stringBuilder.append(";");
            }
            i += INPUT_HWBUTTONS;
        }
        stringBuilder.append("]");
        Log.e("epsxepad", stringBuilder.toString());
    }

    public static int getActionIndexEclair(MotionEvent motionEvent) {
        return (ACTION_POINTER_INDEX_MASK & motionEvent.getAction()) >> ACTION_POINTER_INDEX_SHIFT;
    }

    private void init() {
        setFocusable(true);
        setFocusableInTouchMode(true);
        requestFocus();
    }

    /* JADX WARNING: inconsistent code. */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    private void queueMotionEvent(android.view.MotionEvent r17) {
        /*
        r16 = this;
        r1 = r17.getAction();
        r2 = r1 & 255;
        r0 = r16;
        r1 = r0.osVersion;
        r3 = 8;
        if (r1 < r3) goto L_0x0028;
    L_0x000e:
        r1 = r17.getActionIndex();
        r12 = r1;
    L_0x0013:
        r0 = r16;
        r1 = r0.emu_pad_type;
        r3 = 0;
        r1 = r1[r3];
        r3 = 1;
        if (r1 != r3) goto L_0x002e;
    L_0x001d:
        r0 = r16;
        r1 = r0.emu_pad_type;
        r3 = 1;
        r1 = r1[r3];
        r3 = 1;
        if (r1 != r3) goto L_0x002e;
    L_0x0027:
        return;
    L_0x0028:
        r1 = getActionIndexEclair(r17);
        r12 = r1;
        goto L_0x0013;
    L_0x002e:
        r1 = 5;
        if (r2 == r1) goto L_0x0039;
    L_0x0031:
        r1 = 6;
        if (r2 == r1) goto L_0x0039;
    L_0x0034:
        r1 = 1;
        if (r2 == r1) goto L_0x0039;
    L_0x0037:
        if (r2 != 0) goto L_0x0112;
    L_0x0039:
        r0 = r16;
        r1 = r0.emu_pad_mode;
        r2 = 0;
        r1 = r1[r2];
        r2 = 3;
        if (r1 != r2) goto L_0x00b3;
    L_0x0043:
        r2 = r17.getEventTime();
        r4 = r17.getAction();
        r0 = r17;
        r1 = r0.getX(r12);
        r5 = (int) r1;
        r0 = r17;
        r1 = r0.getY(r12);
        r6 = (int) r1;
        r0 = r17;
        r7 = r0.getPressure(r12);
        r0 = r17;
        r8 = r0.getSize(r12);
        r9 = r17.getDeviceId();
        r0 = r17;
        r10 = r0.getPointerId(r12);
        r0 = r16;
        r1 = r0.emu_pad_type;
        r11 = 0;
        r1 = r1[r11];
        r0 = r16;
        r11 = r0.emu_pad_type;
        r12 = 1;
        r11 = r11[r12];
        r11 = r11 << 1;
        r11 = r11 | r1;
        r1 = r16;
        r1 = r1.touchscreeneventgun(r2, r4, r5, r6, r7, r8, r9, r10, r11);
    L_0x0086:
        r0 = r16;
        r2 = r0.ts_vibration;
        r3 = 0;
        r2 = r2[r3];
        r3 = 1;
        if (r2 != r3) goto L_0x0093;
    L_0x0090:
        r2 = 1;
        if (r1 == r2) goto L_0x00a0;
    L_0x0093:
        r0 = r16;
        r2 = r0.ts_vibration;
        r3 = 1;
        r2 = r2[r3];
        r3 = 1;
        if (r2 != r3) goto L_0x0027;
    L_0x009d:
        r2 = 2;
        if (r1 != r2) goto L_0x0027;
    L_0x00a0:
        r0 = r16;
        r1 = r0.mContext;
        r2 = "vibrator";
        r1 = r1.getSystemService(r2);
        r1 = (android.os.Vibrator) r1;
        r2 = 35;
        r1.vibrate(r2);
        goto L_0x0027;
    L_0x00b3:
        r0 = r16;
        r1 = r0.emu_player_mode;
        r2 = 1;
        if (r1 != r2) goto L_0x00cd;
    L_0x00ba:
        r0 = r16;
        r1 = r0.emu_pad_type;
        r2 = 0;
        r1 = r1[r2];
        if (r1 == 0) goto L_0x00cd;
    L_0x00c3:
        r0 = r16;
        r1 = r0.emu_pad_type;
        r2 = 1;
        r2 = r1[r2];
        r1 = 0;
        if (r2 != 0) goto L_0x0086;
    L_0x00cd:
        r2 = r17.getEventTime();
        r4 = r17.getAction();
        r0 = r17;
        r1 = r0.getX(r12);
        r5 = (int) r1;
        r0 = r17;
        r1 = r0.getY(r12);
        r6 = (int) r1;
        r0 = r17;
        r7 = r0.getPressure(r12);
        r0 = r17;
        r8 = r0.getSize(r12);
        r9 = r17.getDeviceId();
        r0 = r17;
        r10 = r0.getPointerId(r12);
        r0 = r16;
        r1 = r0.emu_pad_type;
        r11 = 0;
        r1 = r1[r11];
        r0 = r16;
        r11 = r0.emu_pad_type;
        r12 = 1;
        r11 = r11[r12];
        r11 = r11 << 1;
        r11 = r11 | r1;
        r1 = r16;
        r1 = r1.touchscreenevent(r2, r4, r5, r6, r7, r8, r9, r10, r11);
        goto L_0x0086;
    L_0x0112:
        r1 = 0;
        r3 = 2;
        if (r2 != r3) goto L_0x0086;
    L_0x0116:
        r2 = 0;
        r14 = r2;
        r13 = r1;
    L_0x0119:
        r1 = r17.getPointerCount();
        if (r14 >= r1) goto L_0x01ce;
    L_0x011f:
        r0 = r16;
        r1 = r0.emu_pad_mode;
        r2 = 0;
        r1 = r1[r2];
        r2 = 3;
        if (r1 != r2) goto L_0x0170;
    L_0x0129:
        r2 = r17.getEventTime();
        r4 = r17.getAction();
        r0 = r17;
        r1 = r0.getX(r12);
        r5 = (int) r1;
        r0 = r17;
        r1 = r0.getY(r12);
        r6 = (int) r1;
        r0 = r17;
        r7 = r0.getPressure(r12);
        r0 = r17;
        r8 = r0.getSize(r12);
        r9 = r17.getDeviceId();
        r0 = r17;
        r10 = r0.getPointerId(r12);
        r0 = r16;
        r1 = r0.emu_pad_type;
        r11 = 0;
        r1 = r1[r11];
        r0 = r16;
        r11 = r0.emu_pad_type;
        r13 = 1;
        r11 = r11[r13];
        r11 = r11 << 1;
        r11 = r11 | r1;
        r1 = r16;
        r13 = r1.touchscreeneventgun(r2, r4, r5, r6, r7, r8, r9, r10, r11);
    L_0x016c:
        r1 = r14 + 1;
        r14 = r1;
        goto L_0x0119;
    L_0x0170:
        r0 = r16;
        r1 = r0.emu_player_mode;
        r2 = 1;
        if (r1 != r2) goto L_0x0189;
    L_0x0177:
        r0 = r16;
        r1 = r0.emu_pad_type;
        r2 = 0;
        r1 = r1[r2];
        if (r1 == 0) goto L_0x0189;
    L_0x0180:
        r0 = r16;
        r1 = r0.emu_pad_type;
        r2 = 1;
        r1 = r1[r2];
        if (r1 != 0) goto L_0x016c;
    L_0x0189:
        r2 = r17.getEventTime();
        r4 = r17.getAction();
        r0 = r17;
        r1 = r0.getX(r14);
        r5 = (int) r1;
        r0 = r17;
        r1 = r0.getY(r14);
        r6 = (int) r1;
        r0 = r17;
        r7 = r0.getPressure(r14);
        r0 = r17;
        r8 = r0.getSize(r14);
        r9 = r17.getDeviceId();
        r0 = r17;
        r10 = r0.getPointerId(r14);
        r0 = r16;
        r1 = r0.emu_pad_type;
        r11 = 0;
        r1 = r1[r11];
        r0 = r16;
        r11 = r0.emu_pad_type;
        r15 = 1;
        r11 = r11[r15];
        r11 = r11 << 1;
        r11 = r11 | r1;
        r1 = r16;
        r1 = r1.touchscreenevent(r2, r4, r5, r6, r7, r8, r9, r10, r11);
        r13 = r13 + r1;
        goto L_0x016c;
    L_0x01ce:
        r1 = r13;
        goto L_0x0086;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.epsxe.ePSXe.ePSXeViewGL2.queueMotionEvent(android.view.MotionEvent):void");
    }

    public void FlipGL() {
        this.mGLThread.FlipGL();
    }

    public boolean dispatchTouchEvent(MotionEvent motionEvent) {
        queueMotionEvent(motionEvent);
        return true;
    }

    public void exec_tools(int i, int i2) {
        int i3 = (int) ((this.padResize * 508.0f) / 9.0f);
        int i4 = (this.mWidth - ((int) (this.padResize * 508.0f))) / 2;
        if (i <= (i3 * INPUT_HWBUTTONS) + i4) {
            if ((this.emu_opengl_options & 4096) != 0) {
                this.f640e.gpusetoptiongl(0, 4096);
            } else {
                this.f640e.gpusetoptiongl(INPUT_HWBUTTONS, 4096);
            }
            this.emu_opengl_options ^= 4096;
        } else if (i <= (i3 * 2) + i4) {
            if ((this.emu_opengl_options & 7) != 0) {
                this.f640e.gpusetoptiongl(0, 3);
                this.emu_opengl_options &= -8;
                return;
            }
            this.f640e.gpusetoptiongl(INPUT_HWBUTTONS, 3);
            this.emu_opengl_options = (this.emu_opengl_options & -8) | 3;
        } else if (i <= (i3 * 3) + i4) {
            i3 = ((this.emu_opengl_options >> 3) & 7) + INPUT_HWBUTTONS;
            if (i3 == 7) {
                i3 = 0;
            }
            if ((i3 & 56) != 0) {
                this.f640e.gpusetoptiongl(0, 32);
                this.emu_opengl_options &= -57;
                return;
            }
            this.f640e.gpusetoptiongl(INPUT_HWBUTTONS, i3 << 3);
            this.emu_opengl_options = (i3 << 3) | (this.emu_opengl_options & -57);
        } else if (i <= (i3 * 4) + i4) {
            if ((this.emu_opengl_options & 16384) != 0) {
                this.f640e.gpusetoptiongl(0, 16384);
            } else {
                this.f640e.gpusetoptiongl(INPUT_HWBUTTONS, 16384);
            }
            this.emu_opengl_options ^= 16384;
        } else if (i <= (i3 * 5) + i4) {
            if ((this.emu_opengl_options & 32768) != 0) {
                this.f640e.gpusetoptiongl(0, 32768);
            } else {
                this.f640e.gpusetoptiongl(INPUT_HWBUTTONS, 32768);
            }
            this.emu_opengl_options ^= 32768;
        } else if (i <= (i3 * 6) + i4) {
            if ((this.emu_opengl_options & 448) != 0) {
                this.f640e.gpusetoptiongl(0, InputList.KEYCODE_BUTTON_5);
                this.emu_opengl_options &= -449;
                return;
            }
            this.f640e.gpusetoptiongl(INPUT_HWBUTTONS, InputList.KEYCODE_BUTTON_5);
            this.emu_opengl_options = (this.emu_opengl_options & -449) | Policy.LICENSED;
        } else if (i <= (i3 * 7) + i4) {
            if ((this.emu_opengl_options & 8192) != 0) {
                this.f640e.gpusetoptiongl(0, 8192);
            } else {
                this.f640e.gpusetoptiongl(INPUT_HWBUTTONS, 8192);
            }
            this.emu_opengl_options ^= 8192;
        } else if (i <= (i3 * ACTION_POINTER_INDEX_SHIFT) + i4) {
            this.f640e.gpusaveoptiongl(this.emu_opengl_options);
            Toast.makeText(this.mContext, "Saving config...", 0).show();
        } else if (i <= (i3 * 9) + i4) {
            this.emu_enable_tools ^= INPUT_HWBUTTONS;
        }
    }

    public native void initPluginGL();

    public void init_motionevent_1playerGun() {
        this.virtualPadPos[0][0] = (this.mWidth - ((this.mHeight * 4) / 3)) / 2;
        this.virtualPadPos[0][INPUT_HWBUTTONS] = 0;
        this.virtualPadPos[0][2] = ((this.mWidth - ((this.mHeight * 4) / 3)) / 2) + ((this.mHeight * 4) / 3);
        this.virtualPadPos[0][3] = this.mHeight;
        this.virtualPadBit[0] = INPUT_HWBUTTONS;
        if (this.emu_pad_type_selected == 0) {
            int[] iArr = this.virtualPadBit;
            iArr[0] = 65536 | iArr[0];
        }
        this.virtualPadId[0] = -1;
        this.virtualPadPos[INPUT_HWBUTTONS][0] = 0;
        this.virtualPadPos[INPUT_HWBUTTONS][INPUT_HWBUTTONS] = 0;
        this.virtualPadPos[INPUT_HWBUTTONS][2] = (this.mWidth - ((this.mHeight * 4) / 3)) / 2;
        this.virtualPadPos[INPUT_HWBUTTONS][3] = this.mHeight / 2;
        this.virtualPadBit[INPUT_HWBUTTONS] = 2;
        if (this.emu_pad_type_selected == 0) {
            iArr = this.virtualPadBit;
            iArr[INPUT_HWBUTTONS] = 65536 | iArr[INPUT_HWBUTTONS];
        }
        this.virtualPadId[INPUT_HWBUTTONS] = -1;
        this.virtualPadPos[2][0] = 0;
        this.virtualPadPos[2][INPUT_HWBUTTONS] = this.mHeight / 2;
        this.virtualPadPos[2][2] = (this.mWidth - ((this.mHeight * 4) / 3)) / 2;
        this.virtualPadPos[2][3] = this.mHeight;
        this.virtualPadBit[2] = 4;
        if (this.emu_pad_type_selected == 0) {
            iArr = this.virtualPadBit;
            iArr[2] = 65536 | iArr[2];
        }
        this.virtualPadId[2] = -1;
        this.initvirtualPad = INPUT_HWBUTTONS;
    }

    public void init_motionevent_1playerLandscape() {
        int i = 0;
        while (i < 29) {
            if (i > 22 && i < 29) {
                if (this.padScreenFunc[i - 23] == 2) {
                    if (this.padScreenExtra[i - 23] == 10) {
                        this.virtualPad[i][5] = 48;
                    } else if (this.padScreenExtra[i - 23] == 11) {
                        this.virtualPad[i][5] = 144;
                    } else if (this.padScreenExtra[i - 23] == 12) {
                        this.virtualPad[i][5] = 192;
                    } else if (this.padScreenExtra[i - 23] == 13) {
                        this.virtualPad[i][5] = 96;
                    } else if (this.padScreenExtra[i - 23] == 14) {
                        this.virtualPad[i][5] = 80;
                    } else if (this.padScreenExtra[i - 23] == 15) {
                        this.virtualPad[i][5] = 160;
                    } else if (this.padScreenExtra[i - 23] == 16) {
                        this.virtualPad[i][5] = 12;
                    } else if (this.padScreenExtra[i - 23] == 17) {
                        this.virtualPad[i][5] = 3;
                    }
                    this.virtualPad[i][0] = i - 9;
                } else if (this.padScreenFunc[i - 23] == INPUT_HWBUTTONS) {
                    this.virtualPad[i][0] = i - 9;
                } else {
                    this.virtualPad[i][0] = -1;
                }
            }
            if (this.virtualPad[i][0] == -1 || this.padScreenStatus[this.mode][this.virtualPad[i][0]] != INPUT_HWBUTTONS) {
                this.virtualPadBit[i] = 0;
                this.virtualPadId[i] = -1;
                this.virtualPadPos[i][0] = -1;
                this.virtualPadPos[i][INPUT_HWBUTTONS] = -1;
                this.virtualPadPos[i][2] = -1;
                this.virtualPadPos[i][3] = -1;
            } else {
                int i2 = ((int) this.padOffScreenLan[this.mode][this.virtualPad[i][0] * 2]) - ((int) ((this.padSizeScreenLan[this.mode][this.virtualPad[i][0] * 2] * this.padScreenResize[this.mode][this.virtualPad[i][0]]) / 2.0f));
                int i3 = ((int) this.padOffScreenLan[this.mode][(this.virtualPad[i][0] * 2) + INPUT_HWBUTTONS]) - ((int) ((this.padSizeScreenLan[this.mode][(this.virtualPad[i][0] * 2) + INPUT_HWBUTTONS] * this.padScreenResize[this.mode][this.virtualPad[i][0]]) / 2.0f));
                this.virtualPadPos[i][0] = ((int) ((((float) this.virtualPad[i][INPUT_HWBUTTONS]) * this.padResize) * this.padScreenResize[this.mode][this.virtualPad[i][0]])) + i2;
                this.virtualPadPos[i][INPUT_HWBUTTONS] = (((int) ((((float) this.virtualPad[i][2]) * this.padResize) * this.padScreenResize[this.mode][this.virtualPad[i][0]])) + (this.mHeight - ((int) (this.padSizeScreenLan[this.mode][(this.virtualPad[i][0] * 2) + INPUT_HWBUTTONS] * this.padScreenResize[this.mode][this.virtualPad[i][0]])))) - i3;
                this.virtualPadPos[i][2] = i2 + ((int) ((((float) this.virtualPad[i][3]) * this.padResize) * this.padScreenResize[this.mode][this.virtualPad[i][0]]));
                this.virtualPadPos[i][3] = (((int) ((((float) this.virtualPad[i][4]) * this.padResize) * this.padScreenResize[this.mode][this.virtualPad[i][0]])) + (this.mHeight - ((int) (this.padSizeScreenLan[this.mode][(this.virtualPad[i][0] * 2) + INPUT_HWBUTTONS] * this.padScreenResize[this.mode][this.virtualPad[i][0]])))) - i3;
                this.virtualPadBit[i] = this.virtualPad[i][5];
                if (this.emu_pad_type_selected == 0) {
                    int[] iArr = this.virtualPadBit;
                    iArr[i] = 65536 | iArr[i];
                }
                this.virtualPadId[i] = -1;
                if (i == 20) {
                    this.analog_values[0][0] = ((this.virtualPadPos[i][2] - this.virtualPadPos[i][0]) / 2) + this.virtualPadPos[i][0];
                    this.analog_values[0][INPUT_HWBUTTONS] = this.mHeight - (((this.virtualPadPos[i][3] - this.virtualPadPos[i][INPUT_HWBUTTONS]) / 2) + this.virtualPadPos[i][INPUT_HWBUTTONS]);
                }
                if (i == 21) {
                    this.analog_values[0][2] = ((this.virtualPadPos[i][2] - this.virtualPadPos[i][0]) / 2) + this.virtualPadPos[i][0];
                    this.analog_values[0][3] = this.mHeight - (((this.virtualPadPos[i][3] - this.virtualPadPos[i][INPUT_HWBUTTONS]) / 2) + this.virtualPadPos[i][INPUT_HWBUTTONS]);
                }
            }
            i += INPUT_HWBUTTONS;
        }
        this.initvirtualPad = INPUT_HWBUTTONS;
    }

    public void init_motionevent_1playerPortrait() {
        for (int i = 0; i < 23; i += INPUT_HWBUTTONS) {
            if (this.virtualPadPort[i][0] == -1) {
                this.virtualPadBit[i] = 0;
                this.virtualPadId[i] = -1;
                this.virtualPadPos[i][0] = -1;
                this.virtualPadPos[i][INPUT_HWBUTTONS] = -1;
                this.virtualPadPos[i][2] = -1;
                this.virtualPadPos[i][3] = -1;
            } else {
                int i2 = this.mHeight / 2;
                this.virtualPadPos[i][0] = ((this.virtualPadPort[i][INPUT_HWBUTTONS] * this.mWidth) / 480) + 0;
                this.virtualPadPos[i][INPUT_HWBUTTONS] = ((this.virtualPadPort[i][2] * (this.mHeight / 2)) / 400) + i2;
                this.virtualPadPos[i][2] = ((this.virtualPadPort[i][3] * this.mWidth) / 480) + 0;
                this.virtualPadPos[i][3] = i2 + ((this.virtualPadPort[i][4] * (this.mHeight / 2)) / 400);
                this.virtualPadBit[i] = this.virtualPadPort[i][5];
                if (this.emu_pad_type_selected == 0) {
                    int[] iArr = this.virtualPadBit;
                    iArr[i] = 65536 | iArr[i];
                }
                this.virtualPadId[i] = -1;
                if (i == 20) {
                    this.analog_values[0][0] = -1;
                    this.analog_values[0][INPUT_HWBUTTONS] = -1;
                }
                if (i == 21) {
                    this.analog_values[0][2] = -1;
                    this.analog_values[0][3] = -1;
                }
            }
        }
        this.initvirtualPad = INPUT_HWBUTTONS;
    }

    public void init_motionevent_2playerH(int i) {
        int i2;
        int i3 = 0;
        for (i2 = 0; i2 < 20; i2 += INPUT_HWBUTTONS) {
            if (this.virtualPad[i2][0] == -1) {
                this.virtualPadBit[i2] = 0;
                this.virtualPadId[i2] = -1;
                this.virtualPadPos[i2][0] = -1;
                this.virtualPadPos[i2][INPUT_HWBUTTONS] = -1;
                this.virtualPadPos[i2][2] = -1;
                this.virtualPadPos[i2][3] = -1;
            } else {
                int i4 = ((int) this.padOffScreenLan[this.mode][this.virtualPad[i2][0] * 2]) - (((int) this.padSizeScreenLan[this.mode][this.virtualPad[i2][0] * 2]) / 2);
                int i5 = ((int) this.padOffScreenLan[this.mode][(this.virtualPad[i2][0] * 2) + INPUT_HWBUTTONS]) - (((int) this.padSizeScreenLan[this.mode][(this.virtualPad[i2][0] * 2) + INPUT_HWBUTTONS]) / 2);
                this.virtualPadPos[i2][0] = ((int) (((float) this.virtualPad[i2][INPUT_HWBUTTONS]) * this.padResize)) + i4;
                this.virtualPadPos[i2][INPUT_HWBUTTONS] = (((((int) (((float) this.virtualPad[i2][2]) * this.padResize)) + (this.mHeight - ((int) this.padSizeScreenLan[this.mode][(this.virtualPad[i2][0] * 2) + INPUT_HWBUTTONS]))) - i5) / 2) + (this.mHeight / 2);
                this.virtualPadPos[i2][2] = i4 + ((int) (((float) this.virtualPad[i2][3]) * this.padResize));
                this.virtualPadPos[i2][3] = (((((int) (((float) this.virtualPad[i2][4]) * this.padResize)) + (this.mHeight - ((int) this.padSizeScreenLan[this.mode][(this.virtualPad[i2][0] * 2) + INPUT_HWBUTTONS]))) - i5) / 2) + (this.mHeight / 2);
                this.virtualPadBit[i2] = 65536 | this.virtualPad[i2][5];
                this.virtualPadId[i2] = -1;
            }
        }
        for (i2 = 0; i2 < 20; i2 += INPUT_HWBUTTONS) {
            if (this.virtualPad[i2][0] == -1) {
                this.virtualPadBit[i2 + 20] = 0;
                this.virtualPadId[i2 + 20] = -1;
                this.virtualPadPos[i2 + 20][0] = -1;
                this.virtualPadPos[i2 + 20][INPUT_HWBUTTONS] = -1;
                this.virtualPadPos[i2 + 20][2] = -1;
                this.virtualPadPos[i2 + 20][3] = -1;
            } else {
                i4 = ((int) this.padOffScreenLan[this.mode][this.virtualPad[i2][0] * 2]) - (((int) this.padSizeScreenLan[this.mode][this.virtualPad[i2][0] * 2]) / 2);
                i5 = ((int) this.padOffScreenLan[this.mode][(this.virtualPad[i2][0] * 2) + INPUT_HWBUTTONS]) - (((int) this.padSizeScreenLan[this.mode][(this.virtualPad[i2][0] * 2) + INPUT_HWBUTTONS]) / 2);
                this.virtualPadPos[i2 + 20][0] = this.mWidth - (((int) (((float) this.virtualPad[i2][3]) * this.padResize)) + i4);
                this.virtualPadPos[i2 + 20][INPUT_HWBUTTONS] = (this.mHeight / 2) - (((((int) (((float) this.virtualPad[i2][4]) * this.padResize)) + (this.mHeight - ((int) this.padSizeScreenLan[this.mode][(this.virtualPad[i2][0] * 2) + INPUT_HWBUTTONS]))) - i5) / 2);
                this.virtualPadPos[i2 + 20][2] = this.mWidth - (i4 + ((int) (((float) this.virtualPad[i2][INPUT_HWBUTTONS]) * this.padResize)));
                this.virtualPadPos[i2 + 20][3] = (this.mHeight / 2) - (((((int) (((float) this.virtualPad[i2][2]) * this.padResize)) + (this.mHeight - ((int) this.padSizeScreenLan[this.mode][(this.virtualPad[i2][0] * 2) + INPUT_HWBUTTONS]))) - i5) / 2);
                this.virtualPadBit[i2 + 20] = this.virtualPad[i2][5];
                this.virtualPadId[i2 + 20] = -1;
            }
        }
        if (i == INPUT_HWBUTTONS) {
            while (i3 < 40) {
                int[] iArr = this.virtualPadBit;
                iArr[i3] = 65536 ^ iArr[i3];
                i3 += INPUT_HWBUTTONS;
            }
        }
        this.initvirtualPad = INPUT_HWBUTTONS;
    }

    public void init_motionevent_2playerV() {
        int i;
        for (i = 0; i < 20; i += INPUT_HWBUTTONS) {
            if (this.virtualPad[i][0] == -1) {
                this.virtualPadBit[i] = 0;
                this.virtualPadId[i] = -1;
                this.virtualPadPos[i][0] = -1;
                this.virtualPadPos[i][INPUT_HWBUTTONS] = -1;
                this.virtualPadPos[i][2] = -1;
                this.virtualPadPos[i][3] = -1;
            } else {
                int i2 = ((int) this.padOffScreenLan[this.mode][this.virtualPad[i][0] * 2]) - (((int) this.padSizeScreenLan[this.mode][this.virtualPad[i][0] * 2]) / 2);
                int i3 = ((int) this.padOffScreenLan[this.mode][(this.virtualPad[i][0] * 2) + INPUT_HWBUTTONS]) - (((int) this.padSizeScreenLan[this.mode][(this.virtualPad[i][0] * 2) + INPUT_HWBUTTONS]) / 2);
                int i4 = ((int) (((float) this.virtualPad[i][INPUT_HWBUTTONS]) * this.padResize)) + i2;
                int i5 = (((int) (((float) this.virtualPad[i][2]) * this.padResize)) + (this.mHeight - ((int) this.padSizeScreenLan[this.mode][(this.virtualPad[i][0] * 2) + INPUT_HWBUTTONS]))) - i3;
                i4 = (i4 * this.mHeight) / this.mWidth;
                i2 = ((i2 + ((int) (((float) this.virtualPad[i][3]) * this.padResize))) * this.mHeight) / this.mWidth;
                i3 = ((((((int) (((float) this.virtualPad[i][4]) * this.padResize)) + (this.mHeight - ((int) this.padSizeScreenLan[this.mode][(this.virtualPad[i][0] * 2) + INPUT_HWBUTTONS]))) - i3) * this.mWidth) / 2) / this.mHeight;
                this.virtualPadPos[i][0] = (((i5 * this.mWidth) / 2) / this.mHeight) + (this.mWidth / 2);
                this.virtualPadPos[i][INPUT_HWBUTTONS] = this.mHeight - i2;
                this.virtualPadPos[i][2] = i3 + (this.mWidth / 2);
                this.virtualPadPos[i][3] = this.mHeight - i4;
                this.virtualPadBit[i] = 65536 | this.virtualPad[i][5];
                this.virtualPadId[i] = -1;
            }
        }
        for (i = 0; i < 20; i += INPUT_HWBUTTONS) {
            if (this.virtualPad[i][0] == -1) {
                this.virtualPadBit[i + 20] = 0;
                this.virtualPadId[i + 20] = -1;
                this.virtualPadPos[i + 20][0] = -1;
                this.virtualPadPos[i + 20][INPUT_HWBUTTONS] = -1;
                this.virtualPadPos[i + 20][2] = -1;
                this.virtualPadPos[i + 20][3] = -1;
            } else {
                i2 = ((int) this.padOffScreenLan[this.mode][this.virtualPad[i][0] * 2]) - (((int) this.padSizeScreenLan[this.mode][this.virtualPad[i][0] * 2]) / 2);
                i3 = ((int) this.padOffScreenLan[this.mode][(this.virtualPad[i][0] * 2) + INPUT_HWBUTTONS]) - (((int) this.padSizeScreenLan[this.mode][(this.virtualPad[i][0] * 2) + INPUT_HWBUTTONS]) / 2);
                i4 = ((int) (((float) this.virtualPad[i][INPUT_HWBUTTONS]) * this.padResize)) + i2;
                i5 = (((int) (((float) this.virtualPad[i][2]) * this.padResize)) + (this.mHeight - ((int) this.padSizeScreenLan[this.mode][(this.virtualPad[i][0] * 2) + INPUT_HWBUTTONS]))) - i3;
                i4 = (i4 * this.mHeight) / this.mWidth;
                i5 = ((i5 * this.mWidth) / 2) / this.mHeight;
                i2 = ((i2 + ((int) (((float) this.virtualPad[i][3]) * this.padResize))) * this.mHeight) / this.mWidth;
                this.virtualPadPos[i + 20][0] = (this.mWidth / 2) - (((((((int) (((float) this.virtualPad[i][4]) * this.padResize)) + (this.mHeight - ((int) this.padSizeScreenLan[this.mode][(this.virtualPad[i][0] * 2) + INPUT_HWBUTTONS]))) - i3) * this.mWidth) / 2) / this.mHeight);
                this.virtualPadPos[i + 20][INPUT_HWBUTTONS] = i4;
                this.virtualPadPos[i + 20][2] = (this.mWidth / 2) - i5;
                this.virtualPadPos[i + 20][3] = i2;
                this.virtualPadBit[i + 20] = this.virtualPad[i][5];
                this.virtualPadId[i + 20] = -1;
            }
        }
        this.initvirtualPad = INPUT_HWBUTTONS;
    }

    public void loadExtraButtons() {
        if (this.emu_player_mode == INPUT_HWBUTTONS) {
            if (this.mePSXeReadPreferences == null) {
                this.mePSXeReadPreferences = new ePSXeReadPreferences(this.mContext);
            }
            this.padScreenExtraCombo = 0;
            this.padScreenExtraEnabled = 0;
            for (int i = 0; i < 6; i += INPUT_HWBUTTONS) {
                int padExtra = this.mePSXeReadPreferences.getPadExtra("inputExtrasPref" + (i + INPUT_HWBUTTONS));
                if (padExtra == 19) {
                    this.padScreenStatus[0][i + 14] = 2;
                    this.padScreenStatus[INPUT_HWBUTTONS][i + 14] = 2;
                } else {
                    this.padScreenExtraEnabled = INPUT_HWBUTTONS;
                    this.padScreenStatus[0][i + 14] = INPUT_HWBUTTONS;
                    this.padScreenStatus[INPUT_HWBUTTONS][i + 14] = INPUT_HWBUTTONS;
                }
                this.padScreenExtra[i] = padExtra;
                if (this.padScreenExtra[i] < 5) {
                    this.padScreenFunc[i] = INPUT_HWBUTTONS;
                } else if (this.padScreenExtra[i] < 10) {
                    this.padScreenFunc[i] = INPUT_HWBUTTONS;
                } else if (this.padScreenExtra[i] < 18) {
                    this.padScreenFunc[i] = 2;
                    this.padScreenExtraCombo = INPUT_HWBUTTONS;
                } else if (this.padScreenExtra[i] == 18) {
                    this.padScreenFunc[i] = INPUT_HWBUTTONS;
                } else if (this.padScreenExtra[i] == 20) {
                    this.padScreenFunc[i] = INPUT_HWBUTTONS;
                } else if (this.padScreenExtra[i] == 21) {
                    this.padScreenFunc[i] = INPUT_HWBUTTONS;
                } else if (this.padScreenExtra[i] == 22) {
                    this.padScreenFunc[i] = INPUT_HWBUTTONS;
                } else if (this.padScreenExtra[i] == 23) {
                    this.padScreenFunc[i] = INPUT_HWBUTTONS;
                } else if (this.padScreenExtra[i] == 24) {
                    this.padScreenFunc[i] = INPUT_HWBUTTONS;
                } else if (this.padScreenExtra[i] == 25) {
                    this.padScreenFunc[i] = INPUT_HWBUTTONS;
                } else if (this.padScreenExtra[i] == 26) {
                    this.padScreenFunc[i] = INPUT_HWBUTTONS;
                } else if (this.padScreenExtra[i] == 27) {
                    this.padScreenFunc[i] = INPUT_HWBUTTONS;
                } else {
                    this.padScreenFunc[i] = 0;
                }
            }
        }
    }

    public void onAutosave(int i) {
        Log.e("epsxe", "epsxeview autosaving status");
        this.f640e.setSaveMode(i);
    }

    public void onPause() {
        Log.e("epsxe", "epsxeview saving status");
        this.f640e.setSaveMode(INPUT_HWBUTTONS);
    }

    /* JADX WARNING: inconsistent code. */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public void queueMotionEvent(int r12, int r13, int r14, int r15) {
        /*
        r11 = this;
        r1 = r12 & 255;
        r0 = r11.emu_pad_type;
        r2 = 0;
        r0 = r0[r2];
        r2 = 1;
        if (r0 != r2) goto L_0x0017;
    L_0x000a:
        r0 = r11.emu_pad_type;
        r2 = 1;
        r0 = r0[r2];
        r2 = 1;
        if (r0 != r2) goto L_0x0017;
    L_0x0012:
        r0 = r11.emu_enable_tools;
        if (r0 != 0) goto L_0x0017;
    L_0x0016:
        return;
    L_0x0017:
        r0 = 5;
        if (r1 == r0) goto L_0x0026;
    L_0x001a:
        r0 = 6;
        if (r1 == r0) goto L_0x0026;
    L_0x001d:
        r0 = 1;
        if (r1 == r0) goto L_0x0026;
    L_0x0020:
        if (r1 == 0) goto L_0x0026;
    L_0x0022:
        r0 = 0;
        r2 = 2;
        if (r1 != r2) goto L_0x004a;
    L_0x0026:
        r0 = r11.emu_pad_mode;
        r1 = 0;
        r0 = r0[r1];
        r1 = 3;
        if (r0 != r1) goto L_0x0070;
    L_0x002e:
        r1 = 0;
        r6 = 0;
        r7 = 0;
        r8 = 0;
        r0 = r11.emu_pad_type;
        r3 = 0;
        r0 = r0[r3];
        r3 = r11.emu_pad_type;
        r4 = 1;
        r3 = r3[r4];
        r3 = r3 << 1;
        r10 = r0 | r3;
        r0 = r11;
        r3 = r12;
        r4 = r13;
        r5 = r14;
        r9 = r15;
        r0 = r0.touchscreeneventgun(r1, r3, r4, r5, r6, r7, r8, r9, r10);
    L_0x004a:
        r1 = r11.ts_vibration;
        r2 = 0;
        r1 = r1[r2];
        r2 = 1;
        if (r1 != r2) goto L_0x0055;
    L_0x0052:
        r1 = 1;
        if (r0 == r1) goto L_0x0060;
    L_0x0055:
        r1 = r11.ts_vibration;
        r2 = 1;
        r1 = r1[r2];
        r2 = 1;
        if (r1 != r2) goto L_0x0016;
    L_0x005d:
        r1 = 2;
        if (r0 != r1) goto L_0x0016;
    L_0x0060:
        r0 = r11.mContext;
        r1 = "vibrator";
        r0 = r0.getSystemService(r1);
        r0 = (android.os.Vibrator) r0;
        r1 = 35;
        r0.vibrate(r1);
        goto L_0x0016;
    L_0x0070:
        r0 = r11.emu_player_mode;
        r1 = 1;
        if (r0 != r1) goto L_0x0089;
    L_0x0075:
        r0 = r11.emu_pad_type;
        r1 = 0;
        r0 = r0[r1];
        if (r0 == 0) goto L_0x0089;
    L_0x007c:
        r0 = r11.emu_pad_type;
        r1 = 1;
        r0 = r0[r1];
        if (r0 == 0) goto L_0x0089;
    L_0x0083:
        r1 = r11.emu_enable_tools;
        r0 = 0;
        r2 = 1;
        if (r1 != r2) goto L_0x004a;
    L_0x0089:
        r1 = 0;
        r6 = 0;
        r7 = 0;
        r8 = 0;
        r0 = r11.emu_pad_type;
        r3 = 0;
        r0 = r0[r3];
        r3 = r11.emu_pad_type;
        r4 = 1;
        r3 = r3[r4];
        r3 = r3 << 1;
        r10 = r0 | r3;
        r0 = r11;
        r3 = r12;
        r4 = r13;
        r5 = r14;
        r9 = r15;
        r0 = r0.touchscreenevent(r1, r3, r4, r5, r6, r7, r8, r9, r10);
        r0 = r0 + 0;
        goto L_0x004a;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.epsxe.ePSXe.ePSXeViewGL2.queueMotionEvent(int, int, int, int):void");
    }

    public void redoPads(int i, int i2) {
        int i3 = 14;
        if (this.mePSXeReadPreferences == null) {
            this.mePSXeReadPreferences = new ePSXeReadPreferences(this.mContext);
        }
        if (this.mePSXeReadPreferences.getPadStatus("Pad1Status1") != -1 && this.emu_player_mode == INPUT_HWBUTTONS && this.emu_screen_orientation == 0) {
            int padStatus;
            float padSize;
            float padSize2;
            Log.e("epsxeviewgl", "loading pad info from preferences");
            int i4 = this.mode;
            this.mode = 0;
            resetPad1Values();
            this.mode = INPUT_HWBUTTONS;
            resetPad1Values();
            this.mode = i4;
            for (i4 = INPUT_HWBUTTONS; i4 < 14; i4 += INPUT_HWBUTTONS) {
                padStatus = this.mePSXeReadPreferences.getPadStatus("Pad1Status" + i4);
                if (padStatus != -1) {
                    this.padScreenStatus[0][i4 - 1] = padStatus;
                }
            }
            for (i4 = 14; i4 < 20; i4 += INPUT_HWBUTTONS) {
                padStatus = this.mePSXeReadPreferences.getPadStatus("Pad1Status" + i4);
                if (padStatus != -1) {
                    this.padScreenStatus[0][i4] = padStatus;
                }
            }
            for (i4 = INPUT_HWBUTTONS; i4 < 14; i4 += INPUT_HWBUTTONS) {
                padStatus = this.mePSXeReadPreferences.getPadStatus("Pad1StatusAnalog" + i4);
                if (padStatus != -1) {
                    this.padScreenStatus[INPUT_HWBUTTONS][i4 - 1] = padStatus;
                }
            }
            for (i4 = 14; i4 < 20; i4 += INPUT_HWBUTTONS) {
                padStatus = this.mePSXeReadPreferences.getPadStatus("Pad1StatusAnalog" + i4);
                if (padStatus != -1) {
                    this.padScreenStatus[INPUT_HWBUTTONS][i4] = padStatus;
                }
            }
            for (i4 = INPUT_HWBUTTONS; i4 < 14; i4 += INPUT_HWBUTTONS) {
                padSize = this.mePSXeReadPreferences.getPadSize("Pad1SizeX" + i4);
                padSize2 = this.mePSXeReadPreferences.getPadSize("Pad1SizeY" + i4);
                if (padSize != -1.0f) {
                    this.padSizeScreenLan[0][(i4 - 1) * 2] = padSize;
                    this.padSizeScreenLan[0][((i4 - 1) * 2) + INPUT_HWBUTTONS] = padSize2;
                }
            }
            for (i4 = 14; i4 < 20; i4 += INPUT_HWBUTTONS) {
                padSize = this.mePSXeReadPreferences.getPadSize("Pad1SizeX" + i4);
                padSize2 = this.mePSXeReadPreferences.getPadSize("Pad1SizeY" + i4);
                if (padSize != -1.0f) {
                    this.padSizeScreenLan[0][i4 * 2] = padSize;
                    this.padSizeScreenLan[0][(i4 * 2) + INPUT_HWBUTTONS] = padSize2;
                }
            }
            for (i4 = INPUT_HWBUTTONS; i4 < 14; i4 += INPUT_HWBUTTONS) {
                padSize = this.mePSXeReadPreferences.getPadSize("Pad1SizeXAnalog" + i4);
                padSize2 = this.mePSXeReadPreferences.getPadSize("Pad1SizeYAnalog" + i4);
                if (padSize != -1.0f) {
                    this.padSizeScreenLan[INPUT_HWBUTTONS][(i4 - 1) * 2] = padSize;
                    this.padSizeScreenLan[INPUT_HWBUTTONS][((i4 - 1) * 2) + INPUT_HWBUTTONS] = padSize2;
                }
            }
            for (i4 = 14; i4 < 20; i4 += INPUT_HWBUTTONS) {
                padSize = this.mePSXeReadPreferences.getPadSize("Pad1SizeXAnalog" + i4);
                padSize2 = this.mePSXeReadPreferences.getPadSize("Pad1SizeYAnalog" + i4);
                if (padSize != -1.0f) {
                    this.padSizeScreenLan[INPUT_HWBUTTONS][i4 * 2] = padSize;
                    this.padSizeScreenLan[INPUT_HWBUTTONS][(i4 * 2) + INPUT_HWBUTTONS] = padSize2;
                }
            }
            for (i4 = INPUT_HWBUTTONS; i4 < 14; i4 += INPUT_HWBUTTONS) {
                padSize = this.mePSXeReadPreferences.getPadSize("Pad1PosX" + i4);
                padSize2 = this.mePSXeReadPreferences.getPadSize("Pad1PosY" + i4);
                if (padSize != -1.0f) {
                    this.padOffScreenLan[0][(i4 - 1) * 2] = padSize;
                    this.padOffScreenLan[0][((i4 - 1) * 2) + INPUT_HWBUTTONS] = padSize2;
                }
            }
            for (i4 = 14; i4 < 20; i4 += INPUT_HWBUTTONS) {
                padSize = this.mePSXeReadPreferences.getPadSize("Pad1PosX" + i4);
                padSize2 = this.mePSXeReadPreferences.getPadSize("Pad1PosY" + i4);
                if (padSize != -1.0f) {
                    this.padOffScreenLan[0][i4 * 2] = padSize;
                    this.padOffScreenLan[0][(i4 * 2) + INPUT_HWBUTTONS] = padSize2;
                }
            }
            for (i4 = INPUT_HWBUTTONS; i4 < 14; i4 += INPUT_HWBUTTONS) {
                padSize = this.mePSXeReadPreferences.getPadSize("Pad1PosXAnalog" + i4);
                padSize2 = this.mePSXeReadPreferences.getPadSize("Pad1PosYAnalog" + i4);
                if (padSize != -1.0f) {
                    this.padOffScreenLan[INPUT_HWBUTTONS][(i4 - 1) * 2] = padSize;
                    this.padOffScreenLan[INPUT_HWBUTTONS][((i4 - 1) * 2) + INPUT_HWBUTTONS] = padSize2;
                }
            }
            for (i4 = 14; i4 < 20; i4 += INPUT_HWBUTTONS) {
                padSize = this.mePSXeReadPreferences.getPadSize("Pad1PosXAnalog" + i4);
                padSize2 = this.mePSXeReadPreferences.getPadSize("Pad1PosYAnalog" + i4);
                if (padSize != -1.0f) {
                    this.padOffScreenLan[INPUT_HWBUTTONS][i4 * 2] = padSize;
                    this.padOffScreenLan[INPUT_HWBUTTONS][(i4 * 2) + INPUT_HWBUTTONS] = padSize2;
                }
            }
            for (i4 = INPUT_HWBUTTONS; i4 < 14; i4 += INPUT_HWBUTTONS) {
                padSize = this.mePSXeReadPreferences.getPadResize("Pad1Resize" + i4);
                if (padSize != -1.0f) {
                    this.padScreenResize[0][i4 - 1] = padSize;
                }
            }
            for (i4 = 14; i4 < 20; i4 += INPUT_HWBUTTONS) {
                padSize = this.mePSXeReadPreferences.getPadResize("Pad1Resize" + i4);
                if (padSize != -1.0f) {
                    this.padScreenResize[0][i4] = padSize;
                }
            }
            for (i4 = INPUT_HWBUTTONS; i4 < 14; i4 += INPUT_HWBUTTONS) {
                padSize = this.mePSXeReadPreferences.getPadResize("Pad1ResizeAnalog" + i4);
                if (padSize != -1.0f) {
                    this.padScreenResize[INPUT_HWBUTTONS][i4 - 1] = padSize;
                }
            }
            while (i3 < 20) {
                float padResize = this.mePSXeReadPreferences.getPadResize("Pad1ResizeAnalog" + i3);
                if (padResize != -1.0f) {
                    this.padScreenResize[INPUT_HWBUTTONS][i3] = padResize;
                }
                i3 += INPUT_HWBUTTONS;
            }
            loadExtraButtons();
        } else {
            Log.e("epsxepadeditor", "setting default pad info");
            i3 = this.mode;
            this.mode = 0;
            resetPad1Values();
            this.mode = INPUT_HWBUTTONS;
            resetPad1Values();
            this.mode = i3;
        }
        resetPadAllValues();
        this.initvirtualPad = 0;
        if (this.emu_player_mode != INPUT_HWBUTTONS) {
            return;
        }
        if (this.emu_pad_mode[0] == INPUT_HWBUTTONS || this.emu_pad_mode[0] == 4) {
            if (this.emu_screen_orientation == INPUT_HWBUTTONS) {
                init_motionevent_1playerPortrait();
            } else {
                init_motionevent_1playerLandscape();
            }
        } else if (this.emu_pad_mode[0] == 3) {
            init_motionevent_1playerGun();
        }
    }

    public void resetPad1Values() {
        int i = 0;
        if (this.mWidth <= 600) {
            this.padResize = 0.8f;
        } else if (this.mWidth > 600 && this.mWidth <= 800) {
            this.padResize = 1.0f;
        } else if (this.mWidth <= 800 || this.mWidth > 1280) {
            this.padResize = 1.5f;
        } else {
            this.padResize = 1.35f;
        }
        float[][] fArr = new float[][]{new float[]{228.0f, 228.0f, 224.0f, 248.0f, 66.0f, 50.0f, 66.0f, 62.0f, 64.0f, 60.0f, 64.0f, 60.0f, 64.0f, 60.0f, 64.0f, 60.0f, 53.0f, 41.0f, 64.0f, 60.0f, 64.0f, 60.0f, 222.0f, 222.0f, 222.0f, 222.0f, 71.0f, 71.0f, 64.0f, 64.0f, 64.0f, 64.0f, 64.0f, 64.0f, 64.0f, 64.0f, 64.0f, 64.0f, 64.0f, 64.0f}, new float[]{228.0f, 228.0f, 224.0f, 248.0f, 66.0f, 50.0f, 66.0f, 62.0f, 64.0f, 60.0f, 64.0f, 60.0f, 64.0f, 60.0f, 64.0f, 60.0f, 53.0f, 41.0f, 64.0f, 60.0f, 64.0f, 60.0f, 222.0f, 222.0f, 222.0f, 222.0f, 71.0f, 71.0f, 64.0f, 64.0f, 64.0f, 64.0f, 64.0f, 64.0f, 64.0f, 64.0f, 64.0f, 64.0f, 64.0f, 64.0f}};
        for (int i2 = 0; i2 < 20; i2 += INPUT_HWBUTTONS) {
            this.padSizeScreenLan[this.mode][(i2 * 2) + 0] = fArr[this.mode][(i2 * 2) + 0] * this.padResize;
            this.padSizeScreenLan[this.mode][(i2 * 2) + INPUT_HWBUTTONS] = fArr[this.mode][(i2 * 2) + INPUT_HWBUTTONS] * this.padResize;
        }
        r1 = new float[2][];
        r1[0] = new float[]{this.padSizeScreenLan[0][0] / 2.0f, this.padSizeScreenLan[0][INPUT_HWBUTTONS] / 2.0f, ((float) this.mWidth) - (this.padSizeScreenLan[0][2] / 2.0f), this.padSizeScreenLan[0][3] / 2.0f, (((float) (this.mWidth / 2)) - this.padSizeScreenLan[0][4]) - 30.0f, this.padSizeScreenLan[0][5] / 2.0f, (float) ((this.mWidth / 2) + 30), this.padSizeScreenLan[0][7] / 2.0f, this.padSizeScreenLan[0][ACTION_POINTER_INDEX_SHIFT] / 2.0f, ((float) this.mHeight) - (this.padSizeScreenLan[0][9] / 2.0f), (this.padSizeScreenLan[0][10] / 2.0f) + this.padSizeScreenLan[0][ACTION_POINTER_INDEX_SHIFT], ((float) this.mHeight) - (this.padSizeScreenLan[0][11] / 2.0f), ((float) this.mWidth) - (this.padSizeScreenLan[0][12] / 2.0f), ((float) this.mHeight) - (this.padSizeScreenLan[0][13] / 2.0f), (((float) this.mWidth) - (this.padSizeScreenLan[0][14] / 2.0f)) - this.padSizeScreenLan[0][12], ((float) this.mHeight) - (this.padSizeScreenLan[0][15] / 2.0f), ((float) ((this.mWidth / 2) + 40)) + this.padSizeScreenLan[0][6], this.padSizeScreenLan[0][17] / 2.0f, ((this.padSizeScreenLan[0][18] / 2.0f) + this.padSizeScreenLan[0][10]) + this.padSizeScreenLan[0][ACTION_POINTER_INDEX_SHIFT], ((float) this.mHeight) - (this.padSizeScreenLan[0][19] / 2.0f), ((((float) this.mWidth) - (this.padSizeScreenLan[0][20] / 2.0f)) - this.padSizeScreenLan[0][12]) - this.padSizeScreenLan[0][14], ((float) this.mHeight) - (this.padSizeScreenLan[0][21] / 2.0f), this.padSizeScreenLan[0][22] / 2.0f, this.padSizeScreenLan[0][23] / 2.0f, ((float) this.mWidth) - (this.padSizeScreenLan[0][24] / 2.0f), this.padSizeScreenLan[0][25] / 2.0f, ((float) (this.mWidth / 2)) - (0.76f * (this.padSizeScreenLan[INPUT_HWBUTTONS][0] / 2.0f)), (float) (this.mHeight / 2), ((float) this.mWidth) - (this.padSizeScreenLan[INPUT_HWBUTTONS][2] / 2.0f), this.padSizeScreenLan[INPUT_HWBUTTONS][3] / 2.0f, 0.0f, 0.0f, this.padSizeScreenLan[0][28] / 2.0f, (((float) this.mHeight) - (this.padSizeScreenLan[0][29] / 2.0f)) - (this.padSizeScreenLan[0][10] * 2.0f), (this.padSizeScreenLan[0][30] / 2.0f) + this.padSizeScreenLan[0][28], (((float) this.mHeight) - (this.padSizeScreenLan[0][31] / 2.0f)) - (this.padSizeScreenLan[0][10] * 2.0f), ((this.padSizeScreenLan[0][32] / 2.0f) + this.padSizeScreenLan[0][28]) + this.padSizeScreenLan[0][30], (((float) this.mHeight) - (this.padSizeScreenLan[0][33] / 2.0f)) - (this.padSizeScreenLan[0][10] * 2.0f), ((float) this.mWidth) - (this.padSizeScreenLan[0][34] / 2.0f), (((float) this.mHeight) - (this.padSizeScreenLan[0][35] / 2.0f)) - (this.padSizeScreenLan[0][10] * 2.0f), (((float) this.mWidth) - (this.padSizeScreenLan[0][36] / 2.0f)) - this.padSizeScreenLan[0][34], (((float) this.mHeight) - (this.padSizeScreenLan[0][37] / 2.0f)) - (this.padSizeScreenLan[0][10] * 2.0f), ((((float) this.mWidth) - (this.padSizeScreenLan[0][38] / 2.0f)) - this.padSizeScreenLan[0][34]) - this.padSizeScreenLan[0][36], (((float) this.mHeight) - (this.padSizeScreenLan[0][39] / 2.0f)) - (this.padSizeScreenLan[0][10] * 2.0f)};
        r1[INPUT_HWBUTTONS] = new float[]{((float) (this.mWidth / 2)) - (0.76f * (this.padSizeScreenLan[INPUT_HWBUTTONS][0] / 2.0f)), (float) (this.mHeight / 2), ((float) this.mWidth) - (this.padSizeScreenLan[INPUT_HWBUTTONS][2] / 2.0f), this.padSizeScreenLan[INPUT_HWBUTTONS][3] / 2.0f, (((float) (this.mWidth / 2)) - this.padSizeScreenLan[INPUT_HWBUTTONS][4]) - 30.0f, this.padSizeScreenLan[INPUT_HWBUTTONS][5] / 2.0f, (float) ((this.mWidth / 2) + 30), this.padSizeScreenLan[INPUT_HWBUTTONS][7] / 2.0f, this.padSizeScreenLan[INPUT_HWBUTTONS][ACTION_POINTER_INDEX_SHIFT] / 2.0f, ((float) this.mHeight) - (this.padSizeScreenLan[INPUT_HWBUTTONS][9] / 2.0f), (this.padSizeScreenLan[INPUT_HWBUTTONS][10] / 2.0f) + this.padSizeScreenLan[INPUT_HWBUTTONS][ACTION_POINTER_INDEX_SHIFT], ((float) this.mHeight) - (this.padSizeScreenLan[INPUT_HWBUTTONS][11] / 2.0f), ((float) this.mWidth) - (this.padSizeScreenLan[INPUT_HWBUTTONS][12] / 2.0f), ((float) this.mHeight) - (this.padSizeScreenLan[INPUT_HWBUTTONS][13] / 2.0f), (((float) this.mWidth) - (this.padSizeScreenLan[INPUT_HWBUTTONS][14] / 2.0f)) - this.padSizeScreenLan[INPUT_HWBUTTONS][12], ((float) this.mHeight) - (this.padSizeScreenLan[INPUT_HWBUTTONS][15] / 2.0f), ((float) ((this.mWidth / 2) + 40)) + this.padSizeScreenLan[INPUT_HWBUTTONS][6], this.padSizeScreenLan[INPUT_HWBUTTONS][17] / 2.0f, ((this.padSizeScreenLan[INPUT_HWBUTTONS][18] / 2.0f) + this.padSizeScreenLan[INPUT_HWBUTTONS][10]) + this.padSizeScreenLan[INPUT_HWBUTTONS][ACTION_POINTER_INDEX_SHIFT], ((float) this.mHeight) - (this.padSizeScreenLan[INPUT_HWBUTTONS][19] / 2.0f), ((((float) this.mWidth) - (this.padSizeScreenLan[INPUT_HWBUTTONS][20] / 2.0f)) - this.padSizeScreenLan[INPUT_HWBUTTONS][12]) - this.padSizeScreenLan[INPUT_HWBUTTONS][14], ((float) this.mHeight) - (this.padSizeScreenLan[INPUT_HWBUTTONS][21] / 2.0f), this.padSizeScreenLan[INPUT_HWBUTTONS][22] / 2.0f, this.padSizeScreenLan[INPUT_HWBUTTONS][23] / 2.0f, ((float) (this.mWidth / 2)) + (0.76f * (this.padSizeScreenLan[INPUT_HWBUTTONS][24] / 2.0f)), (float) (this.mHeight / 2), 0.0f, 0.0f, this.padSizeScreenLan[INPUT_HWBUTTONS][28] / 2.0f, (((float) this.mHeight) - (this.padSizeScreenLan[INPUT_HWBUTTONS][29] / 2.0f)) - (this.padSizeScreenLan[INPUT_HWBUTTONS][10] * 2.0f), (this.padSizeScreenLan[INPUT_HWBUTTONS][30] / 2.0f) + this.padSizeScreenLan[INPUT_HWBUTTONS][28], (((float) this.mHeight) - (this.padSizeScreenLan[INPUT_HWBUTTONS][31] / 2.0f)) - (this.padSizeScreenLan[INPUT_HWBUTTONS][10] * 2.0f), ((this.padSizeScreenLan[INPUT_HWBUTTONS][32] / 2.0f) + this.padSizeScreenLan[INPUT_HWBUTTONS][28]) + this.padSizeScreenLan[INPUT_HWBUTTONS][30], (((float) this.mHeight) - (this.padSizeScreenLan[INPUT_HWBUTTONS][33] / 2.0f)) - (this.padSizeScreenLan[INPUT_HWBUTTONS][10] * 2.0f), ((float) this.mWidth) - (this.padSizeScreenLan[INPUT_HWBUTTONS][34] / 2.0f), (((float) this.mHeight) - (this.padSizeScreenLan[INPUT_HWBUTTONS][35] / 2.0f)) - (this.padSizeScreenLan[INPUT_HWBUTTONS][10] * 2.0f), (((float) this.mWidth) - (this.padSizeScreenLan[INPUT_HWBUTTONS][36] / 2.0f)) - this.padSizeScreenLan[INPUT_HWBUTTONS][34], (((float) this.mHeight) - (this.padSizeScreenLan[INPUT_HWBUTTONS][37] / 2.0f)) - (this.padSizeScreenLan[INPUT_HWBUTTONS][10] * 2.0f), ((((float) this.mWidth) - (this.padSizeScreenLan[INPUT_HWBUTTONS][38] / 2.0f)) - this.padSizeScreenLan[INPUT_HWBUTTONS][34]) - this.padSizeScreenLan[INPUT_HWBUTTONS][36], (((float) this.mHeight) - (this.padSizeScreenLan[INPUT_HWBUTTONS][39] / 2.0f)) - (this.padSizeScreenLan[INPUT_HWBUTTONS][10] * 2.0f)};
        while (i < 20) {
            this.padOffScreenLan[this.mode][(i * 2) + 0] = r1[this.mode][(i * 2) + 0];
            this.padOffScreenLan[this.mode][(i * 2) + INPUT_HWBUTTONS] = r1[this.mode][(i * 2) + INPUT_HWBUTTONS];
            i += INPUT_HWBUTTONS;
        }
        if (this.mWidth <= 600) {
            this.padResize = 0.8f;
        } else if (this.mWidth > 600 && this.mWidth <= 800) {
            this.padResize = 1.0f;
        } else if (this.mWidth <= 800 || this.mWidth > 1280) {
            this.padResize = 1.5f;
        } else {
            this.padResize = 1.35f;
        }
    }

    public void resetPadAllValues() {
        int i;
        if (this.mWidth <= 600) {
            this.padResize = 0.8f;
        } else if (this.mWidth > 600 && this.mWidth <= 800) {
            this.padResize = 1.0f;
        } else if (this.mWidth <= 800 || this.mWidth > 1280) {
            this.padResize = 1.5f;
        } else {
            this.padResize = 1.35f;
        }
        float[] fArr = new float[]{(float) this.mWidth, (float) (this.mHeight / 2)};
        float[] fArr2 = new float[]{(float) (this.mWidth / 2), (float) (this.mHeight / 4)};
        for (i = 0; i < INPUT_HWBUTTONS; i += INPUT_HWBUTTONS) {
            this.padSizeScreenPor[(i * 2) + 0] = fArr[(i * 2) + 0];
            this.padSizeScreenPor[(i * 2) + INPUT_HWBUTTONS] = fArr[(i * 2) + INPUT_HWBUTTONS];
            this.padOffScreenPor[(i * 2) + 0] = fArr2[(i * 2) + 0];
            this.padOffScreenPor[(i * 2) + INPUT_HWBUTTONS] = fArr2[(i * 2) + INPUT_HWBUTTONS];
        }
        fArr = new float[]{228.0f, 114.0f, 224.0f, 124.0f, 66.0f, 25.0f, 66.0f, 31.0f, 64.0f, 30.0f, 64.0f, 30.0f, 64.0f, 30.0f, 64.0f, 30.0f};
        for (i = 0; i < ACTION_POINTER_INDEX_SHIFT; i += INPUT_HWBUTTONS) {
            this.padSizeScreenLan2H[(i * 2) + 0] = fArr[(i * 2) + 0] * this.padResize;
            this.padSizeScreenLan2H[(i * 2) + INPUT_HWBUTTONS] = fArr[(i * 2) + INPUT_HWBUTTONS] * this.padResize;
        }
        fArr = new float[]{this.padSizeScreenLan2H[0] / 2.0f, this.padSizeScreenLan2H[INPUT_HWBUTTONS] / 2.0f, ((float) this.mWidth) - (this.padSizeScreenLan2H[2] / 2.0f), this.padSizeScreenLan2H[3] / 2.0f, (((float) (this.mWidth / 2)) - this.padSizeScreenLan2H[4]) - 30.0f, this.padSizeScreenLan2H[5] / 2.0f, (float) ((this.mWidth / 2) + 30), this.padSizeScreenLan2H[7] / 2.0f, this.padSizeScreenLan2H[ACTION_POINTER_INDEX_SHIFT] / 2.0f, ((float) (this.mHeight / 2)) - (this.padSizeScreenLan2H[9] / 2.0f), (this.padSizeScreenLan2H[10] / 2.0f) + this.padSizeScreenLan2H[ACTION_POINTER_INDEX_SHIFT], ((float) (this.mHeight / 2)) - (this.padSizeScreenLan2H[11] / 2.0f), ((float) this.mWidth) - (this.padSizeScreenLan2H[12] / 2.0f), ((float) (this.mHeight / 2)) - (this.padSizeScreenLan2H[13] / 2.0f), (((float) this.mWidth) - (this.padSizeScreenLan2H[14] / 2.0f)) - this.padSizeScreenLan2H[12], ((float) (this.mHeight / 2)) - (this.padSizeScreenLan2H[15] / 2.0f)};
        for (i = 0; i < ACTION_POINTER_INDEX_SHIFT; i += INPUT_HWBUTTONS) {
            this.padOffScreenLan2H[(i * 2) + 0] = fArr[(i * 2) + 0];
            this.padOffScreenLan2H[(i * 2) + INPUT_HWBUTTONS] = fArr[(i * 2) + INPUT_HWBUTTONS];
        }
        fArr = new float[]{(float) ((this.mHeight * 228) / this.mWidth), (float) (((this.mWidth / 2) * 228) / this.mHeight), (float) ((this.mHeight * 224) / this.mWidth), (float) (((this.mWidth / 2) * 248) / this.mHeight), (float) ((this.mHeight * 66) / this.mWidth), (float) (((this.mWidth / 2) * 40) / this.mHeight), (float) ((this.mHeight * 66) / this.mWidth), (float) (((this.mWidth / 2) * 62) / this.mHeight), (float) ((this.mHeight * 64) / this.mWidth), (float) (((this.mWidth / 2) * 60) / this.mHeight), (float) ((this.mHeight * 64) / this.mWidth), (float) (((this.mWidth / 2) * 60) / this.mHeight), (float) ((this.mHeight * 64) / this.mWidth), (float) (((this.mWidth / 2) * 60) / this.mHeight), (float) ((this.mHeight * 64) / this.mWidth), (float) (((this.mWidth / 2) * 60) / this.mHeight)};
        for (i = 0; i < ACTION_POINTER_INDEX_SHIFT; i += INPUT_HWBUTTONS) {
            this.padSizeScreenLan2V[(i * 2) + 0] = fArr[(i * 2) + 0] * this.padResize;
            this.padSizeScreenLan2V[(i * 2) + INPUT_HWBUTTONS] = fArr[(i * 2) + INPUT_HWBUTTONS] * this.padResize;
        }
        fArr = new float[]{this.padSizeScreenLan2V[0] / 2.0f, this.padSizeScreenLan2V[INPUT_HWBUTTONS] / 2.0f, ((float) this.mHeight) - (this.padSizeScreenLan2V[2] / 2.0f), this.padSizeScreenLan2V[3] / 2.0f, (((float) (this.mHeight / 2)) - this.padSizeScreenLan2V[4]) - 30.0f, this.padSizeScreenLan2V[5] / 2.0f, (float) ((this.mHeight / 2) + 30), this.padSizeScreenLan2V[7] / 2.0f, this.padSizeScreenLan2V[ACTION_POINTER_INDEX_SHIFT] / 2.0f, ((float) (this.mWidth / 2)) - (this.padSizeScreenLan2V[9] / 2.0f), (this.padSizeScreenLan2V[10] / 2.0f) - this.padSizeScreenLan2V[ACTION_POINTER_INDEX_SHIFT], ((float) (this.mWidth / 2)) - (this.padSizeScreenLan2V[11] / 2.0f), ((float) this.mHeight) - (this.padSizeScreenLan2V[12] / 2.0f), ((float) (this.mWidth / 2)) - (this.padSizeScreenLan2V[13] / 2.0f), (((float) this.mHeight) - (this.padSizeScreenLan2V[14] / 2.0f)) - this.padSizeScreenLan2V[12], ((float) (this.mWidth / 2)) - (this.padSizeScreenLan2V[15] / 2.0f)};
        for (i = 0; i < ACTION_POINTER_INDEX_SHIFT; i += INPUT_HWBUTTONS) {
            this.padOffScreenLan2V[(i * 2) + 0] = fArr[(i * 2) + 0];
            this.padOffScreenLan2V[(i * 2) + INPUT_HWBUTTONS] = fArr[(i * 2) + INPUT_HWBUTTONS];
        }
        this.initvirtualPad = 0;
    }

    public void setIsoName(String str, int i, String str2) {
        this.mIsoName = str;
        this.mIsoSlot = i;
        System.load(str2);
        initPluginGL();
    }

    public void setSaveslot(int i) {
        this.screenshot = i;
    }

    public void setanalogdebug(int i, int i2, int i3, int i4) {
    }

    public void setdebugstring(String str) {
    }

    public void setdebugstring2(String str) {
    }

    public void setePSXeLib(libepsxe com_epsxe_ePSXe_libepsxe) {
        this.f640e = com_epsxe_ePSXe_libepsxe;
    }

    public void setfps(int i) {
    }

    public void setframeskip(int i) {
        this.emu_enable_frameskip = i;
        this.emu_enable_frameskip_tmp = i;
        Log.e("epsxeView", "FrameSkip = " + i);
        this.emu_enable_frameskip = this.f640e.setFrameSkip(this.emu_enable_frameskip);
        this.emu_enable_frameskip_tmp = this.emu_enable_frameskip;
    }

    public void setinputalpha(float f) {
    }

    public void setinputpadmode(int i, int i2, int i3, int i4) {
        if (this.emu_player_mode == INPUT_HWBUTTONS) {
            this.emu_pad_mode[0] = i;
            this.emu_pad_mode[INPUT_HWBUTTONS] = i2;
            this.f640e.setpadmode(0, i);
            this.f640e.setpadmode(INPUT_HWBUTTONS, i2);
            if (i == 4) {
                this.emu_pad_mode_analog[0] = i3;
                this.mode = i3;
                this.f640e.setpadanalogmode(0, this.emu_pad_mode_analog[0]);
            } else if (i == INPUT_HWBUTTONS) {
                this.emu_pad_mode_analog[0] = 0;
                this.mode = 0;
                this.f640e.setpadanalogmode(0, this.emu_pad_mode_analog[0]);
            }
            if (i2 == 4) {
                this.emu_pad_mode_analog[INPUT_HWBUTTONS] = i4;
                this.f640e.setpadanalogmode(INPUT_HWBUTTONS, this.emu_pad_mode_analog[INPUT_HWBUTTONS]);
            } else if (i2 == INPUT_HWBUTTONS) {
                this.emu_pad_mode_analog[INPUT_HWBUTTONS] = 0;
                this.f640e.setpadanalogmode(INPUT_HWBUTTONS, this.emu_pad_mode_analog[INPUT_HWBUTTONS]);
            }
            if (i == 4 || i == INPUT_HWBUTTONS) {
                init_motionevent_1playerLandscape();
            } else if (i == 3) {
                this.emu_pad_mode_analog[0] = INPUT_HWBUTTONS;
                this.mode = INPUT_HWBUTTONS;
                this.f640e.setpadanalogmode(0, this.emu_pad_mode_analog[0]);
                init_motionevent_1playerGun();
            }
            Log.e("epsxeView", "PadMode " + i);
            Log.e("epsxeView", "PadMode2 " + i2);
        }
    }

    public void setinputpadmodeanalog(int i) {
        if (this.emu_player_mode == INPUT_HWBUTTONS && this.emu_pad_mode[i] == 4) {
            int[] iArr = this.emu_pad_mode_analog;
            iArr[i] = iArr[i] ^ INPUT_HWBUTTONS;
            this.f640e.setpadanalogmode(i, this.emu_pad_mode_analog[i]);
        }
    }

    public void setinputpadtype(int i, int i2) {
        this.emu_pad_type[0] = i;
        this.emu_pad_type[INPUT_HWBUTTONS] = i2;
        Log.e("epsxeView", "PadType " + i);
        Log.e("epsxeView", "PadType2 " + i2);
        if (this.emu_pad_type[0] == 0) {
            this.emu_pad_type_selected = 0;
        } else {
            this.emu_pad_type_selected = INPUT_HWBUTTONS;
        }
    }

    public void setinputpaintpadmode(int i, int i2) {
        this.emu_pad_draw_mode[0] = i;
        this.emu_pad_draw_mode[INPUT_HWBUTTONS] = i2;
        Log.e("epsxeView", "PadMode " + i);
        Log.e("epsxeView", "PadMode2 " + i2);
    }

    public void setinputskinname(String str) {
        this.skinName = str;
        Log.e("epsxeView", "skinName " + str);
    }

    public void setinputvibration(int i, int i2) {
        this.ts_vibration[0] = i;
        this.ts_vibration[INPUT_HWBUTTONS] = i2;
        Log.e("epsxeView", "InputVibrate1 = " + i);
        Log.e("epsxeView", "InputVibrate2 = " + i2);
    }

    public void setlicense(boolean z) {
        this.license = z;
    }

    public void setplayermode(int i) {
        this.emu_player_mode = i;
        Log.e("epsxeView", "PlayerMode = " + i);
        this.emu_player_mode = this.f640e.setPlayerMode(this.emu_player_mode);
        if (this.emu_player_mode != 10) {
            return;
        }
        if (this.emu_screen_orientation == 0) {
            this.emu_split_mode = INPUT_HWBUTTONS;
        } else {
            this.emu_split_mode = 0;
        }
    }

    public void setscreenblackbands(int i) {
        Log.e("epsxeView", "blackbands = " + i);
    }

    public void setscreendepth(int i) {
    }

    public void setscreenorientation(int i) {
        Log.e("epsxeView", "Orientation = " + i);
        this.emu_screen_orientation = this.f640e.setscreenorientation(i);
    }

    public void setscreenratio(int i) {
        Log.e("epsxeView", "Ratio = " + i);
        this.emu_screen_ratio = i;
    }

    public void setshowfps(int i) {
        this.emu_enable_printfps = i;
        Log.e("epsxeView", "CpuShowFPS " + i);
    }

    public void setsnaprestoring(boolean z) {
        Log.e("epsxeView", "loadtmp_snap ");
        this.f640e.loadtmpsnap();
    }

    public void setsoundlatency(int i) {
        Log.e("epsxeView", "SoundLatency = " + i);
        this.emu_sound_latency = this.f640e.setSoundLatency(i);
    }

    public void setsplitmode(int i) {
        this.emu_split_mode = i;
        Log.e("epsxeView", "SplitMode = " + i);
        this.emu_split_mode = this.f640e.setSplitMode(i);
        this.initvirtualPad = 0;
    }

    public void setvideodither(int i) {
        Log.e("epsxeView", "PSX Dither = " + i);
        this.f640e.setDithering(i);
    }

    public void setvideofilter(int i) {
        Log.e("epsxeView", "Filter = " + i);
        this.emu_video_filter = i;
    }

    public void setvideofilterhw(int i) {
        Log.e("epsxeView", "PSX Filter hw = " + i);
        this.f640e.setFilterhw(i);
    }

    public void surfaceChanged(SurfaceHolder surfaceHolder, int i, int i2, int i3) {
        Log.e("epsxeviewgl2", "onSurfaceChanged");
        this.mWidth = i2;
        this.mHeight = i3;
        redoPads(this.mWidth, this.mHeight);
        this.f640e.setwh(this.mWidth, this.mHeight, this.emu_screen_ratio);
    }

    public void surfaceCreated(SurfaceHolder surfaceHolder) {
        Log.e("epsxeviewgl2", "create surface");
        this.osVersion = Integer.parseInt(VERSION.SDK);
        this.mGLThread = new EmuGLThread(this);
        this.mGLThread.start();
        setEGLContextClientVersion(2);
        setRenderer(new ePSXeRendererGL2());
    }

    public void surfaceDestroyed(SurfaceHolder surfaceHolder) {
        Object obj = INPUT_HWBUTTONS;
        this.mGLThread.requestStop();
        while (obj != null) {
            try {
                this.mGLThread.join();
                obj = null;
            } catch (InterruptedException e) {
            }
        }
        try {
            this.mGLThread.stop();
        } catch (Exception e2) {
        }
        this.f640e.quit();
    }

    public void toggleStickyButton(int i, int i2) {
        int[] iArr = this.stickyButton;
        iArr[i] = iArr[i] ^ INPUT_HWBUTTONS;
        if (this.stickyButton[i] == 0) {
            this.f640e.setPadDataUp(i2 & 65535, 0);
        } else {
            this.f640e.setPadDataDown(i2 & 65535, 0);
        }
    }

    public void toggleframelimit() {
        if (this.emu_enable_framelimit == INPUT_HWBUTTONS) {
            this.emu_enable_frameskip_tmp = this.emu_enable_frameskip;
            this.emu_enable_frameskip = 0;
            this.emu_enable_frameskip = this.f640e.setFrameSkip(this.emu_enable_frameskip);
            this.emu_enable_framelimit ^= INPUT_HWBUTTONS;
            this.emu_enable_framelimit = this.f640e.setFrameLimit(this.emu_enable_framelimit);
            return;
        }
        this.emu_enable_frameskip = this.emu_enable_frameskip_tmp;
        this.emu_enable_frameskip = this.f640e.setFrameSkip(this.emu_enable_frameskip);
        this.emu_enable_framelimit ^= INPUT_HWBUTTONS;
        this.emu_enable_framelimit = this.f640e.setFrameLimit(this.emu_enable_framelimit);
    }

    public void toggletools() {
        this.emu_enable_tools ^= INPUT_HWBUTTONS;
        this.emu_opengl_options = this.f640e.gpugetoptiongl();
        Log.e("epsxeView", "emu_opengl_options " + this.emu_opengl_options);
    }

    public int touchscreenevent(long j, int i, int i2, int i3, float f, float f2, int i4, int i5, int i6) {
        int i7;
        Object obj;
        int i8 = this.emu_player_mode == INPUT_HWBUTTONS ? 20 : 40;
        int i9 = 0;
        if (this.emu_pad_mode[this.emu_pad_type_selected] == 4) {
            i9 = 0;
            if (this.emu_pad_mode_analog[this.emu_pad_type_selected] == INPUT_HWBUTTONS) {
                i9 = 2;
            }
        }
        if (this.emu_screen_orientation == INPUT_HWBUTTONS) {
            i9 = 0;
        }
        int i10 = 0;
        if (this.padScreenExtraCombo == INPUT_HWBUTTONS) {
            i10 = i9 != 0 ? 6 : ACTION_POINTER_INDEX_SHIFT;
        }
        if (this.initvirtualPad == 0) {
            if (this.emu_player_mode == INPUT_HWBUTTONS) {
                if (this.emu_screen_orientation == INPUT_HWBUTTONS) {
                    init_motionevent_1playerPortrait();
                } else {
                    init_motionevent_1playerLandscape();
                }
            } else if (this.emu_split_mode == 0) {
                init_motionevent_2playerV();
            } else if (this.emu_split_mode == INPUT_HWBUTTONS) {
                init_motionevent_2playerH(0);
            } else if (this.emu_split_mode == 2) {
                init_motionevent_2playerH(INPUT_HWBUTTONS);
            }
        }
        if (i == 2) {
            i7 = 0;
            obj = INPUT_HWBUTTONS;
        } else {
            obj = null;
            i7 = i;
        }
        if (i7 == 261 || i7 == 5 || i7 == 517) {
            i7 = 0;
        }
        int i11 = (i7 == 262 || i7 == 6 || i7 == 518) ? INPUT_HWBUTTONS : i7;
        if (i11 == INPUT_HWBUTTONS && this.virtualPadId[i5] != -1) {
            i7 = this.virtualPadId[i5];
            if (i7 < 20) {
                if ((65536 & this.virtualPadBit[i7]) == 65536) {
                    this.f640e.setPadDataUp(this.virtualPadBit[i7] & 65535, 0);
                } else {
                    this.f640e.setPadDataUp(0, this.virtualPadBit[i7] & 65535);
                }
            } else if (i7 < 22) {
                this.f640e.setpadanalog(((this.virtualPadBit[i7] >> 16) & INPUT_HWBUTTONS) ^ INPUT_HWBUTTONS, i7 - 20, 0, 0);
                if (i7 == 20) {
                    this.analog_values[0][0] = ((this.virtualPadPos[i7][2] - this.virtualPadPos[i7][0]) / 2) + this.virtualPadPos[i7][0];
                    this.analog_values[0][INPUT_HWBUTTONS] = this.mHeight - (((this.virtualPadPos[i7][3] - this.virtualPadPos[i7][INPUT_HWBUTTONS]) / 2) + this.virtualPadPos[i7][INPUT_HWBUTTONS]);
                }
                if (i7 == 21) {
                    this.analog_values[0][2] = ((this.virtualPadPos[i7][2] - this.virtualPadPos[i7][0]) / 2) + this.virtualPadPos[i7][0];
                    this.analog_values[0][3] = this.mHeight - (this.virtualPadPos[i7][INPUT_HWBUTTONS] + ((this.virtualPadPos[i7][3] - this.virtualPadPos[i7][INPUT_HWBUTTONS]) / 2));
                }
            } else if (i7 > 22 && i7 < 29) {
                if ((65536 & this.virtualPadBit[i7]) == 65536) {
                    this.f640e.setPadDataUp(this.virtualPadBit[i7] & 65535, 0);
                } else {
                    this.f640e.setPadDataUp(0, this.virtualPadBit[i7] & 65535);
                }
            }
            this.virtualPadId[i5] = -1;
        }
        if (i11 != 0) {
            return 0;
        }
        int i12;
        Object obj2;
        if (this.emu_pad_mode[this.emu_pad_type_selected] == 4 && obj == null && i2 >= this.virtualPadPos[22][0] && i2 <= this.virtualPadPos[22][2] && i3 >= this.virtualPadPos[22][INPUT_HWBUTTONS] && i3 <= this.virtualPadPos[22][3]) {
            int[] iArr = this.emu_pad_mode_analog;
            i12 = this.emu_pad_type_selected;
            iArr[i12] = iArr[i12] ^ INPUT_HWBUTTONS;
            this.mode = this.emu_pad_mode_analog[this.emu_pad_type_selected];
            this.f640e.setpadanalogmode(this.emu_pad_type_selected, this.emu_pad_mode_analog[this.emu_pad_type_selected]);
            init_motionevent_1playerLandscape();
        }
        if (this.emu_enable_tools == INPUT_HWBUTTONS && obj == null && ((float) i2) >= (((float) this.mWidth) - (508.0f * this.padResize)) / 2.0f && ((float) i2) <= ((((float) this.mWidth) - (508.0f * this.padResize)) / 2.0f) + (508.0f * this.padResize) && i3 >= 0 && ((float) i3) <= 60.0f * this.padResize) {
            exec_tools(i2, i3);
        }
        if (obj == null && this.padScreenExtraEnabled == INPUT_HWBUTTONS) {
            i7 = 0;
            while (i7 < 6) {
                if (this.padScreenFunc[i7] == INPUT_HWBUTTONS && i2 >= this.virtualPadPos[i7 + 23][0] && i2 <= this.virtualPadPos[i7 + 23][2] && i3 >= this.virtualPadPos[i7 + 23][INPUT_HWBUTTONS] && i3 <= this.virtualPadPos[i7 + 23][3]) {
                    if (this.padScreenExtra[i7] < 5) {
                        this.f640e.setsslot(this.padScreenExtra[i7]);
                    } else if (this.padScreenExtra[i7] < 10) {
                        this.f640e.setsslot(this.padScreenExtra[i7] + 5);
                        setSaveslot(this.padScreenExtra[i7] + 5);
                    } else if (this.padScreenExtra[i7] != 16) {
                        if (this.padScreenExtra[i7] == 18) {
                            toggleframelimit();
                        } else if (this.padScreenExtra[i7] == 20) {
                            toggleStickyButton(0, InputList.KEYCODE_MEDIA_CLOSE);
                        } else if (this.padScreenExtra[i7] == 21) {
                            toggleStickyButton(INPUT_HWBUTTONS, 64);
                        } else if (this.padScreenExtra[i7] == 22) {
                            toggleStickyButton(2, 32);
                        } else if (this.padScreenExtra[i7] == 23) {
                            toggleStickyButton(3, 16);
                        } else if (this.padScreenExtra[i7] == 24) {
                            toggleStickyButton(4, 4);
                        } else if (this.padScreenExtra[i7] == 25) {
                            toggleStickyButton(5, INPUT_HWBUTTONS);
                        } else if (this.padScreenExtra[i7] == 26) {
                            toggleStickyButton(6, ACTION_POINTER_INDEX_SHIFT);
                        } else if (this.padScreenExtra[i7] == 27) {
                            toggleStickyButton(7, 2);
                        }
                    }
                }
                i7 += INPUT_HWBUTTONS;
            }
        }
        i12 = 0;
        while (i12 < i10 + (i8 + i9)) {
            if (i2 < this.virtualPadPos[i12][0] || i2 > this.virtualPadPos[i12][2] || i3 < this.virtualPadPos[i12][INPUT_HWBUTTONS] || i3 > this.virtualPadPos[i12][3] || i11 != 0) {
                i12 += INPUT_HWBUTTONS;
            } else {
                if (this.virtualPadId[i5] != -1) {
                    i8 = this.virtualPadId[i5];
                    if (i8 < 20 || this.emu_player_mode != INPUT_HWBUTTONS) {
                        if ((65536 & this.virtualPadBit[i8]) == 65536) {
                            this.f640e.setPadDataUp(this.virtualPadBit[i8] & 65535, 0);
                        } else {
                            this.f640e.setPadDataUp(0, this.virtualPadBit[i8] & 65535);
                        }
                    } else if (i8 < 22 && i9 != 0) {
                        this.f640e.setpadanalog(((this.virtualPadBit[i8] >> 16) & INPUT_HWBUTTONS) ^ INPUT_HWBUTTONS, i8 - 20, 0, 0);
                        if (i8 == 20) {
                            this.analog_values[0][0] = ((this.virtualPadPos[i8][2] - this.virtualPadPos[i8][0]) / 2) + this.virtualPadPos[i8][0];
                            this.analog_values[0][INPUT_HWBUTTONS] = this.mHeight - (((this.virtualPadPos[i8][3] - this.virtualPadPos[i8][INPUT_HWBUTTONS]) / 2) + this.virtualPadPos[i8][INPUT_HWBUTTONS]);
                        }
                        if (i8 == 21) {
                            this.analog_values[0][2] = ((this.virtualPadPos[i8][2] - this.virtualPadPos[i8][0]) / 2) + this.virtualPadPos[i8][0];
                            this.analog_values[0][3] = this.mHeight - (this.virtualPadPos[i8][INPUT_HWBUTTONS] + ((this.virtualPadPos[i8][3] - this.virtualPadPos[i8][INPUT_HWBUTTONS]) / 2));
                        }
                    } else if (i8 > 22 && i8 < 29) {
                        if ((65536 & this.virtualPadBit[i8]) == 65536) {
                            this.f640e.setPadDataUp(this.virtualPadBit[i8] & 65535, 0);
                        } else {
                            this.f640e.setPadDataUp(0, this.virtualPadBit[i8] & 65535);
                        }
                    }
                }
                if (i12 < 20 || this.emu_player_mode != INPUT_HWBUTTONS) {
                    if ((65536 & this.virtualPadBit[i12]) == 65536) {
                        this.f640e.setPadDataDown(65535 & this.virtualPadBit[i12], 0);
                    } else {
                        this.f640e.setPadDataDown(0, 65535 & this.virtualPadBit[i12]);
                    }
                } else if (i12 < 22 && i9 != 0) {
                    i8 = ((i2 - this.virtualPadPos[i12][0]) * 255) / (this.virtualPadPos[i12][2] - this.virtualPadPos[i12][0]);
                    i9 = ((i3 - this.virtualPadPos[i12][INPUT_HWBUTTONS]) * 255) / (this.virtualPadPos[i12][3] - this.virtualPadPos[i12][INPUT_HWBUTTONS]);
                    i10 = ((this.virtualPadBit[i12] >> 16) & INPUT_HWBUTTONS) ^ INPUT_HWBUTTONS;
                    if (i12 == 20) {
                        this.analog_values[0][0] = i2;
                        this.analog_values[0][INPUT_HWBUTTONS] = this.mHeight - i3;
                    }
                    if (i12 == 21) {
                        this.analog_values[0][2] = i2;
                        this.analog_values[0][3] = this.mHeight - i3;
                    }
                    this.f640e.setpadanalog(i10, i12 - 20, i8 - 128, i9 - 128);
                } else if (i12 > 22 && i12 < 29) {
                    if ((65536 & this.virtualPadBit[i12]) == 65536) {
                        this.f640e.setPadDataDown(65535 & this.virtualPadBit[i12], 0);
                    } else {
                        this.f640e.setPadDataDown(0, 65535 & this.virtualPadBit[i12]);
                    }
                }
                this.virtualPadId[i5] = i12;
                i8 = 0;
                if (i != 2) {
                    i8 = INPUT_HWBUTTONS;
                }
                obj2 = INPUT_HWBUTTONS;
                if (this.emu_pad_mode[this.emu_pad_type_selected] == 4 || this.emu_pad_mode_analog[this.emu_pad_type_selected] != INPUT_HWBUTTONS || r3 != null) {
                    return i8;
                }
                if (this.virtualPadId[i5] != 20 && this.virtualPadId[i5] != 21) {
                    return i8;
                }
                i7 = this.virtualPadId[i5];
                int i13 = this.virtualPadPos[i7][2] - this.virtualPadPos[i7][0];
                i10 = this.virtualPadPos[i7][3] - this.virtualPadPos[i7][INPUT_HWBUTTONS];
                i12 = ((this.virtualPadBit[i7] >> 16) & INPUT_HWBUTTONS) ^ INPUT_HWBUTTONS;
                i9 = i2 <= this.virtualPadPos[i7][0] ? 0 : i2 >= this.virtualPadPos[i7][2] ? 255 : ((i2 - this.virtualPadPos[i7][0]) * 255) / i13;
                i10 = i3 <= this.virtualPadPos[i7][INPUT_HWBUTTONS] ? 0 : i3 >= this.virtualPadPos[i7][3] ? 255 : ((i3 - this.virtualPadPos[i7][INPUT_HWBUTTONS]) * 255) / i10;
                if (i7 == 20) {
                    this.analog_values[0][0] = this.virtualPadPos[i7][0] + ((i9 * i13) / 255);
                    this.analog_values[0][INPUT_HWBUTTONS] = this.mHeight - (this.virtualPadPos[i7][INPUT_HWBUTTONS] + ((i10 * i13) / 255));
                }
                if (i7 == 21) {
                    this.analog_values[0][2] = this.virtualPadPos[i7][0] + ((i9 * i13) / 255);
                    this.analog_values[0][3] = this.mHeight - (((i13 * i10) / 255) + this.virtualPadPos[i7][INPUT_HWBUTTONS]);
                }
                this.f640e.setpadanalog(i12, i7 - 20, i9 - 128, i10 - 128);
                return i8;
            }
        }
        i8 = 0;
        obj2 = null;
        return this.emu_pad_mode[this.emu_pad_type_selected] == 4 ? i8 : i8;
    }

    public int touchscreeneventgun(long j, int i, int i2, int i3, float f, float f2, int i4, int i5, int i6) {
        if (this.initvirtualPad == 0) {
            init_motionevent_1playerGun();
        }
        int i7 = i == 2 ? 0 : i;
        if (i7 == 261 || i7 == 5 || i7 == 517) {
            i7 = 0;
        }
        int i8 = (i7 == 262 || i7 == 6 || i7 == 518) ? INPUT_HWBUTTONS : i7;
        if (i8 == INPUT_HWBUTTONS && this.virtualPadId[i5] != -1) {
            i7 = this.virtualPadId[i5];
            if (i7 < 3) {
                if (i7 == INPUT_HWBUTTONS) {
                    this.gunb1 = 0;
                }
                if (i7 == 2) {
                    this.gunb2 = 0;
                }
                if (i7 == 0) {
                    this.gunb0 = 0;
                }
                this.f640e.setGunData(0, this.gunX, this.gunY, this.gunb0, this.gunb1, this.gunb2);
            }
            this.virtualPadId[i5] = -1;
        }
        if (i8 != 0) {
            return 0;
        }
        int i9 = 0;
        while (i9 < 3) {
            if (i2 < this.virtualPadPos[i9][0] || i2 > this.virtualPadPos[i9][2] || i3 < this.virtualPadPos[i9][INPUT_HWBUTTONS] || i3 > this.virtualPadPos[i9][3] || i8 != 0) {
                i9 += INPUT_HWBUTTONS;
            } else {
                if (this.virtualPadId[i5] != -1) {
                    i7 = this.virtualPadId[i5];
                    if (i7 < 3) {
                        if (i7 == INPUT_HWBUTTONS) {
                            this.gunb1 = 0;
                        }
                        if (i7 == 2) {
                            this.gunb2 = 0;
                        }
                        if (i7 == 0) {
                            this.gunb0 = 0;
                        }
                        this.f640e.setGunData(0, this.gunX, this.gunY, this.gunb0, this.gunb1, this.gunb2);
                    }
                }
                if (i9 < 3) {
                    if (i9 == INPUT_HWBUTTONS) {
                        this.gunb1 = INPUT_HWBUTTONS;
                    }
                    if (i9 == 2) {
                        this.gunb2 = INPUT_HWBUTTONS;
                    }
                    if (i9 == 0) {
                        this.gunb0 = INPUT_HWBUTTONS;
                        this.gunX = (((i2 - ((this.mWidth - ((this.mHeight * 4) / 3)) / 2)) * 384) / ((this.mHeight * 4) / 3)) + 77;
                        if (this.mfps == 60) {
                            this.gunY = ((i3 * 223) / this.mHeight) + 25;
                        } else {
                            this.gunY = ((i3 * 263) / this.mHeight) + 32;
                        }
                    }
                    this.f640e.setGunData(0, this.gunX, this.gunY, this.gunb0, this.gunb1, this.gunb2);
                }
                this.virtualPadId[i5] = i9;
                return i != 2 ? INPUT_HWBUTTONS : 0;
            }
        }
        return 0;
    }
}
