package com.epsxe.ePSXe;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Bitmap.Config;
import android.graphics.Canvas;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.graphics.Paint.Style;
import android.graphics.Path;
import android.graphics.Rect;
import android.graphics.RectF;
import android.os.Build.VERSION;
import android.os.Vibrator;
import android.util.Log;
import android.view.MotionEvent;
import android.view.SurfaceHolder;
import android.view.SurfaceHolder.Callback;
import android.view.SurfaceView;
import java.nio.ByteBuffer;

class ePSXeViewSoft extends SurfaceView implements Callback, ePSXeView {
    public static final int ACTION_POINTER_INDEX_MASK = 65280;
    public static final int ACTION_POINTER_INDEX_SHIFT = 8;
    private static final int INPUT_HWBUTTONS = 1;
    private static final int INPUT_TOUCHSCREEN = 0;
    private ByteBuffer byteBuffer;
    private libepsxe f643e;
    private int emu_enable_framelimit;
    private int emu_enable_frameskip;
    private int emu_enable_frameskip_tmp;
    private int emu_enable_mme;
    private int emu_enable_printfps;
    private int[] emu_pad_mode;
    private int emu_pad_portrait;
    private int[] emu_pad_type;
    private int emu_player_mode;
    private int emu_screen_orientation;
    private int emu_screen_ratio;
    private int emu_sound_latency;
    private int emu_split_mode;
    private int emu_video_filter;
    private boolean license;
    private Context mContext;
    private int mfps;
    private int osVersion;
    private String skinName;
    private EmuThread thread;
    private int[] ts_vibration;

    class EmuThread extends Thread {
        public static final int STATE_AUTOSAVING = 4;
        public static final int STATE_PAUSE = 1;
        public static final int STATE_RUNNING = 2;
        public static final int STATE_SAVING = 3;
        private Rect DestRect;
        private Rect DestRectP1;
        private Rect DestRectP2;
        private Rect DestRectPartial;
        private Rect SourceRect;
        private Rect SourceRectP1;
        private Rect SourceRectP2;
        private int bitmapheight;
        private int bitmapwidth;
        private Bitmap mBitmap;
        private int mCanvasHeight;
        private int mCanvasWidth;
        private long mEmuTime;
        private int mHeight;
        private long mLastTime;
        private int mMode;
        private Paint mPaint;
        private Paint mPaintFilter;
        private boolean mRun;
        private long mStartTime;
        private SurfaceHolder mSurfaceHolder;
        private int mWidth;
        private int skippedCount;

        public EmuThread(SurfaceHolder surfaceHolder, Context context) {
            this.SourceRect = new Rect(0, 0, 0, 0);
            this.DestRect = new Rect(0, 0, 0, 0);
            this.DestRectP1 = new Rect(0, 0, 0, 0);
            this.DestRectP2 = new Rect(0, 0, 0, 0);
            this.DestRectPartial = new Rect(0, 0, 0, 0);
            this.SourceRectP1 = new Rect(0, 0, 0, 0);
            this.SourceRectP2 = new Rect(0, 0, 0, 0);
            this.mCanvasHeight = STATE_PAUSE;
            this.mCanvasWidth = STATE_PAUSE;
            this.mRun = false;
            this.mLastTime = 0;
            this.mStartTime = 0;
            this.mEmuTime = 0;
            this.skippedCount = 0;
            this.mPaint = new Paint();
            this.mPaintFilter = new Paint();
            this.mSurfaceHolder = surfaceHolder;
            ePSXeViewSoft.this.mContext = context;
        }

        private void clear(Canvas canvas) {
            Rect rect = new Rect();
            rect.set(0, 0, canvas.getWidth(), canvas.getHeight());
            Paint paint = new Paint();
            paint.setStyle(Style.FILL);
            paint.setColor(-16777216);
            canvas.drawRect(rect, paint);
        }

        private void doBlitToBitmap(int i, int i2) {
            int i3 = i & -8;
            if (i3 < i) {
                i3 += ePSXeViewSoft.ACTION_POINTER_INDEX_SHIFT;
            }
            if (i > 0 && i2 > 0 && !(i3 == this.bitmapwidth && i2 == this.bitmapheight)) {
                if (this.mBitmap != null) {
                    this.mBitmap.recycle();
                }
                this.bitmapwidth = i3;
                this.bitmapheight = i2;
                Log.e("ePSXeViewSoft", "Creating bitmap of " + i3 + " x " + i2 + " resol (" + i + "," + i2 + ")");
                this.mBitmap = Bitmap.createBitmap(this.bitmapwidth, this.bitmapheight, Config.RGB_565);
            }
            if (i > 0 && i2 > 0) {
                if (ePSXeViewSoft.this.osVersion >= ePSXeViewSoft.ACTION_POINTER_INDEX_SHIFT) {
                    ePSXeViewSoft.this.f643e.copyPixelsFromVRAMToBitmap(this.mBitmap);
                    return;
                }
                ePSXeViewSoft.this.f643e.copyPixelsFromVRAMToBuffer();
                this.mBitmap.copyPixelsFromBuffer(ePSXeViewSoft.this.byteBuffer);
                ePSXeViewSoft.this.byteBuffer.clear();
            }
        }

        private void doDraw(Canvas canvas, int i, int i2, int i3) {
            Matrix matrix;
            if (i > 0 && i2 > 0) {
                if (!(this.SourceRect.right == i && this.SourceRect.bottom == i2)) {
                    this.SourceRect.set(0, 0, i, i2);
                }
                if (!(this.DestRect != null && this.DestRect.right == canvas.getWidth() && this.DestRect.bottom == canvas.getHeight())) {
                    int width = (canvas.getWidth() - ((canvas.getHeight() * STATE_AUTOSAVING) / STATE_SAVING)) / STATE_RUNNING;
                    this.DestRect.set(0, 0, canvas.getWidth(), canvas.getHeight());
                    this.DestRectP1.set(0, 0, canvas.getHeight(), canvas.getWidth() / STATE_RUNNING);
                    this.DestRectP2.set(canvas.getWidth() - canvas.getHeight(), 0, canvas.getWidth(), canvas.getWidth() / STATE_RUNNING);
                    this.DestRectPartial.set(width, 0, ((canvas.getHeight() * STATE_AUTOSAVING) / STATE_SAVING) + width, canvas.getHeight());
                }
                if (ePSXeViewSoft.this.emu_player_mode == STATE_PAUSE) {
                    if (ePSXeViewSoft.this.emu_screen_orientation == 0) {
                        if (ePSXeViewSoft.this.emu_video_filter == STATE_PAUSE) {
                            this.mPaintFilter.setFilterBitmap(true);
                            if (ePSXeViewSoft.this.emu_screen_ratio == STATE_PAUSE) {
                                canvas.drawBitmap(this.mBitmap, null, this.DestRectPartial, this.mPaintFilter);
                            } else {
                                canvas.drawBitmap(this.mBitmap, null, this.DestRect, this.mPaintFilter);
                            }
                        } else if (ePSXeViewSoft.this.emu_screen_ratio == STATE_PAUSE) {
                            canvas.drawBitmap(this.mBitmap, null, this.DestRectPartial, null);
                        } else {
                            canvas.drawBitmap(this.mBitmap, null, this.DestRect, null);
                        }
                        doDrawVirtualPad(canvas, this.mHeight, this.mWidth, 0, 0, 0);
                        if (ePSXeViewSoft.this.emu_enable_printfps == STATE_PAUSE) {
                            if (ePSXeViewSoft.this.emu_screen_ratio == STATE_PAUSE) {
                                doDrawFPS(canvas, canvas.getHeight() / STATE_AUTOSAVING);
                            } else {
                                doDrawFPS(canvas, 0);
                            }
                        }
                    } else {
                        this.DestRectPartial.set(0, 0, canvas.getWidth(), canvas.getHeight() / STATE_RUNNING);
                        if (ePSXeViewSoft.this.emu_video_filter == STATE_PAUSE) {
                            this.mPaintFilter.setFilterBitmap(true);
                            canvas.drawBitmap(this.mBitmap, null, this.DestRectPartial, this.mPaintFilter);
                        } else {
                            canvas.drawBitmap(this.mBitmap, null, this.DestRectPartial, null);
                        }
                        if (i3 == STATE_PAUSE) {
                            doDrawVirtualPadPortrait(canvas, canvas.getHeight() / STATE_RUNNING, canvas.getWidth(), 0, canvas.getHeight() / STATE_RUNNING);
                        }
                        if (ePSXeViewSoft.this.emu_enable_printfps == STATE_PAUSE) {
                            doDrawFPS(canvas, 0);
                        }
                    }
                } else if (ePSXeViewSoft.this.emu_split_mode == 0) {
                    this.DestRectP1.set(0, 0, canvas.getHeight(), canvas.getWidth() / STATE_RUNNING);
                    this.DestRectP2.set(canvas.getWidth() - canvas.getHeight(), 0, canvas.getWidth(), canvas.getWidth() / STATE_RUNNING);
                    matrix = canvas.getMatrix();
                    matrix.setTranslate((float) ((canvas.getHeight() - (canvas.getWidth() / STATE_RUNNING)) / STATE_RUNNING), (float) ((-((canvas.getWidth() / STATE_RUNNING) - canvas.getHeight())) / STATE_RUNNING));
                    matrix.postRotate(90.0f, (float) (canvas.getHeight() / STATE_RUNNING), (float) (canvas.getWidth() / STATE_AUTOSAVING));
                    canvas.setMatrix(matrix);
                    canvas.drawBitmap(this.mBitmap, null, this.DestRectP1, null);
                    doDrawVirtualPad(canvas, canvas.getWidth() / STATE_RUNNING, canvas.getHeight(), 0, 0, 0);
                    canvas.setMatrix(matrix);
                    matrix = canvas.getMatrix();
                    matrix.setTranslate((float) ((-(canvas.getHeight() - (canvas.getWidth() / STATE_RUNNING))) / STATE_RUNNING), (float) ((-((canvas.getWidth() / STATE_RUNNING) - canvas.getHeight())) / STATE_RUNNING));
                    matrix.postRotate(270.0f, (float) ((canvas.getWidth() - canvas.getHeight()) + (canvas.getHeight() / STATE_RUNNING)), (float) (canvas.getWidth() / STATE_AUTOSAVING));
                    canvas.setMatrix(matrix);
                    canvas.drawBitmap(this.mBitmap, null, this.DestRectP2, null);
                    doDrawVirtualPad(canvas, canvas.getWidth() / STATE_RUNNING, canvas.getHeight(), canvas.getWidth() - canvas.getHeight(), 0, STATE_PAUSE);
                    canvas.setMatrix(matrix);
                } else if (ePSXeViewSoft.this.emu_split_mode == STATE_PAUSE || ePSXeViewSoft.this.emu_split_mode == STATE_RUNNING) {
                    this.DestRectP1.set(0, canvas.getHeight() / STATE_RUNNING, canvas.getWidth(), canvas.getHeight());
                    this.DestRectP2.set(0, 0, canvas.getWidth(), canvas.getHeight() / STATE_RUNNING);
                    this.SourceRectP1.set(this.SourceRect.left, this.SourceRect.bottom / STATE_RUNNING, this.SourceRect.right, this.SourceRect.bottom);
                    this.SourceRectP2.set(this.SourceRect.left, this.SourceRect.top, this.SourceRect.right, this.SourceRect.bottom / STATE_RUNNING);
                    canvas.drawBitmap(this.mBitmap, this.SourceRectP1, this.DestRectP1, null);
                    doDrawVirtualPad(canvas, canvas.getHeight() / STATE_RUNNING, canvas.getWidth(), 0, canvas.getHeight() / STATE_RUNNING, 0);
                    matrix = canvas.getMatrix();
                    matrix.setTranslate(0.0f, 0.0f);
                    matrix.postRotate(180.0f, (float) (canvas.getWidth() / STATE_RUNNING), (float) (canvas.getHeight() / STATE_AUTOSAVING));
                    canvas.setMatrix(matrix);
                    canvas.drawBitmap(this.mBitmap, this.SourceRectP2, this.DestRectP2, null);
                    doDrawVirtualPad(canvas, canvas.getHeight() / STATE_RUNNING, canvas.getWidth(), 0, 0, STATE_PAUSE);
                    canvas.setMatrix(matrix);
                }
            }
            if (i == 0 && i2 == 0) {
                clear(canvas);
                if (ePSXeViewSoft.this.emu_player_mode == STATE_PAUSE) {
                    if (ePSXeViewSoft.this.emu_screen_orientation == 0) {
                        doDrawVirtualPad(canvas, this.mHeight, this.mWidth, 0, 0, 0);
                        if (ePSXeViewSoft.this.emu_enable_printfps != STATE_PAUSE) {
                            return;
                        }
                        if (ePSXeViewSoft.this.emu_screen_ratio == STATE_PAUSE) {
                            doDrawFPS(canvas, canvas.getHeight() / STATE_AUTOSAVING);
                            return;
                        } else {
                            doDrawFPS(canvas, 0);
                            return;
                        }
                    }
                    this.DestRectPartial.set(0, 0, canvas.getWidth(), canvas.getHeight() / STATE_RUNNING);
                    if (i3 == STATE_PAUSE) {
                        doDrawVirtualPadPortrait(canvas, canvas.getHeight() / STATE_RUNNING, canvas.getWidth(), 0, canvas.getHeight() / STATE_RUNNING);
                    }
                    if (ePSXeViewSoft.this.emu_enable_printfps == STATE_PAUSE) {
                        doDrawFPS(canvas, 0);
                    }
                } else if (ePSXeViewSoft.this.emu_split_mode == 0) {
                    this.DestRectP1.set(0, 0, canvas.getHeight(), canvas.getWidth() / STATE_RUNNING);
                    this.DestRectP2.set(canvas.getWidth() - canvas.getHeight(), 0, canvas.getWidth(), canvas.getWidth() / STATE_RUNNING);
                    matrix = canvas.getMatrix();
                    matrix.setTranslate((float) ((canvas.getHeight() - (canvas.getWidth() / STATE_RUNNING)) / STATE_RUNNING), (float) ((-((canvas.getWidth() / STATE_RUNNING) - canvas.getHeight())) / STATE_RUNNING));
                    matrix.postRotate(90.0f, (float) (canvas.getHeight() / STATE_RUNNING), (float) (canvas.getWidth() / STATE_AUTOSAVING));
                    canvas.setMatrix(matrix);
                    doDrawVirtualPad(canvas, canvas.getWidth() / STATE_RUNNING, canvas.getHeight(), 0, 0, 0);
                    canvas.setMatrix(matrix);
                    matrix = canvas.getMatrix();
                    matrix.setTranslate((float) ((-(canvas.getHeight() - (canvas.getWidth() / STATE_RUNNING))) / STATE_RUNNING), (float) ((-((canvas.getWidth() / STATE_RUNNING) - canvas.getHeight())) / STATE_RUNNING));
                    matrix.postRotate(270.0f, (float) ((canvas.getWidth() - canvas.getHeight()) + (canvas.getHeight() / STATE_RUNNING)), (float) (canvas.getWidth() / STATE_AUTOSAVING));
                    canvas.setMatrix(matrix);
                    doDrawVirtualPad(canvas, canvas.getWidth() / STATE_RUNNING, canvas.getHeight(), canvas.getWidth() - canvas.getHeight(), 0, STATE_PAUSE);
                    canvas.setMatrix(matrix);
                } else if (ePSXeViewSoft.this.emu_split_mode == STATE_PAUSE || ePSXeViewSoft.this.emu_split_mode == STATE_RUNNING) {
                    this.DestRectP1.set(0, canvas.getHeight() / STATE_RUNNING, canvas.getWidth(), canvas.getHeight());
                    this.DestRectP2.set(0, 0, canvas.getWidth(), canvas.getHeight() / STATE_RUNNING);
                    doDrawVirtualPad(canvas, canvas.getHeight() / STATE_RUNNING, canvas.getWidth(), 0, canvas.getHeight() / STATE_RUNNING, 0);
                    matrix = canvas.getMatrix();
                    matrix.setTranslate(0.0f, 0.0f);
                    matrix.postRotate(180.0f, (float) (canvas.getWidth() / STATE_RUNNING), (float) (canvas.getHeight() / STATE_AUTOSAVING));
                    canvas.setMatrix(matrix);
                    doDrawVirtualPad(canvas, canvas.getHeight() / STATE_RUNNING, canvas.getWidth(), 0, 0, STATE_PAUSE);
                    canvas.setMatrix(matrix);
                }
            }
        }

        private void doDrawFPS(Canvas canvas, int i) {
            this.mPaint.setColor(-65536);
            this.mPaint.setStyle(Style.FILL);
            this.mPaint.setTextSize(30.0f);
            canvas.drawText(String.valueOf(ePSXeViewSoft.this.f643e.getFPS()) + "/" + ePSXeViewSoft.this.mfps, (float) i, 30.0f, this.mPaint);
        }

        private void doDrawVirtualPad(Canvas canvas, int i, int i2, int i3, int i4, int i5) {
            if (ePSXeViewSoft.this.emu_pad_mode[i5] != STATE_RUNNING) {
                RectF rectF = new RectF();
                if (ePSXeViewSoft.this.emu_pad_mode[i5] == STATE_PAUSE) {
                    this.mPaint.setColor(-3355444);
                    this.mPaint.setStyle(Style.FILL);
                    this.mPaint.setAlpha(1092);
                    canvas.drawCircle((float) (((i2 * InputList.KEYCODE_NUMPAD_6) / 850) + i3), (float) (((i * 360) / 480) + i4), (float) ((i * InputList.KEYCODE_BUTTON_MODE) / 480), this.mPaint);
                    this.mPaint.setColor(-7829368);
                    this.mPaint.setStyle(Style.FILL);
                    this.mPaint.setAlpha(1092);
                    canvas.drawCircle((float) (((i2 * InputList.KEYCODE_NUMPAD_6) / 850) + i3), (float) (((i * 360) / 480) + i4), (float) ((i * 80) / 480), this.mPaint);
                    this.mPaint.setColor(-12303292);
                    this.mPaint.setStyle(Style.FILL);
                    this.mPaint.setAlpha(1092);
                    canvas.drawCircle((float) (((i2 * InputList.KEYCODE_NUMPAD_6) / 850) + i3), (float) (((i * 360) / 480) + i4), (float) ((i * 20) / 480), this.mPaint);
                }
                this.mPaint.setColor(-65536);
                this.mPaint.setStyle(Style.FILL);
                this.mPaint.setAlpha(3276);
                Path path = new Path();
                path.moveTo(0.0f, 0.0f);
                path.lineTo(5.0f, 10.0f);
                path.lineTo(-5.0f, 10.0f);
                path.close();
                path.offset((float) (((i2 * InputList.KEYCODE_NUMPAD_6) / 850) + i3), (float) (((((i * 360) / 480) - ((i * 80) / 480)) - 10) + i4));
                canvas.drawPath(path, this.mPaint);
                path = new Path();
                path.moveTo(0.0f, 0.0f);
                path.lineTo(-5.0f, -10.0f);
                path.lineTo(5.0f, -10.0f);
                path.close();
                path.offset((float) (((i2 * InputList.KEYCODE_NUMPAD_6) / 850) + i3), (float) (((((i * 360) / 480) + ((i * 80) / 480)) + 10) + i4));
                canvas.drawPath(path, this.mPaint);
                path = new Path();
                path.moveTo(0.0f, 0.0f);
                path.lineTo(10.0f, -5.0f);
                path.lineTo(10.0f, 5.0f);
                path.close();
                path.offset((float) (((((i2 * InputList.KEYCODE_NUMPAD_6) / 850) - ((i * 80) / 480)) - 10) + i3), (float) (((i * 360) / 480) + i4));
                canvas.drawPath(path, this.mPaint);
                path = new Path();
                path.moveTo(0.0f, 0.0f);
                path.lineTo(-10.0f, -5.0f);
                path.lineTo(-10.0f, 5.0f);
                path.close();
                path.offset((float) (((((i2 * InputList.KEYCODE_NUMPAD_6) / 850) + ((i * 80) / 480)) + 10) + i3), (float) (((i * 360) / 480) + i4));
                canvas.drawPath(path, this.mPaint);
                this.mPaint.setColor(-3355444);
                if (ePSXeViewSoft.this.emu_pad_mode[i5] == STATE_PAUSE) {
                    this.mPaint.setStyle(Style.FILL);
                } else {
                    this.mPaint.setStyle(Style.STROKE);
                }
                this.mPaint.setAlpha(1092);
                path = new Path();
                path.moveTo(0.0f, 0.0f);
                path.lineTo((float) ((-(i * 60)) / 480), (float) ((-(i * 25)) / 480));
                path.lineTo((float) ((-(i * 60)) / 480), (float) ((i * 25) / 480));
                path.close();
                path.offset((float) (((i2 * 540) / 850) + i3), (float) ((((i * 385) / 480) + ((i * 25) / 480)) + i4));
                canvas.drawPath(path, this.mPaint);
                rectF.set((float) (((i2 * 350) / 850) + i3), (float) (((i * 390) / 480) + i4), (float) (((i2 * 410) / 850) + i3), (float) (((i * 430) / 480) + i4));
                canvas.drawRoundRect(rectF, 5.0f, 5.0f, this.mPaint);
                if (ePSXeViewSoft.this.emu_pad_mode[i5] == STATE_PAUSE) {
                    this.mPaint.setColor(-3355444);
                    this.mPaint.setStyle(Style.FILL);
                    this.mPaint.setAlpha(1092);
                    canvas.drawCircle((float) (((i2 * 655) / 850) + i3), (float) (((i * 355) / 480) + i4), (float) ((i * 40) / 480), this.mPaint);
                }
                this.mPaint.setColor(-65281);
                canvas.drawLine((float) ((((i2 * 655) / 850) - 10) + i3), (float) ((((i * 355) / 480) - 10) + i4), (float) ((((i2 * 655) / 850) + 10) + i3), (float) ((((i * 355) / 480) - 10) + i4), this.mPaint);
                canvas.drawLine((float) ((((i2 * 655) / 850) + 10) + i3), (float) ((((i * 355) / 480) - 10) + i4), (float) ((((i2 * 655) / 850) + 10) + i3), (float) ((((i * 355) / 480) + 10) + i4), this.mPaint);
                canvas.drawLine((float) ((((i2 * 655) / 850) + 10) + i3), (float) ((((i * 355) / 480) + 10) + i4), (float) ((((i2 * 655) / 850) - 10) + i3), (float) ((((i * 355) / 480) + 10) + i4), this.mPaint);
                canvas.drawLine((float) ((((i2 * 655) / 850) - 10) + i3), (float) ((((i * 355) / 480) + 10) + i4), (float) ((((i2 * 655) / 850) - 10) + i3), (float) ((((i * 355) / 480) - 10) + i4), this.mPaint);
                if (ePSXeViewSoft.this.emu_pad_mode[i5] == STATE_PAUSE) {
                    this.mPaint.setColor(-3355444);
                    this.mPaint.setStyle(Style.FILL);
                    this.mPaint.setAlpha(1092);
                    canvas.drawCircle((float) (((i2 * 725) / 850) + i3), (float) (((i * 280) / 480) + i4), (float) ((i * 40) / 480), this.mPaint);
                }
                this.mPaint.setColor(-16711936);
                canvas.drawLine((float) (((i2 * 725) / 850) + i3), (float) ((((i * 280) / 480) - 10) + i4), (float) ((((i2 * 725) / 850) + 10) + i3), (float) ((((i * 280) / 480) + 10) + i4), this.mPaint);
                canvas.drawLine((float) ((((i2 * 725) / 850) + 10) + i3), (float) ((((i * 280) / 480) + 10) + i4), (float) ((((i2 * 725) / 850) - 10) + i3), (float) ((((i * 280) / 480) + 10) + i4), this.mPaint);
                canvas.drawLine((float) ((((i2 * 725) / 850) - 10) + i3), (float) ((((i * 280) / 480) + 10) + i4), (float) (((i2 * 725) / 850) + i3), (float) ((((i * 280) / 480) - 10) + i4), this.mPaint);
                if (ePSXeViewSoft.this.emu_pad_mode[i5] == STATE_PAUSE) {
                    this.mPaint.setColor(-3355444);
                    this.mPaint.setStyle(Style.FILL);
                    this.mPaint.setAlpha(1092);
                    canvas.drawCircle((float) (((i2 * 795) / 850) + i3), (float) (((i * 355) / 480) + i4), (float) ((i * 40) / 480), this.mPaint);
                }
                this.mPaint.setColor(-65536);
                this.mPaint.setStyle(Style.STROKE);
                this.mPaint.setAlpha(1092);
                this.mPaint.setStrokeWidth(3.0f);
                canvas.drawCircle((float) (((i2 * 795) / 850) + i3), (float) (((i * 355) / 480) + i4), (float) (((i * 40) / STATE_SAVING) / 480), this.mPaint);
                if (ePSXeViewSoft.this.emu_pad_mode[i5] == STATE_PAUSE) {
                    this.mPaint.setColor(-3355444);
                    this.mPaint.setStyle(Style.FILL);
                    this.mPaint.setAlpha(1092);
                    canvas.drawCircle((float) (((i2 * 725) / 850) + i3), (float) (((i * 430) / 480) + i4), (float) ((i * 40) / 480), this.mPaint);
                }
                this.mPaint.setColor(-16776961);
                canvas.drawLine((float) ((((i2 * 725) / 850) - 10) + i3), (float) ((((i * 430) / 480) - 10) + i4), (float) ((((i2 * 725) / 850) + 10) + i3), (float) ((((i * 430) / 480) + 10) + i4), this.mPaint);
                canvas.drawLine((float) ((((i2 * 725) / 850) + 10) + i3), (float) ((((i * 430) / 480) - 10) + i4), (float) ((((i2 * 725) / 850) - 10) + i3), (float) ((((i * 430) / 480) + 10) + i4), this.mPaint);
                this.mPaint.setColor(-3355444);
                if (ePSXeViewSoft.this.emu_pad_mode[i5] == STATE_PAUSE) {
                    this.mPaint.setStyle(Style.FILL);
                } else {
                    this.mPaint.setStyle(Style.STROKE);
                }
                this.mPaint.setAlpha(1092);
                rectF.set((float) (((i2 * 90) / 850) + i3), (float) (((i * 10) / 480) + i4), (float) (((i2 * 210) / 850) + i3), (float) (((i * 60) / 480) + i4));
                canvas.drawRoundRect(rectF, 5.0f, 5.0f, this.mPaint);
                this.mPaint.setColor(-7829368);
                canvas.drawLine((float) (((i2 * InputList.KEYCODE_NUMPAD_6) / 850) + i3), (float) (((i * 10) / 480) + i4), (float) (((i2 * InputList.KEYCODE_NUMPAD_6) / 850) + i3), (float) (((i * 60) / 480) + i4), this.mPaint);
                this.mPaint.setColor(-12303292);
                canvas.drawLine((float) (((i2 * InputList.KEYCODE_SYSRQ) / 850) + i3), (float) (((i * 20) / 480) + i4), (float) (((i2 * InputList.KEYCODE_SYSRQ) / 850) + i3), (float) (((i * 50) / 480) + i4), this.mPaint);
                canvas.drawLine((float) (((i2 * InputList.KEYCODE_TV_POWER) / 850) + i3), (float) (((i * 20) / 480) + i4), (float) (((i2 * InputList.KEYCODE_TV_POWER) / 850) + i3), (float) (((i * 50) / 480) + i4), this.mPaint);
                canvas.drawLine((float) (((i2 * InputList.KEYCODE_AVR_INPUT) / 850) + i3), (float) (((i * 20) / 480) + i4), (float) (((i2 * InputList.KEYCODE_AVR_INPUT) / 850) + i3), (float) (((i * 50) / 480) + i4), this.mPaint);
                this.mPaint.setColor(-3355444);
                if (ePSXeViewSoft.this.emu_pad_mode[i5] == STATE_PAUSE) {
                    this.mPaint.setStyle(Style.FILL);
                } else {
                    this.mPaint.setStyle(Style.STROKE);
                }
                this.mPaint.setAlpha(1092);
                rectF.set((float) (((i2 * 680) / 850) + i3), (float) (((i * 10) / 480) + i4), (float) (((i2 * 800) / 850) + i3), (float) (((i * 60) / 480) + i4));
                canvas.drawRoundRect(rectF, 5.0f, 5.0f, this.mPaint);
                this.mPaint.setColor(-7829368);
                canvas.drawLine((float) (((i2 * 740) / 850) + i3), (float) (((i * 10) / 480) + i4), (float) (((i2 * 740) / 850) + i3), (float) (((i * 60) / 480) + i4), this.mPaint);
                this.mPaint.setColor(-12303292);
                canvas.drawLine((float) (((i2 * InputList.KEYCODE_DPADX_DOWN) / 850) + i3), (float) (((i * 20) / 480) + i4), (float) (((i2 * InputList.KEYCODE_DPADX_DOWN) / 850) + i3), (float) (((i * 50) / 480) + i4), this.mPaint);
                canvas.drawLine((float) (((i2 * 712) / 850) + i3), (float) (((i * 20) / 480) + i4), (float) (((i2 * 712) / 850) + i3), (float) (((i * 50) / 480) + i4), this.mPaint);
                canvas.drawLine((float) (((i2 * 770) / 850) + i3), (float) (((i * 20) / 480) + i4), (float) (((i2 * 770) / 850) + i3), (float) (((i * 50) / 480) + i4), this.mPaint);
            }
        }

        private void doDrawVirtualPadPortrait(Canvas canvas, int i, int i2, int i3, int i4) {
            RectF rectF = new RectF();
            this.mPaint.setColor(-12303292);
            this.mPaint.setStyle(Style.FILL);
            canvas.drawCircle((float) (((i2 * InputList.KEYCODE_BUTTON_13) / 850) + i3), (float) (((i * 260) / 480) + i4), (float) ((i * InputList.KEYCODE_MEDIA_RECORD) / 480), this.mPaint);
            this.mPaint.setColor(-7829368);
            this.mPaint.setStyle(Style.FILL);
            canvas.drawCircle((float) (((i2 * InputList.KEYCODE_BUTTON_13) / 850) + i3), (float) (((i * 260) / 480) + i4), (float) ((i * InputList.KEYCODE_BUTTON_MODE) / 480), this.mPaint);
            this.mPaint.setColor(-12303292);
            this.mPaint.setStyle(Style.FILL);
            canvas.drawCircle((float) (((i2 * InputList.KEYCODE_BUTTON_13) / 850) + i3), (float) (((i * 260) / 480) + i4), (float) ((i * 30) / 480), this.mPaint);
            this.mPaint.setColor(-65536);
            this.mPaint.setStyle(Style.FILL);
            Path path = new Path();
            path.moveTo(0.0f, 0.0f);
            path.lineTo(5.0f, 10.0f);
            path.lineTo(-5.0f, 10.0f);
            path.close();
            path.offset((float) (((i2 * InputList.KEYCODE_BUTTON_13) / 850) + i3), (float) (((((i * 260) / 480) - ((i * 80) / 480)) - 10) + i4));
            canvas.drawPath(path, this.mPaint);
            path = new Path();
            path.moveTo(0.0f, 0.0f);
            path.lineTo(-5.0f, -10.0f);
            path.lineTo(5.0f, -10.0f);
            path.close();
            path.offset((float) (((i2 * InputList.KEYCODE_BUTTON_13) / 850) + i3), (float) (((((i * 260) / 480) + ((i * 80) / 480)) + 10) + i4));
            canvas.drawPath(path, this.mPaint);
            path = new Path();
            path.moveTo(0.0f, 0.0f);
            path.lineTo(10.0f, -5.0f);
            path.lineTo(10.0f, 5.0f);
            path.close();
            path.offset((float) (((((i2 * InputList.KEYCODE_BUTTON_13) / 850) - ((i * 80) / 480)) - 10) + i3), (float) (((i * 260) / 480) + i4));
            canvas.drawPath(path, this.mPaint);
            path = new Path();
            path.moveTo(0.0f, 0.0f);
            path.lineTo(-10.0f, -5.0f);
            path.lineTo(-10.0f, 5.0f);
            path.close();
            path.offset((float) (((((i2 * InputList.KEYCODE_BUTTON_13) / 850) + ((i * 80) / 480)) + 10) + i3), (float) (((i * 260) / 480) + i4));
            canvas.drawPath(path, this.mPaint);
            this.mPaint.setColor(-7829368);
            this.mPaint.setStyle(Style.FILL);
            this.mPaint.setAlpha(4095);
            path = new Path();
            path.moveTo(0.0f, 0.0f);
            path.lineTo((float) ((-(i * 60)) / 480), (float) ((-(i * 25)) / 480));
            path.lineTo((float) ((-(i * 60)) / 480), (float) ((i * 25) / 480));
            path.close();
            path.offset((float) (((i2 * 540) / 850) + i3), (float) ((((i * 10) / 480) + ((i * 25) / 480)) + i4));
            canvas.drawPath(path, this.mPaint);
            rectF.set((float) (((i2 * 350) / 850) + i3), (float) (((i * 15) / 480) + i4), (float) (((i2 * 410) / 850) + i3), (float) (((i * 55) / 480) + i4));
            canvas.drawRoundRect(rectF, 5.0f, 5.0f, this.mPaint);
            this.mPaint.setColor(-7829368);
            this.mPaint.setStyle(Style.FILL);
            this.mPaint.setAlpha(4095);
            canvas.drawCircle((float) (((i2 * 560) / 850) + i3), (float) (((i * 320) / 480) + i4), (float) ((i * 50) / 480), this.mPaint);
            this.mPaint.setColor(-65281);
            canvas.drawLine((float) ((((i2 * 560) / 850) - 10) + i3), (float) ((((i * 320) / 480) - 10) + i4), (float) ((((i2 * 560) / 850) + 10) + i3), (float) ((((i * 320) / 480) - 10) + i4), this.mPaint);
            canvas.drawLine((float) ((((i2 * 560) / 850) + 10) + i3), (float) ((((i * 320) / 480) - 10) + i4), (float) ((((i2 * 560) / 850) + 10) + i3), (float) ((((i * 320) / 480) + 10) + i4), this.mPaint);
            canvas.drawLine((float) ((((i2 * 560) / 850) + 10) + i3), (float) ((((i * 320) / 480) + 10) + i4), (float) ((((i2 * 560) / 850) - 10) + i3), (float) ((((i * 320) / 480) + 10) + i4), this.mPaint);
            canvas.drawLine((float) ((((i2 * 560) / 850) - 10) + i3), (float) ((((i * 320) / 480) + 10) + i4), (float) ((((i2 * 560) / 850) - 10) + i3), (float) ((((i * 320) / 480) - 10) + i4), this.mPaint);
            this.mPaint.setColor(-7829368);
            this.mPaint.setStyle(Style.FILL);
            this.mPaint.setAlpha(4095);
            canvas.drawCircle((float) (((i2 * 665) / 850) + i3), (float) (((i * 240) / 480) + i4), (float) ((i * 50) / 480), this.mPaint);
            this.mPaint.setColor(-16711936);
            canvas.drawLine((float) (((i2 * 665) / 850) + i3), (float) ((((i * 240) / 480) - 10) + i4), (float) ((((i2 * 665) / 850) + 10) + i3), (float) ((((i * 240) / 480) + 10) + i4), this.mPaint);
            canvas.drawLine((float) ((((i2 * 665) / 850) + 10) + i3), (float) ((((i * 240) / 480) + 10) + i4), (float) ((((i2 * 665) / 850) - 10) + i3), (float) ((((i * 240) / 480) + 10) + i4), this.mPaint);
            canvas.drawLine((float) ((((i2 * 665) / 850) - 10) + i3), (float) ((((i * 240) / 480) + 10) + i4), (float) (((i2 * 665) / 850) + i3), (float) ((((i * 240) / 480) - 10) + i4), this.mPaint);
            this.mPaint.setColor(-7829368);
            this.mPaint.setStyle(Style.FILL);
            this.mPaint.setAlpha(4095);
            canvas.drawCircle((float) (((i2 * 760) / 850) + i3), (float) (((i * 320) / 480) + i4), (float) ((i * 50) / 480), this.mPaint);
            this.mPaint.setColor(-65536);
            this.mPaint.setStyle(Style.STROKE);
            this.mPaint.setAlpha(4095);
            this.mPaint.setStrokeWidth(3.0f);
            canvas.drawCircle((float) (((i2 * 760) / 850) + i3), (float) (((i * 320) / 480) + i4), (float) (((i * 50) / STATE_SAVING) / 480), this.mPaint);
            this.mPaint.setColor(-7829368);
            this.mPaint.setStyle(Style.FILL);
            this.mPaint.setAlpha(4095);
            canvas.drawCircle((float) (((i2 * 665) / 850) + i3), (float) (((i * 400) / 480) + i4), (float) ((i * 50) / 480), this.mPaint);
            this.mPaint.setColor(-16776961);
            canvas.drawLine((float) ((((i2 * 665) / 850) - 10) + i3), (float) ((((i * 400) / 480) - 10) + i4), (float) ((((i2 * 665) / 850) + 10) + i3), (float) ((((i * 400) / 480) + 10) + i4), this.mPaint);
            canvas.drawLine((float) ((((i2 * 665) / 850) + 10) + i3), (float) ((((i * 400) / 480) - 10) + i4), (float) ((((i2 * 665) / 850) - 10) + i3), (float) ((((i * 400) / 480) + 10) + i4), this.mPaint);
            this.mPaint.setColor(-7829368);
            this.mPaint.setStyle(Style.FILL);
            this.mPaint.setAlpha(4095);
            rectF.set((float) (((i2 * 30) / 850) + i3), (float) (((i * 10) / 480) + i4), (float) (((i2 * 210) / 850) + i3), (float) (((i * 70) / 480) + i4));
            canvas.drawRoundRect(rectF, 5.0f, 5.0f, this.mPaint);
            this.mPaint.setColor(-12303292);
            canvas.drawLine((float) (((i2 * InputList.KEYCODE_SYSRQ) / 850) + i3), (float) (((i * 10) / 480) + i4), (float) (((i2 * InputList.KEYCODE_SYSRQ) / 850) + i3), (float) (((i * 70) / 480) + i4), this.mPaint);
            this.mPaint.setColor(-12303292);
            canvas.drawLine((float) (((i2 * 75) / 850) + i3), (float) (((i * 20) / 480) + i4), (float) (((i2 * 75) / 850) + i3), (float) (((i * 60) / 480) + i4), this.mPaint);
            canvas.drawLine((float) (((i2 * InputList.KEYCODE_NUMPAD_ENTER) / 850) + i3), (float) (((i * 20) / 480) + i4), (float) (((i2 * InputList.KEYCODE_NUMPAD_ENTER) / 850) + i3), (float) (((i * 60) / 480) + i4), this.mPaint);
            canvas.drawLine((float) (((i2 * InputList.KEYCODE_TV) / 850) + i3), (float) (((i * 20) / 480) + i4), (float) (((i2 * InputList.KEYCODE_TV) / 850) + i3), (float) (((i * 60) / 480) + i4), this.mPaint);
            this.mPaint.setColor(-7829368);
            this.mPaint.setStyle(Style.FILL);
            this.mPaint.setAlpha(4095);
            rectF.set((float) (((i2 * 640) / 850) + i3), (float) (((i * 10) / 480) + i4), (float) (((i2 * 820) / 850) + i3), (float) (((i * 70) / 480) + i4));
            canvas.drawRoundRect(rectF, 5.0f, 5.0f, this.mPaint);
            this.mPaint.setColor(-12303292);
            canvas.drawLine((float) (((i2 * 730) / 850) + i3), (float) (((i * 10) / 480) + i4), (float) (((i2 * 730) / 850) + i3), (float) (((i * 70) / 480) + i4), this.mPaint);
            this.mPaint.setColor(-12303292);
            canvas.drawLine((float) (((i2 * 680) / 850) + i3), (float) (((i * 20) / 480) + i4), (float) (((i2 * 680) / 850) + i3), (float) (((i * 60) / 480) + i4), this.mPaint);
            canvas.drawLine((float) (((i2 * 690) / 850) + i3), (float) (((i * 20) / 480) + i4), (float) (((i2 * 690) / 850) + i3), (float) (((i * 60) / 480) + i4), this.mPaint);
            canvas.drawLine((float) (((i2 * 775) / 850) + i3), (float) (((i * 20) / 480) + i4), (float) (((i2 * 775) / 850) + i3), (float) (((i * 60) / 480) + i4), this.mPaint);
        }

        public void autosaving() {
            synchronized (this.mSurfaceHolder) {
                setState(STATE_AUTOSAVING);
            }
        }

        public void pause() {
            synchronized (this.mSurfaceHolder) {
                if (this.mMode == STATE_RUNNING) {
                    setState(STATE_PAUSE);
                }
            }
        }

        /* JADX WARNING: inconsistent code. */
        /* Code decompiled incorrectly, please refer to instructions dump. */
        public void run() {
            /*
            r12 = this;
            r3 = 0;
            r2 = 0;
            r1 = 0;
            r0 = 0;
        L_0x0004:
            r4 = r12.mRun;
            if (r4 == 0) goto L_0x01a5;
        L_0x0008:
            r4 = r12.mMode;
            r5 = 3;
            if (r4 != r5) goto L_0x0020;
        L_0x000d:
            r1 = 1;
            r4 = com.epsxe.ePSXe.ePSXeViewSoft.this;
            r4 = r4.f643e;
            r5 = 20;
            r4.setsslot(r5);
            r4 = "ePSXeViewSoft";
            r5 = "saving game in slot fixed";
            android.util.Log.e(r4, r5);
        L_0x0020:
            r4 = r12.mMode;
            r5 = 4;
            if (r4 != r5) goto L_0x0038;
        L_0x0025:
            r1 = 1;
            r4 = com.epsxe.ePSXe.ePSXeViewSoft.this;
            r4 = r4.f643e;
            r5 = 15;
            r4.setsslot(r5);
            r4 = "ePSXeViewSoft";
            r5 = "saving game in slot fixed";
            android.util.Log.e(r4, r5);
        L_0x0038:
            r5 = 0;
            r8 = java.lang.System.currentTimeMillis();
            r6 = r12.mStartTime;
            r6 = r8 - r6;
            r4 = com.epsxe.ePSXe.ePSXeViewSoft.this;
            r4 = r4.mfps;
            r10 = (long) r4;
            r6 = r6 * r10;
            r10 = 1000; // 0x3e8 float:1.401E-42 double:4.94E-321;
            r6 = r6 / r10;
            r10 = r12.mEmuTime;
            r6 = r6 - r10;
            r4 = com.epsxe.ePSXe.ePSXeViewSoft.this;
            r4 = r4.mfps;
            r4 = -r4;
            r10 = (long) r4;
            r4 = (r6 > r10 ? 1 : (r6 == r10 ? 0 : -1));
            if (r4 < 0) goto L_0x0066;
        L_0x005b:
            r4 = com.epsxe.ePSXe.ePSXeViewSoft.this;
            r4 = r4.mfps;
            r10 = (long) r4;
            r4 = (r6 > r10 ? 1 : (r6 == r10 ? 0 : -1));
            if (r4 <= 0) goto L_0x0086;
        L_0x0066:
            r4 = "ePSXeViewSoft";
            r10 = new java.lang.StringBuilder;
            r10.<init>();
            r11 = "Reseting time base ";
            r10 = r10.append(r11);
            r6 = r10.append(r6);
            r6 = r6.toString();
            android.util.Log.e(r4, r6);
            r6 = 0;
            r12.mEmuTime = r6;
            r12.mStartTime = r8;
            r6 = 0;
        L_0x0086:
            r8 = 0;
            r4 = (r6 > r8 ? 1 : (r6 == r8 ? 0 : -1));
            if (r4 <= 0) goto L_0x0132;
        L_0x008c:
            r4 = r12.skippedCount;
            r4 = r4 + 1;
            r12.skippedCount = r4;
            r4 = r12.skippedCount;
            r6 = 2;
            if (r4 >= r6) goto L_0x012c;
        L_0x0097:
            r4 = 2;
        L_0x0098:
            r6 = com.epsxe.ePSXe.ePSXeViewSoft.this;
            r6 = r6.f643e;
            r7 = r12.mWidth;
            r8 = r12.mHeight;
            r6.runepsxeframe(r7, r8, r4);
            r4 = r4 & 2;
            if (r4 != 0) goto L_0x00b1;
        L_0x00a9:
            r4 = com.epsxe.ePSXe.ePSXeViewSoft.this;
            r4 = r4.emu_enable_frameskip;
            if (r4 == 0) goto L_0x00c5;
        L_0x00b1:
            r4 = com.epsxe.ePSXe.ePSXeViewSoft.this;
            r4 = r4.f643e;
            r4 = r4.isSkip();
            if (r4 <= 0) goto L_0x011a;
        L_0x00bd:
            r4 = com.epsxe.ePSXe.ePSXeViewSoft.this;
            r4 = r4.emu_enable_frameskip;
            if (r4 <= 0) goto L_0x011a;
        L_0x00c5:
            r4 = com.epsxe.ePSXe.ePSXeViewSoft.this;
            r4 = r4.emu_enable_framelimit;
            r6 = 1;
            if (r4 == r6) goto L_0x00d1;
        L_0x00ce:
            r4 = 7;
            if (r0 <= r4) goto L_0x011a;
        L_0x00d1:
            r0 = com.epsxe.ePSXe.ePSXeViewSoft.this;
            r0 = r0.f643e;
            r0 = r0.getwidth();
            r4 = com.epsxe.ePSXe.ePSXeViewSoft.this;
            r4 = r4.f643e;
            r6 = r4.getheight();
            r12.doBlitToBitmap(r0, r6);
            r4 = com.epsxe.ePSXe.ePSXeViewSoft.this;	 Catch:{ all -> 0x01a8 }
            r4 = r4.emu_screen_orientation;	 Catch:{ all -> 0x01a8 }
            r7 = 1;
            if (r4 != r7) goto L_0x0166;
        L_0x00f1:
            r4 = com.epsxe.ePSXe.ePSXeViewSoft.this;	 Catch:{ all -> 0x01a8 }
            r4 = r4.emu_player_mode;	 Catch:{ all -> 0x01a8 }
            r7 = 1;
            if (r4 != r7) goto L_0x0166;
        L_0x00fa:
            r4 = r3 & 63;
            if (r4 == 0) goto L_0x0166;
        L_0x00fe:
            r2 = r12.mSurfaceHolder;	 Catch:{ all -> 0x01a8 }
            r4 = r12.DestRectPartial;	 Catch:{ all -> 0x01a8 }
            r4 = r2.lockCanvas(r4);	 Catch:{ all -> 0x01a8 }
            r2 = 0;
        L_0x0107:
            if (r4 == 0) goto L_0x0110;
        L_0x0109:
            r5 = r12.mSurfaceHolder;	 Catch:{ all -> 0x019b }
            monitor-enter(r5);	 Catch:{ all -> 0x019b }
            r12.doDraw(r4, r0, r6, r2);	 Catch:{ all -> 0x0198 }
            monitor-exit(r5);	 Catch:{ all -> 0x0198 }
        L_0x0110:
            r3 = r3 + 1;
            if (r4 == 0) goto L_0x0119;
        L_0x0114:
            r0 = r12.mSurfaceHolder;
            r0.unlockCanvasAndPost(r4);
        L_0x0119:
            r0 = 0;
        L_0x011a:
            r4 = 1;
            r6 = r12.mEmuTime;
            r4 = r4 + r6;
            r12.mEmuTime = r4;
            r0 = r0 + 1;
            r4 = 1;
            if (r1 != r4) goto L_0x0004;
        L_0x0126:
            r1 = 0;
            r12.mRun = r1;
            r1 = 0;
            goto L_0x0004;
        L_0x012c:
            r4 = 0;
            r12.skippedCount = r4;
            r4 = 0;
            goto L_0x0098;
        L_0x0132:
            r8 = 0;
            r4 = (r6 > r8 ? 1 : (r6 == r8 ? 0 : -1));
            if (r4 >= 0) goto L_0x0160;
        L_0x0138:
            r8 = r12.mEmuTime;
            r10 = 1;
            r4 = (r8 > r10 ? 1 : (r8 == r10 ? 0 : -1));
            if (r4 <= 0) goto L_0x0160;
        L_0x0140:
            r4 = com.epsxe.ePSXe.ePSXeViewSoft.this;	 Catch:{ Exception -> 0x01a6 }
            r4 = r4.emu_enable_framelimit;	 Catch:{ Exception -> 0x01a6 }
            r8 = 1;
            if (r4 != r8) goto L_0x0160;
        L_0x0149:
            r4 = com.epsxe.ePSXe.ePSXeViewSoft.this;	 Catch:{ Exception -> 0x01a6 }
            r4 = r4.emu_sound_latency;	 Catch:{ Exception -> 0x01a6 }
            if (r4 != 0) goto L_0x0160;
        L_0x0151:
            r8 = 1000; // 0x3e8 float:1.401E-42 double:4.94E-321;
            r6 = -r6;
            r6 = r6 * r8;
            r4 = com.epsxe.ePSXe.ePSXeViewSoft.this;	 Catch:{ Exception -> 0x01a6 }
            r4 = r4.mfps;	 Catch:{ Exception -> 0x01a6 }
            r8 = (long) r4;	 Catch:{ Exception -> 0x01a6 }
            r6 = r6 / r8;
            sleep(r6);	 Catch:{ Exception -> 0x01a6 }
        L_0x0160:
            r4 = 0;
            r12.skippedCount = r4;
            r4 = 0;
            goto L_0x0098;
        L_0x0166:
            r4 = com.epsxe.ePSXe.ePSXeViewSoft.this;	 Catch:{ all -> 0x01a8 }
            r4 = r4.emu_screen_ratio;	 Catch:{ all -> 0x01a8 }
            r7 = 1;
            if (r4 != r7) goto L_0x018e;
        L_0x016f:
            r4 = com.epsxe.ePSXe.ePSXeViewSoft.this;	 Catch:{ all -> 0x01a8 }
            r4 = r4.emu_screen_orientation;	 Catch:{ all -> 0x01a8 }
            if (r4 != 0) goto L_0x018e;
        L_0x0177:
            r4 = com.epsxe.ePSXe.ePSXeViewSoft.this;	 Catch:{ all -> 0x01a8 }
            r4 = r4.emu_player_mode;	 Catch:{ all -> 0x01a8 }
            r7 = 1;
            if (r4 != r7) goto L_0x018e;
        L_0x0180:
            if (r0 <= 0) goto L_0x018e;
        L_0x0182:
            if (r6 <= 0) goto L_0x018e;
        L_0x0184:
            r4 = r12.mSurfaceHolder;	 Catch:{ all -> 0x01a8 }
            r7 = r12.DestRectPartial;	 Catch:{ all -> 0x01a8 }
            r4 = r4.lockCanvas(r7);	 Catch:{ all -> 0x01a8 }
            goto L_0x0107;
        L_0x018e:
            r2 = r12.mSurfaceHolder;	 Catch:{ all -> 0x01a8 }
            r4 = 0;
            r4 = r2.lockCanvas(r4);	 Catch:{ all -> 0x01a8 }
            r2 = 1;
            goto L_0x0107;
        L_0x0198:
            r0 = move-exception;
            monitor-exit(r5);	 Catch:{ all -> 0x0198 }
            throw r0;	 Catch:{ all -> 0x019b }
        L_0x019b:
            r0 = move-exception;
            r1 = r4;
        L_0x019d:
            if (r1 == 0) goto L_0x01a4;
        L_0x019f:
            r2 = r12.mSurfaceHolder;
            r2.unlockCanvasAndPost(r1);
        L_0x01a4:
            throw r0;
        L_0x01a5:
            return;
        L_0x01a6:
            r4 = move-exception;
            goto L_0x0160;
        L_0x01a8:
            r0 = move-exception;
            r1 = r5;
            goto L_0x019d;
            */
            throw new UnsupportedOperationException("Method not decompiled: com.epsxe.ePSXe.ePSXeViewSoft.EmuThread.run():void");
        }

        public void saving() {
            synchronized (this.mSurfaceHolder) {
                setState(STATE_SAVING);
            }
        }

        public void setRunning(boolean z) {
            this.mRun = z;
        }

        public void setState(int i) {
            synchronized (this.mSurfaceHolder) {
                this.mMode = i;
            }
        }

        public void setSurfaceSize(int i, int i2) {
            synchronized (this.mSurfaceHolder) {
                this.mCanvasWidth = i;
                this.mCanvasHeight = i2;
                this.mWidth = i;
                this.mHeight = i2;
            }
        }

        public void unpause() {
            synchronized (this.mSurfaceHolder) {
                this.mLastTime = 100 + System.currentTimeMillis();
            }
            setState(STATE_RUNNING);
        }
    }

    public ePSXeViewSoft(Context context) {
        super(context);
        this.mfps = 60;
        this.ts_vibration = new int[]{0, 0};
        this.emu_enable_frameskip = 0;
        this.emu_enable_frameskip_tmp = 0;
        this.emu_enable_printfps = INPUT_HWBUTTONS;
        this.emu_player_mode = INPUT_HWBUTTONS;
        this.emu_split_mode = 0;
        this.emu_enable_mme = INPUT_HWBUTTONS;
        this.emu_screen_orientation = 0;
        this.emu_screen_ratio = 0;
        this.emu_pad_portrait = 0;
        this.emu_pad_mode = new int[]{INPUT_HWBUTTONS, INPUT_HWBUTTONS};
        this.emu_enable_framelimit = INPUT_HWBUTTONS;
        this.emu_pad_type = new int[]{0, 0};
        this.emu_video_filter = 0;
        this.emu_sound_latency = 0;
        this.license = true;
        this.skinName = "/sdcard/skin.png";
        SurfaceHolder holder = getHolder();
        holder.addCallback(this);
        this.thread = new EmuThread(holder, context);
        setFocusable(true);
        setFocusableInTouchMode(true);
        requestFocus();
    }

    private void dumpEvent(MotionEvent motionEvent) {
        int i = 0;
        String[] strArr = new String[]{"DOWN", "UP", "MOVE", "CANCEL", "OUTSIDE", "POINTER_DOWN", "POINTER_UP", "7?", "8?", "9?"};
        StringBuilder stringBuilder = new StringBuilder();
        int action = motionEvent.getAction();
        int i2 = action & 255;
        stringBuilder.append("event ACTION_").append(strArr[i2]);
        if (i2 == 5 || i2 == 6) {
            stringBuilder.append("(pid ").append(action >> ACTION_POINTER_INDEX_SHIFT);
            stringBuilder.append(")");
        }
        stringBuilder.append("[");
        while (i < motionEvent.getPointerCount()) {
            stringBuilder.append("#").append(i);
            stringBuilder.append("(pid ").append(motionEvent.getPointerId(i));
            stringBuilder.append(")=").append((int) motionEvent.getX(i));
            stringBuilder.append(",").append((int) motionEvent.getY(i));
            if (i + INPUT_HWBUTTONS < motionEvent.getPointerCount()) {
                stringBuilder.append(";");
            }
            i += INPUT_HWBUTTONS;
        }
        stringBuilder.append("]");
        Log.e("epsxegl", stringBuilder.toString());
    }

    public static int getActionIndexEclair(MotionEvent motionEvent) {
        return (ACTION_POINTER_INDEX_MASK & motionEvent.getAction()) >> ACTION_POINTER_INDEX_SHIFT;
    }

    private void queueMotionEvent(MotionEvent motionEvent) {
        int action = motionEvent.getAction() & 255;
        int actionIndex = this.osVersion >= ACTION_POINTER_INDEX_SHIFT ? motionEvent.getActionIndex() : getActionIndexEclair(motionEvent);
        if (this.emu_pad_type[0] != INPUT_HWBUTTONS || this.emu_pad_type[INPUT_HWBUTTONS] != INPUT_HWBUTTONS) {
            int i;
            if (action != 5 && action != 6 && action != INPUT_HWBUTTONS && action != 0) {
                i = 0;
                if (action == 2) {
                    int i2 = 0;
                    for (int i3 = 0; i3 < motionEvent.getPointerCount(); i3 += INPUT_HWBUTTONS) {
                        if (this.emu_player_mode != INPUT_HWBUTTONS) {
                            i2 += this.f643e.motionevent2P(motionEvent.getEventTime(), motionEvent.getAction(), motionEvent.getX(i3), motionEvent.getY(i3), motionEvent.getPressure(i3), motionEvent.getSize(i3), motionEvent.getDeviceId(), motionEvent.getPointerId(i3), this.emu_pad_type[0] | (this.emu_pad_type[INPUT_HWBUTTONS] << INPUT_HWBUTTONS));
                        } else if (this.emu_pad_type[0] == 0) {
                            i2 += this.f643e.motionevent(motionEvent.getEventTime(), motionEvent.getAction(), motionEvent.getX(i3), motionEvent.getY(i3), motionEvent.getPressure(i3), motionEvent.getSize(i3), motionEvent.getDeviceId(), motionEvent.getPointerId(i3));
                        }
                    }
                    i = i2;
                }
            } else if (this.emu_player_mode == INPUT_HWBUTTONS) {
                i = 0;
                if (this.emu_pad_type[0] == 0) {
                    i = this.f643e.motionevent(motionEvent.getEventTime(), motionEvent.getAction(), motionEvent.getX(actionIndex), motionEvent.getY(actionIndex), motionEvent.getPressure(actionIndex), motionEvent.getSize(actionIndex), motionEvent.getDeviceId(), motionEvent.getPointerId(actionIndex));
                }
            } else {
                i = this.f643e.motionevent2P(motionEvent.getEventTime(), motionEvent.getAction(), motionEvent.getX(actionIndex), motionEvent.getY(actionIndex), motionEvent.getPressure(actionIndex), motionEvent.getSize(actionIndex), motionEvent.getDeviceId(), motionEvent.getPointerId(actionIndex), this.emu_pad_type[0] | (this.emu_pad_type[INPUT_HWBUTTONS] << INPUT_HWBUTTONS));
            }
            if ((this.ts_vibration[0] == INPUT_HWBUTTONS && r1 == INPUT_HWBUTTONS) || (this.ts_vibration[INPUT_HWBUTTONS] == INPUT_HWBUTTONS && r1 == 2)) {
                ((Vibrator) this.mContext.getSystemService("vibrator")).vibrate(15);
            }
        }
    }

    public boolean dispatchTouchEvent(MotionEvent motionEvent) {
        queueMotionEvent(motionEvent);
        return true;
    }

    public void onAutosave(int i) {
        Log.e("epsxe", "epsxeview saving status");
        this.thread.autosaving();
    }

    public void onPause() {
        Log.e("epsxe", "epsxeview saving status");
        this.thread.saving();
    }

    /* JADX WARNING: inconsistent code. */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public void queueMotionEvent(int r11, int r12, int r13, int r14) {
        /*
        r10 = this;
        r1 = r11 & 255;
        r0 = r10.emu_pad_type;
        r2 = 0;
        r0 = r0[r2];
        r2 = 1;
        if (r0 != r2) goto L_0x0013;
    L_0x000a:
        r0 = r10.emu_pad_type;
        r2 = 1;
        r0 = r0[r2];
        r2 = 1;
        if (r0 != r2) goto L_0x0013;
    L_0x0012:
        return;
    L_0x0013:
        r0 = 5;
        if (r1 == r0) goto L_0x0022;
    L_0x0016:
        r0 = 6;
        if (r1 == r0) goto L_0x0022;
    L_0x0019:
        r0 = 1;
        if (r1 == r0) goto L_0x0022;
    L_0x001c:
        if (r1 == 0) goto L_0x0022;
    L_0x001e:
        r0 = 0;
        r2 = 2;
        if (r1 != r2) goto L_0x0040;
    L_0x0022:
        r0 = r10.emu_player_mode;
        r1 = 1;
        if (r0 != r1) goto L_0x002f;
    L_0x0027:
        r0 = r10.emu_pad_type;
        r1 = 0;
        r1 = r0[r1];
        r0 = 0;
        if (r1 != 0) goto L_0x0040;
    L_0x002f:
        r0 = r10.f643e;
        r1 = 0;
        r4 = (float) r12;
        r5 = (float) r13;
        r6 = 0;
        r7 = 0;
        r8 = 0;
        r3 = r11;
        r9 = r14;
        r0 = r0.motionevent(r1, r3, r4, r5, r6, r7, r8, r9);
        r0 = r0 + 0;
    L_0x0040:
        r1 = r10.ts_vibration;
        r2 = 0;
        r1 = r1[r2];
        r2 = 1;
        if (r1 != r2) goto L_0x004b;
    L_0x0048:
        r1 = 1;
        if (r0 == r1) goto L_0x0056;
    L_0x004b:
        r1 = r10.ts_vibration;
        r2 = 1;
        r1 = r1[r2];
        r2 = 1;
        if (r1 != r2) goto L_0x0012;
    L_0x0053:
        r1 = 2;
        if (r0 != r1) goto L_0x0012;
    L_0x0056:
        r0 = r10.mContext;
        r1 = "vibrator";
        r0 = r0.getSystemService(r1);
        r0 = (android.os.Vibrator) r0;
        r1 = 35;
        r0.vibrate(r1);
        goto L_0x0012;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.epsxe.ePSXe.ePSXeViewSoft.queueMotionEvent(int, int, int, int):void");
    }

    public void setIsoName(String str, int i, String str2) {
    }

    public void setSaveslot(int i) {
    }

    public void setanalogdebug(int i, int i2, int i3, int i4) {
    }

    public void setdebugstring(String str) {
    }

    public void setdebugstring2(String str) {
    }

    public void setePSXeLib(libepsxe com_epsxe_ePSXe_libepsxe) {
        this.f643e = com_epsxe_ePSXe_libepsxe;
        this.osVersion = Integer.parseInt(VERSION.SDK);
        if (this.osVersion < ACTION_POINTER_INDEX_SHIFT) {
            this.byteBuffer = ByteBuffer.allocateDirect(655360);
            Log.e("ePSXeViewSoft", "byteBuffer " + this.byteBuffer);
            this.f643e.setbuffer(this.byteBuffer);
        }
    }

    public void setfps(int i) {
        this.mfps = i;
        Log.e("ePSXeViewSoft", "fps = " + i);
    }

    public void setframeskip(int i) {
        this.emu_enable_frameskip = i;
        this.emu_enable_frameskip_tmp = i;
        Log.e("epsxeView", "FrameSkip = " + i);
        this.emu_enable_frameskip = this.f643e.setFrameSkip(this.emu_enable_frameskip);
        this.emu_enable_frameskip_tmp = this.emu_enable_frameskip;
    }

    public void setinputalpha(float f) {
    }

    public void setinputpadmode(int i, int i2, int i3, int i4) {
    }

    public void setinputpadmodeanalog(int i) {
    }

    public void setinputpadtype(int i, int i2) {
        this.emu_pad_type[0] = i;
        this.emu_pad_type[INPUT_HWBUTTONS] = i2;
        Log.e("epsxeView", "PadType " + i);
        Log.e("epsxeView", "PadType2 " + i2);
    }

    public void setinputpaintpadmode(int i, int i2) {
        this.emu_pad_mode[0] = i;
        this.emu_pad_mode[INPUT_HWBUTTONS] = i2;
        Log.e("epsxeView", "PadMode " + i);
        Log.e("epsxeView", "PadMode2 " + i2);
    }

    public void setinputskinname(String str) {
        this.skinName = str;
        Log.e("epsxeView", "skinName " + str);
    }

    public void setinputvibration(int i, int i2) {
        this.ts_vibration[0] = i;
        this.ts_vibration[INPUT_HWBUTTONS] = i2;
        Log.e("epsxeView", "InputVibrate1 = " + i);
        Log.e("epsxeView", "InputVibrate2 = " + i2);
    }

    public void setlicense(boolean z) {
        this.license = z;
    }

    public void setplayermode(int i) {
        this.emu_player_mode = i;
        Log.e("epsxeView", "PlayerMode = " + i);
        this.emu_player_mode = this.f643e.setPlayerMode(this.emu_player_mode);
        if (this.emu_player_mode != 10) {
            return;
        }
        if (this.emu_screen_orientation == 0) {
            this.emu_split_mode = INPUT_HWBUTTONS;
        } else {
            this.emu_split_mode = 0;
        }
    }

    public void setscreenblackbands(int i) {
        Log.e("epsxeView", "blackbands = " + i);
        this.f643e.setblackbands(i);
    }

    public void setscreendepth(int i) {
    }

    public void setscreenorientation(int i) {
        Log.e("epsxeView", "Orientation = " + i);
        if (i == 3) {
            i = 0;
        }
        this.emu_screen_orientation = this.f643e.setscreenorientation(i);
    }

    public void setscreenratio(int i) {
        Log.e("epsxeView", "Ratio = " + i);
        this.emu_screen_ratio = i;
    }

    public void setshowfps(int i) {
        this.emu_enable_printfps = i;
        Log.e("epsxeView", "CpuShowFPS " + i);
    }

    public void setsnaprestoring(boolean z) {
        Log.e("epsxeView", "loadtmp_snap ");
        this.f643e.loadtmpsnap();
    }

    public void setsoundlatency(int i) {
        Log.e("epsxeView", "SoundLatency = " + i);
        this.emu_sound_latency = this.f643e.setSoundLatency(i);
    }

    public void setsplitmode(int i) {
        this.emu_split_mode = i;
        Log.e("epsxeView", "SplitMode = " + i);
        this.emu_split_mode = this.f643e.setSplitMode(i);
    }

    public void setvideodither(int i) {
        Log.e("epsxeView", "PSX Dither = " + i);
        this.f643e.setDithering(i);
    }

    public void setvideofilter(int i) {
        Log.e("epsxeView", "Filter = " + i);
        this.emu_video_filter = i;
    }

    public void setvideofilterhw(int i) {
        Log.e("epsxeView", "PSX Filter hw = " + i);
    }

    public void surfaceChanged(SurfaceHolder surfaceHolder, int i, int i2, int i3) {
        this.thread.setSurfaceSize(i2, i3);
    }

    public void surfaceCreated(SurfaceHolder surfaceHolder) {
        this.thread.setRunning(true);
        this.thread.start();
    }

    public void surfaceDestroyed(SurfaceHolder surfaceHolder) {
        boolean z = true;
        this.thread.setRunning(false);
        while (z) {
            try {
                this.thread.join();
                z = false;
            } catch (InterruptedException e) {
            }
        }
    }

    public void toggleframelimit() {
        if (this.emu_enable_framelimit == INPUT_HWBUTTONS) {
            this.emu_enable_frameskip_tmp = this.emu_enable_frameskip;
            this.emu_enable_frameskip = 0;
            this.emu_enable_frameskip = this.f643e.setFrameSkip(this.emu_enable_frameskip);
            this.emu_enable_framelimit ^= INPUT_HWBUTTONS;
            this.emu_enable_framelimit = this.f643e.setFrameLimit(this.emu_enable_framelimit);
            return;
        }
        this.emu_enable_frameskip = this.emu_enable_frameskip_tmp;
        this.emu_enable_frameskip = this.f643e.setFrameSkip(this.emu_enable_frameskip);
        this.emu_enable_framelimit ^= INPUT_HWBUTTONS;
        this.emu_enable_framelimit = this.f643e.setFrameLimit(this.emu_enable_framelimit);
    }

    public void toggletools() {
    }
}
